# Copyright 2019 Gradient Health Inc. All Rights Reserved.
# Author: Marcelo Lerendegui <marcelo@gradienthealth.io>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================

"""Use decode_dicom ops in python."""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import tensorflow as tf
from tensorflow_io.core.python.ops import core_ops

def decode_dicom_image(
    contents,
    color_dim=False,
    on_error='skip',
    scale='preserve',
    dtype=tf.uint16,
    name=None):
  """Getting DICOM Image Data.

  This package has two operations which wrap `DCMTK` functions.
  `decode_dicom_image` decodes the pixel data from DICOM files, and
  `decode_dicom_data` decodes tag information.
  `dicom_tags` contains useful DICOM tags such as `dicom_tags.PatientsName`.
  We borrow the same tag notation from the
  [`pydicom`](https://pydicom.github.io/) dicom package.

  The detailed usage of DICOM is available in
  [tutorial](https://www.tensorflow.org/io/tutorials/dicom).

  If this package helped, please kindly cite the below:
  ```
  @misc{marcelo_lerendegui_2019_3337331,
    author       = {Marcelo Lerendegui and Ouwen Huang},
    title        = {Tensorflow Dicom Decoder},
    month        = jul,
    year         = 2019,
    doi          = {10.5281/zenodo.3337331},
    url          = {https://doi.org/10.5281/zenodo.3337331}
  }
  ```

  Args:
    contents: A Tensor of type string. 0-D. The byte string encoded DICOM file.
    color_dim: An optional `bool`. Defaults to `False`. If `True`, a third
      channel will be appended to all images forming a 3-D tensor.
      A 1024 x 1024 grayscale image will be 1024 x 1024 x 1.
    on_error: Defaults to `skip`. This attribute establishes the behavior in
      case an error occurs on opening the image or if the output type cannot
      accomodate all the possible input values. For example if the user sets
      the output dtype to `tf.uint8`, but a dicom image stores a `tf.uint16`
      type. `strict` throws an error. `skip` returns a 1-D empty tensor.
      `lossy` continues with the operation scaling the value via the `scale`
      attribute.
    scale:  Defaults to `preserve`. This attribute establishes what to do with
      the scale of the input values. `auto` will autoscale the input values,
      if the output type is integer, `auto` will use the maximum output scale
      for example a `uint8` which stores values from [0, 255] can be linearly
      stretched to fill a `uint16` that is [0,65535]. If the output is float,
      `auto` will scale to [0,1]. `preserve` keeps the values as they are, an
      input value greater than the maximum possible output will be clipped.
    dtype: An optional `tf.DType` from: `tf.uint8`, `tf.uint16`, `tf.uint32`,
      `tf.uint64`, `tf.float16`, `tf.float32`, `tf.float64`. Defaults to
      `tf.uint16`.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `dtype` and the shape is determined by the DICOM file.
  """
  return core_ops.io_decode_dicom_image(
      contents=contents,
      color_dim=color_dim,
      on_error=on_error,
      scale=scale,
      dtype=dtype,
      name=name)

def decode_dicom_data(
    contents,
    tags=None,
    name=None):
  """Getting DICOM Tag Data.

  This package has two operations which wrap `DCMTK` functions.
  `decode_dicom_image` decodes the pixel data from DICOM files, and
  `decode_dicom_data` decodes tag information.
  `dicom_tags` contains useful DICOM tags such as `dicom_tags.PatientsName`.
  We borrow the same tag notation from the
  [`pydicom`](https://pydicom.github.io/) dicom package.

  The detailed usage of DICOM is available in
  [tutorial](https://www.tensorflow.org/io/tutorials/dicom).

  If this package helped, please kindly cite the below:
  ```
  @misc{marcelo_lerendegui_2019_3337331,
    author       = {Marcelo Lerendegui and Ouwen Huang},
    title        = {Tensorflow Dicom Decoder},
    month        = jul,
    year         = 2019,
    doi          = {10.5281/zenodo.3337331},
    url          = {https://doi.org/10.5281/zenodo.3337331}
  }
  ```

  Args:
    contents: A Tensor of type string. 0-D. The byte string encoded DICOM file.
    tags: A Tensor of type `tf.uint32` of any dimension.
      These `uint32` numbers map directly to DICOM tags.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `tf.string` and same shape as `tags`. If a dicom tag is
      a list of strings, they are combined into one string and seperated by a
      double backslash `\\`. There is a bug in
      [DCMTK](https://support.dcmtk.org/docs/) if the tag is a list of numbers,
      only the zeroth element will be returned as a string.
  """
  return core_ops.io_decode_dicom_data(
      contents=contents,
      tags=tags,
      name=name)

class dicom_tags(): # pylint: disable=invalid-name
  """dicom_tags"""

  def __init__(self):
    pass
  # pylint: disable=invalid-name
  FileMetaInformationGroupLength = int('00020000', 16)
  FileMetaInformationVersion = int('00020001', 16)
  MediaStorageSOPClassUID = int('00020002', 16)
  MediaStorageSOPInstanceUID = int('00020003', 16)
  TransferSyntaxUID = int('00020010', 16)
  ImplementationClassUID = int('00020012', 16)
  ImplementationVersionName = int('00020013', 16)
  SourceApplicationEntityTitle = int('00020016', 16)
  SendingApplicationEntityTitle = int('00020017', 16)
  ReceivingApplicationEntityTitle = int('00020018', 16)
  PrivateInformationCreatorUID = int('00020100', 16)
  PrivateInformation = int('00020102', 16)
  FilesetID = int('00041130', 16)
  FilesetDescriptorFileID = int('00041141', 16)
  SpecificCharacterSetofFilesetDescriptorFile = int('00041142', 16)
  OffsetoftheFirstDirectoryRecordoftheRootDirectoryEntity = int(
      '00041200', 16)
  OffsetoftheLastDirectoryRecordoftheRootDirectoryEntity = int(
      '00041202', 16)
  FilesetConsistencyFlag = int('00041212', 16)
  DirectoryRecordSequence = int('00041220', 16)
  OffsetoftheNextDirectoryRecord = int('00041400', 16)
  RecordInuseFlag = int('00041410', 16)
  OffsetofReferencedLowerLevelDirectoryEntity = int('00041420', 16)
  DirectoryRecordType = int('00041430', 16)
  PrivateRecordUID = int('00041432', 16)
  ReferencedFileID = int('00041500', 16)
  MRDRDirectoryRecordOffset = int('00041504', 16)
  ReferencedSOPClassUIDinFile = int('00041510', 16)
  ReferencedSOPInstanceUIDinFile = int('00041511', 16)
  ReferencedTransferSyntaxUIDinFile = int('00041512', 16)
  ReferencedRelatedGeneralSOPClassUIDinFile = int('0004151A', 16)
  NumberofReferences = int('00041600', 16)
  LengthtoEnd = int('00080001', 16)
  SpecificCharacterSet = int('00080005', 16)
  LanguageCodeSequence = int('00080006', 16)
  ImageType = int('00080008', 16)
  RecognitionCode = int('00080010', 16)
  InstanceCreationDate = int('00080012', 16)
  InstanceCreationTime = int('00080013', 16)
  InstanceCreatorUID = int('00080014', 16)
  InstanceCoercionDateTime = int('00080015', 16)
  SOPClassUID = int('00080016', 16)
  SOPInstanceUID = int('00080018', 16)
  RelatedGeneralSOPClassUID = int('0008001A', 16)
  OriginalSpecializedSOPClassUID = int('0008001B', 16)
  StudyDate = int('00080020', 16)
  SeriesDate = int('00080021', 16)
  AcquisitionDate = int('00080022', 16)
  ContentDate = int('00080023', 16)
  OverlayDate = int('00080024', 16)
  CurveDate = int('00080025', 16)
  AcquisitionDateTime = int('0008002A', 16)
  StudyTime = int('00080030', 16)
  SeriesTime = int('00080031', 16)
  AcquisitionTime = int('00080032', 16)
  ContentTime = int('00080033', 16)
  OverlayTime = int('00080034', 16)
  CurveTime = int('00080035', 16)
  DataSetType = int('00080040', 16)
  DataSetSubtype = int('00080041', 16)
  NuclearMedicineSeriesType = int('00080042', 16)
  AccessionNumber = int('00080050', 16)
  IssuerofAccessionNumberSequence = int('00080051', 16)
  QueryRetrieveLevel = int('00080052', 16)
  QueryRetrieveView = int('00080053', 16)
  RetrieveAETitle = int('00080054', 16)
  StationAETitle = int('00080055', 16)
  InstanceAvailability = int('00080056', 16)
  FailedSOPInstanceUIDList = int('00080058', 16)
  Modality = int('00080060', 16)
  ModalitiesinStudy = int('00080061', 16)
  SOPClassesinStudy = int('00080062', 16)
  ConversionType = int('00080064', 16)
  PresentationIntentType = int('00080068', 16)
  Manufacturer = int('00080070', 16)
  InstitutionName = int('00080080', 16)
  InstitutionAddress = int('00080081', 16)
  InstitutionCodeSequence = int('00080082', 16)
  ReferringPhysiciansName = int('00080090', 16)
  ReferringPhysiciansAddress = int('00080092', 16)
  ReferringPhysiciansTelephoneNumbers = int('00080094', 16)
  ReferringPhysicianIdentificationSequence = int('00080096', 16)
  ConsultingPhysiciansName = int('0008009C', 16)
  ConsultingPhysicianIdentificationSequence = int('0008009D', 16)
  CodeValue = int('00080100', 16)
  ExtendedCodeValue = int('00080101', 16)
  CodingSchemeDesignator = int('00080102', 16)
  CodingSchemeVersion = int('00080103', 16)
  CodeMeaning = int('00080104', 16)
  MappingResource = int('00080105', 16)
  ContextGroupVersion = int('00080106', 16)
  ContextGroupLocalVersion = int('00080107', 16)
  ExtendedCodeMeaning = int('00080108', 16)
  ContextGroupExtensionFlag = int('0008010B', 16)
  CodingSchemeUID = int('0008010C', 16)
  ContextGroupExtensionCreatorUID = int('0008010D', 16)
  ContextIdentifier = int('0008010F', 16)
  CodingSchemeIdentificationSequence = int('00080110', 16)
  CodingSchemeRegistry = int('00080112', 16)
  CodingSchemeExternalID = int('00080114', 16)
  CodingSchemeName = int('00080115', 16)
  CodingSchemeResponsibleOrganization = int('00080116', 16)
  ContextUID = int('00080117', 16)
  MappingResourceUID = int('00080118', 16)
  LongCodeValue = int('00080119', 16)
  URNCodeValue = int('00080120', 16)
  EquivalentCodeSequence = int('00080121', 16)
  MappingResourceName = int('00080122', 16)
  ContextGroupIdentificationSequence = int('00080123', 16)
  MappingResourceIdentificationSequence = int('00080124', 16)
  TimezoneOffsetFromUTC = int('00080201', 16)
  PrivateDataElementCharacteristicsSequence = int('00080300', 16)
  PrivateGroupReference = int('00080301', 16)
  PrivateCreatorReference = int('00080302', 16)
  BlockIdentifyingInformationStatus = int('00080303', 16)
  NonidentifyingPrivateElements = int('00080304', 16)
  IdentifyingPrivateElements = int('00080306', 16)
  DeidentificationActionSequence = int('00080305', 16)
  DeidentificationAction = int('00080307', 16)
  NetworkID = int('00081000', 16)
  StationName = int('00081010', 16)
  StudyDescription = int('00081030', 16)
  ProcedureCodeSequence = int('00081032', 16)
  SeriesDescription = int('0008103E', 16)
  SeriesDescriptionCodeSequence = int('0008103F', 16)
  InstitutionalDepartmentName = int('00081040', 16)
  PhysiciansofRecord = int('00081048', 16)
  PhysiciansofRecordIdentificationSequence = int('00081049', 16)
  PerformingPhysiciansName = int('00081050', 16)
  PerformingPhysicianIdentificationSequence = int('00081052', 16)
  NameofPhysiciansReadingStudy = int('00081060', 16)
  PhysiciansReadingStudyIdentificationSequence = int('00081062', 16)
  OperatorsName = int('00081070', 16)
  OperatorIdentificationSequence = int('00081072', 16)
  AdmittingDiagnosesDescription = int('00081080', 16)
  AdmittingDiagnosesCodeSequence = int('00081084', 16)
  ManufacturersModelName = int('00081090', 16)
  ReferencedResultsSequence = int('00081100', 16)
  ReferencedStudySequence = int('00081110', 16)
  ReferencedPerformedProcedureStepSequence = int('00081111', 16)
  ReferencedSeriesSequence = int('00081115', 16)
  ReferencedPatientSequence = int('00081120', 16)
  ReferencedVisitSequence = int('00081125', 16)
  ReferencedOverlaySequence = int('00081130', 16)
  ReferencedStereometricInstanceSequence = int('00081134', 16)
  ReferencedWaveformSequence = int('0008113A', 16)
  ReferencedImageSequence = int('00081140', 16)
  ReferencedCurveSequence = int('00081145', 16)
  ReferencedInstanceSequence = int('0008114A', 16)
  ReferencedRealWorldValueMappingInstanceSequence = int('0008114B', 16)
  ReferencedSOPClassUID = int('00081150', 16)
  ReferencedSOPInstanceUID = int('00081155', 16)
  SOPClassesSupported = int('0008115A', 16)
  ReferencedFrameNumber = int('00081160', 16)
  SimpleFrameList = int('00081161', 16)
  CalculatedFrameList = int('00081162', 16)
  TimeRange = int('00081163', 16)
  FrameExtractionSequence = int('00081164', 16)
  MultiframeSourceSOPInstanceUID = int('00081167', 16)
  RetrieveURL = int('00081190', 16)
  TransactionUID = int('00081195', 16)
  WarningReason = int('00081196', 16)
  FailureReason = int('00081197', 16)
  FailedSOPSequence = int('00081198', 16)
  ReferencedSOPSequence = int('00081199', 16)
  OtherFailuresSequence = int('0008119A', 16)
  StudiesContainingOtherReferencedInstancesSequence = int('00081200', 16)
  RelatedSeriesSequence = int('00081250', 16)
  LossyImageCompressionRetired = int('00082110', 16)
  DerivationDescription = int('00082111', 16)
  SourceImageSequence = int('00082112', 16)
  StageName = int('00082120', 16)
  StageNumber = int('00082122', 16)
  NumberofStages = int('00082124', 16)
  ViewName = int('00082127', 16)
  ViewNumber = int('00082128', 16)
  NumberofEventTimers = int('00082129', 16)
  NumberofViewsinStage = int('0008212A', 16)
  EventElapsedTimes = int('00082130', 16)
  EventTimerNames = int('00082132', 16)
  EventTimerSequence = int('00082133', 16)
  EventTimeOffset = int('00082134', 16)
  EventCodeSequence = int('00082135', 16)
  StartTrim = int('00082142', 16)
  StopTrim = int('00082143', 16)
  RecommendedDisplayFrameRate = int('00082144', 16)
  TransducerPosition = int('00082200', 16)
  TransducerOrientation = int('00082204', 16)
  AnatomicStructure = int('00082208', 16)
  AnatomicRegionSequence = int('00082218', 16)
  AnatomicRegionModifierSequence = int('00082220', 16)
  PrimaryAnatomicStructureSequence = int('00082228', 16)
  AnatomicStructureSpaceorRegionSequence = int('00082229', 16)
  PrimaryAnatomicStructureModifierSequence = int('00082230', 16)
  TransducerPositionSequence = int('00082240', 16)
  TransducerPositionModifierSequence = int('00082242', 16)
  TransducerOrientationSequence = int('00082244', 16)
  TransducerOrientationModifierSequence = int('00082246', 16)
  AnatomicStructureSpaceOrRegionCodeSequenceTrial = int('00082251', 16)
  AnatomicPortalOfEntranceCodeSequenceTrial = int('00082253', 16)
  AnatomicApproachDirectionCodeSequenceTrial = int('00082255', 16)
  AnatomicPerspectiveDescriptionTrial = int('00082256', 16)
  AnatomicPerspectiveCodeSequenceTrial = int('00082257', 16)
  AnatomicLocationOfExaminingInstrumentDescriptionTrial = int('00082258', 16)
  AnatomicLocationOfExaminingInstrumentCodeSequenceTrial = int(
      '00082259', 16)
  AnatomicStructureSpaceOrRegionModifierCodeSequenceTrial = int(
      '0008225A', 16)
  OnAxisBackgroundAnatomicStructureCodeSequenceTrial = int('0008225C', 16)
  AlternateRepresentationSequence = int('00083001', 16)
  IrradiationEventUID = int('00083010', 16)
  SourceIrradiationEventSequence = int('00083011', 16)
  RadiopharmaceuticalAdministrationEventUID = int('00083012', 16)
  IdentifyingComments = int('00084000', 16)
  FrameType = int('00089007', 16)
  ReferencedImageEvidenceSequence = int('00089092', 16)
  ReferencedRawDataSequence = int('00089121', 16)
  CreatorVersionUID = int('00089123', 16)
  DerivationImageSequence = int('00089124', 16)
  SourceImageEvidenceSequence = int('00089154', 16)
  PixelPresentation = int('00089205', 16)
  VolumetricProperties = int('00089206', 16)
  VolumeBasedCalculationTechnique = int('00089207', 16)
  ComplexImageComponent = int('00089208', 16)
  AcquisitionContrast = int('00089209', 16)
  DerivationCodeSequence = int('00089215', 16)
  ReferencedPresentationStateSequence = int('00089237', 16)
  ReferencedOtherPlaneSequence = int('00089410', 16)
  FrameDisplaySequence = int('00089458', 16)
  RecommendedDisplayFrameRateinFloat = int('00089459', 16)
  SkipFrameRangeFlag = int('00089460', 16)
  PatientsName = int('00100010', 16)
  PatientID = int('00100020', 16)
  IssuerofPatientID = int('00100021', 16)
  TypeofPatientID = int('00100022', 16)
  IssuerofPatientIDQualifiersSequence = int('00100024', 16)
  SourcePatientGroupIdentificationSequence = int('00100026', 16)
  GroupofPatientsIdentificationSequence = int('00100027', 16)
  SubjectRelativePositioninImage = int('00100028', 16)
  PatientsBirthDate = int('00100030', 16)
  PatientsBirthTime = int('00100032', 16)
  PatientsBirthDateinAlternativeCalendar = int('00100033', 16)
  PatientsDeathDateinAlternativeCalendar = int('00100034', 16)
  PatientsAlternativeCalendar = int('00100035', 16)
  PatientsSex = int('00100040', 16)
  PatientsInsurancePlanCodeSequence = int('00100050', 16)
  PatientsPrimaryLanguageCodeSequence = int('00100101', 16)
  PatientsPrimaryLanguageModifierCodeSequence = int('00100102', 16)
  QualityControlSubject = int('00100200', 16)
  QualityControlSubjectTypeCodeSequence = int('00100201', 16)
  StrainDescription = int('00100212', 16)
  StrainNomenclature = int('00100213', 16)
  StrainStockNumber = int('00100214', 16)
  StrainSourceRegistryCodeSequence = int('00100215', 16)
  StrainStockSequence = int('00100216', 16)
  StrainSource = int('00100217', 16)
  StrainAdditionalInformation = int('00100218', 16)
  StrainCodeSequence = int('00100219', 16)
  OtherPatientIDs = int('00101000', 16)
  OtherPatientNames = int('00101001', 16)
  OtherPatientIDsSequence = int('00101002', 16)
  PatientsBirthName = int('00101005', 16)
  PatientsAge = int('00101010', 16)
  PatientsSize = int('00101020', 16)
  PatientsSizeCodeSequence = int('00101021', 16)
  PatientsWeight = int('00101030', 16)
  PatientsAddress = int('00101040', 16)
  InsurancePlanIdentification = int('00101050', 16)
  PatientsMothersBirthName = int('00101060', 16)
  MilitaryRank = int('00101080', 16)
  BranchofService = int('00101081', 16)
  MedicalRecordLocator = int('00101090', 16)
  ReferencedPatientPhotoSequence = int('00101100', 16)
  MedicalAlerts = int('00102000', 16)
  Allergies = int('00102110', 16)
  CountryofResidence = int('00102150', 16)
  RegionofResidence = int('00102152', 16)
  PatientsTelephoneNumbers = int('00102154', 16)
  PatientsTelecomInformation = int('00102155', 16)
  EthnicGroup = int('00102160', 16)
  Occupation = int('00102180', 16)
  SmokingStatus = int('001021A0', 16)
  AdditionalPatientHistory = int('001021B0', 16)
  PregnancyStatus = int('001021C0', 16)
  LastMenstrualDate = int('001021D0', 16)
  PatientsReligiousPreference = int('001021F0', 16)
  PatientSpeciesDescription = int('00102201', 16)
  PatientSpeciesCodeSequence = int('00102202', 16)
  PatientsSexNeutered = int('00102203', 16)
  AnatomicalOrientationType = int('00102210', 16)
  PatientBreedDescription = int('00102292', 16)
  PatientBreedCodeSequence = int('00102293', 16)
  BreedRegistrationSequence = int('00102294', 16)
  BreedRegistrationNumber = int('00102295', 16)
  BreedRegistryCodeSequence = int('00102296', 16)
  ResponsiblePerson = int('00102297', 16)
  ResponsiblePersonRole = int('00102298', 16)
  ResponsibleOrganization = int('00102299', 16)
  PatientComments = int('00104000', 16)
  ExaminedBodyThickness = int('00109431', 16)
  ClinicalTrialSponsorName = int('00120010', 16)
  ClinicalTrialProtocolID = int('00120020', 16)
  ClinicalTrialProtocolName = int('00120021', 16)
  ClinicalTrialSiteID = int('00120030', 16)
  ClinicalTrialSiteName = int('00120031', 16)
  ClinicalTrialSubjectID = int('00120040', 16)
  ClinicalTrialSubjectReadingID = int('00120042', 16)
  ClinicalTrialTimePointID = int('00120050', 16)
  ClinicalTrialTimePointDescription = int('00120051', 16)
  ClinicalTrialCoordinatingCenterName = int('00120060', 16)
  PatientIdentityRemoved = int('00120062', 16)
  DeidentificationMethod = int('00120063', 16)
  DeidentificationMethodCodeSequence = int('00120064', 16)
  ClinicalTrialSeriesID = int('00120071', 16)
  ClinicalTrialSeriesDescription = int('00120072', 16)
  ClinicalTrialProtocolEthicsCommitteeName = int('00120081', 16)
  ClinicalTrialProtocolEthicsCommitteeApprovalNumber = int('00120082', 16)
  ConsentforClinicalTrialUseSequence = int('00120083', 16)
  DistributionType = int('00120084', 16)
  ConsentforDistributionFlag = int('00120085', 16)
  CADFileFormat = int('00140023', 16)
  ComponentReferenceSystem = int('00140024', 16)
  ComponentManufacturingProcedure = int('00140025', 16)
  ComponentManufacturer = int('00140028', 16)
  MaterialThickness = int('00140030', 16)
  MaterialPipeDiameter = int('00140032', 16)
  MaterialIsolationDiameter = int('00140034', 16)
  MaterialGrade = int('00140042', 16)
  MaterialPropertiesDescription = int('00140044', 16)
  MaterialPropertiesFileFormatRetired = int('00140045', 16)
  MaterialNotes = int('00140046', 16)
  ComponentShape = int('00140050', 16)
  CurvatureType = int('00140052', 16)
  OuterDiameter = int('00140054', 16)
  InnerDiameter = int('00140056', 16)
  ComponentWelderIDs = int('00140100', 16)
  SecondaryApprovalStatus = int('00140101', 16)
  SecondaryReviewDate = int('00140102', 16)
  SecondaryReviewTime = int('00140103', 16)
  SecondaryReviewerName = int('00140104', 16)
  RepairID = int('00140105', 16)
  MultipleComponentApprovalSequence = int('00140106', 16)
  OtherApprovalStatus = int('00140107', 16)
  OtherSecondaryApprovalStatus = int('00140108', 16)
  ActualEnvironmentalConditions = int('00141010', 16)
  ExpiryDate = int('00141020', 16)
  EnvironmentalConditions = int('00141040', 16)
  EvaluatorSequence = int('00142002', 16)
  EvaluatorNumber = int('00142004', 16)
  EvaluatorName = int('00142006', 16)
  EvaluationAttempt = int('00142008', 16)
  IndicationSequence = int('00142012', 16)
  IndicationNumber = int('00142014', 16)
  IndicationLabel = int('00142016', 16)
  IndicationDescription = int('00142018', 16)
  IndicationType = int('0014201A', 16)
  IndicationDisposition = int('0014201C', 16)
  IndicationROISequence = int('0014201E', 16)
  IndicationPhysicalPropertySequence = int('00142030', 16)
  PropertyLabel = int('00142032', 16)
  CoordinateSystemNumberofAxes = int('00142202', 16)
  CoordinateSystemAxesSequence = int('00142204', 16)
  CoordinateSystemAxisDescription = int('00142206', 16)
  CoordinateSystemDataSetMapping = int('00142208', 16)
  CoordinateSystemAxisNumber = int('0014220A', 16)
  CoordinateSystemAxisType = int('0014220C', 16)
  CoordinateSystemAxisUnits = int('0014220E', 16)
  CoordinateSystemAxisValues = int('00142210', 16)
  CoordinateSystemTransformSequence = int('00142220', 16)
  TransformDescription = int('00142222', 16)
  TransformNumberofAxes = int('00142224', 16)
  TransformOrderofAxes = int('00142226', 16)
  TransformedAxisUnits = int('00142228', 16)
  CoordinateSystemTransformRotationandScaleMatrix = int('0014222A', 16)
  CoordinateSystemTransformTranslationMatrix = int('0014222C', 16)
  InternalDetectorFrameTime = int('00143011', 16)
  NumberofFramesIntegrated = int('00143012', 16)
  DetectorTemperatureSequence = int('00143020', 16)
  SensorName = int('00143022', 16)
  HorizontalOffsetofSensor = int('00143024', 16)
  VerticalOffsetofSensor = int('00143026', 16)
  SensorTemperature = int('00143028', 16)
  DarkCurrentSequence = int('00143040', 16)
  DarkCurrentCounts = int('00143050', 16)
  GainCorrectionReferenceSequence = int('00143060', 16)
  AirCounts = int('00143070', 16)
  KVUsedinGainCalibration = int('00143071', 16)
  MAUsedinGainCalibration = int('00143072', 16)
  NumberofFramesUsedforIntegration = int('00143073', 16)
  FilterMaterialUsedinGainCalibration = int('00143074', 16)
  FilterThicknessUsedinGainCalibration = int('00143075', 16)
  DateofGainCalibration = int('00143076', 16)
  TimeofGainCalibration = int('00143077', 16)
  BadPixelImage = int('00143080', 16)
  CalibrationNotes = int('00143099', 16)
  PulserEquipmentSequence = int('00144002', 16)
  PulserType = int('00144004', 16)
  PulserNotes = int('00144006', 16)
  ReceiverEquipmentSequence = int('00144008', 16)
  AmplifierType = int('0014400A', 16)
  ReceiverNotes = int('0014400C', 16)
  PreAmplifierEquipmentSequence = int('0014400E', 16)
  PreAmplifierNotes = int('0014400F', 16)
  TransmitTransducerSequence = int('00144010', 16)
  ReceiveTransducerSequence = int('00144011', 16)
  NumberofElements = int('00144012', 16)
  ElementShape = int('00144013', 16)
  ElementDimensionA = int('00144014', 16)
  ElementDimensionB = int('00144015', 16)
  ElementPitchA = int('00144016', 16)
  MeasuredBeamDimensionA = int('00144017', 16)
  MeasuredBeamDimensionB = int('00144018', 16)
  LocationofMeasuredBeamDiameter = int('00144019', 16)
  NominalFrequency = int('0014401A', 16)
  MeasuredCenterFrequency = int('0014401B', 16)
  MeasuredBandwidth = int('0014401C', 16)
  ElementPitchB = int('0014401D', 16)
  PulserSettingsSequence = int('00144020', 16)
  PulseWidth = int('00144022', 16)
  ExcitationFrequency = int('00144024', 16)
  ModulationType = int('00144026', 16)
  Damping = int('00144028', 16)
  ReceiverSettingsSequence = int('00144030', 16)
  AcquiredSoundpathLength = int('00144031', 16)
  AcquisitionCompressionType = int('00144032', 16)
  AcquisitionSampleSize = int('00144033', 16)
  RectifierSmoothing = int('00144034', 16)
  DACSequence = int('00144035', 16)
  DACType = int('00144036', 16)
  DACGainPoints = int('00144038', 16)
  DACTimePoints = int('0014403A', 16)
  DACAmplitude = int('0014403C', 16)
  PreAmplifierSettingsSequence = int('00144040', 16)
  TransmitTransducerSettingsSequence = int('00144050', 16)
  ReceiveTransducerSettingsSequence = int('00144051', 16)
  IncidentAngle = int('00144052', 16)
  CouplingTechnique = int('00144054', 16)
  CouplingMedium = int('00144056', 16)
  CouplingVelocity = int('00144057', 16)
  ProbeCenterLocationX = int('00144058', 16)
  ProbeCenterLocationZ = int('00144059', 16)
  SoundPathLength = int('0014405A', 16)
  DelayLawIdentifier = int('0014405C', 16)
  GateSettingsSequence = int('00144060', 16)
  GateThreshold = int('00144062', 16)
  VelocityofSound = int('00144064', 16)
  CalibrationSettingsSequence = int('00144070', 16)
  CalibrationProcedure = int('00144072', 16)
  ProcedureVersion = int('00144074', 16)
  ProcedureCreationDate = int('00144076', 16)
  ProcedureExpirationDate = int('00144078', 16)
  ProcedureLastModifiedDate = int('0014407A', 16)
  CalibrationTime = int('0014407C', 16)
  CalibrationDate = int('0014407E', 16)
  ProbeDriveEquipmentSequence = int('00144080', 16)
  DriveType = int('00144081', 16)
  ProbeDriveNotes = int('00144082', 16)
  DriveProbeSequence = int('00144083', 16)
  ProbeInductance = int('00144084', 16)
  ProbeResistance = int('00144085', 16)
  ReceiveProbeSequence = int('00144086', 16)
  ProbeDriveSettingsSequence = int('00144087', 16)
  BridgeResistors = int('00144088', 16)
  ProbeOrientationAngle = int('00144089', 16)
  UserSelectedGainY = int('0014408B', 16)
  UserSelectedPhase = int('0014408C', 16)
  UserSelectedOffsetX = int('0014408D', 16)
  UserSelectedOffsetY = int('0014408E', 16)
  ChannelSettingsSequence = int('00144091', 16)
  ChannelThreshold = int('00144092', 16)
  ScannerSettingsSequence = int('0014409A', 16)
  ScanProcedure = int('0014409B', 16)
  TranslationRateX = int('0014409C', 16)
  TranslationRateY = int('0014409D', 16)
  ChannelOverlap = int('0014409F', 16)
  ImageQualityIndicatorType = int('001440A0', 16)
  ImageQualityIndicatorMaterial = int('001440A1', 16)
  ImageQualityIndicatorSize = int('001440A2', 16)
  LINACEnergy = int('00145002', 16)
  LINACOutput = int('00145004', 16)
  ActiveAperture = int('00145100', 16)
  TotalAperture = int('00145101', 16)
  ApertureElevation = int('00145102', 16)
  MainLobeAngle = int('00145103', 16)
  MainRoofAngle = int('00145104', 16)
  ConnectorType = int('00145105', 16)
  WedgeModelNumber = int('00145106', 16)
  WedgeAngleFloat = int('00145107', 16)
  WedgeRoofAngle = int('00145108', 16)
  WedgeElement1Position = int('00145109', 16)
  WedgeMaterialVelocity = int('0014510A', 16)
  WedgeMaterial = int('0014510B', 16)
  WedgeOffsetZ = int('0014510C', 16)
  WedgeOriginOffsetX = int('0014510D', 16)
  WedgeTimeDelay = int('0014510E', 16)
  WedgeName = int('0014510F', 16)
  WedgeManufacturerName = int('00145110', 16)
  WedgeDescription = int('00145111', 16)
  NominalBeamAngle = int('00145112', 16)
  WedgeOffsetX = int('00145113', 16)
  WedgeOffsetY = int('00145114', 16)
  WedgeTotalLength = int('00145115', 16)
  WedgeInContactLength = int('00145116', 16)
  WedgeFrontGap = int('00145117', 16)
  WedgeTotalHeight = int('00145118', 16)
  WedgeFrontHeight = int('00145119', 16)
  WedgeRearHeight = int('0014511A', 16)
  WedgeTotalWidth = int('0014511B', 16)
  WedgeInContactWidth = int('0014511C', 16)
  WedgeChamferHeight = int('0014511D', 16)
  WedgeCurve = int('0014511E', 16)
  RadiusAlongtheWedge = int('0014511F', 16)
  ContrastBolusAgent = int('00180010', 16)
  ContrastBolusAgentSequence = int('00180012', 16)
  ContrastBolusT1Relaxivity = int('00180013', 16)
  ContrastBolusAdministrationRouteSequence = int('00180014', 16)
  BodyPartExamined = int('00180015', 16)
  ScanningSequence = int('00180020', 16)
  SequenceVariant = int('00180021', 16)
  ScanOptions = int('00180022', 16)
  MRAcquisitionType = int('00180023', 16)
  SequenceName = int('00180024', 16)
  AngioFlag = int('00180025', 16)
  InterventionDrugInformationSequence = int('00180026', 16)
  InterventionDrugStopTime = int('00180027', 16)
  InterventionDrugDose = int('00180028', 16)
  InterventionDrugCodeSequence = int('00180029', 16)
  AdditionalDrugSequence = int('0018002A', 16)
  Radionuclide = int('00180030', 16)
  Radiopharmaceutical = int('00180031', 16)
  EnergyWindowCenterline = int('00180032', 16)
  EnergyWindowTotalWidth = int('00180033', 16)
  InterventionDrugName = int('00180034', 16)
  InterventionDrugStartTime = int('00180035', 16)
  InterventionSequence = int('00180036', 16)
  TherapyType = int('00180037', 16)
  InterventionStatus = int('00180038', 16)
  TherapyDescription = int('00180039', 16)
  InterventionDescription = int('0018003A', 16)
  CineRate = int('00180040', 16)
  InitialCineRunState = int('00180042', 16)
  SliceThickness = int('00180050', 16)
  KVP = int('00180060', 16)
  CountsAccumulated = int('00180070', 16)
  AcquisitionTerminationCondition = int('00180071', 16)
  EffectiveDuration = int('00180072', 16)
  AcquisitionStartCondition = int('00180073', 16)
  AcquisitionStartConditionData = int('00180074', 16)
  AcquisitionTerminationConditionData = int('00180075', 16)
  RepetitionTime = int('00180080', 16)
  EchoTime = int('00180081', 16)
  InversionTime = int('00180082', 16)
  NumberofAverages = int('00180083', 16)
  ImagingFrequency = int('00180084', 16)
  ImagedNucleus = int('00180085', 16)
  EchoNumbers = int('00180086', 16)
  MagneticFieldStrength = int('00180087', 16)
  SpacingBetweenSlices = int('00180088', 16)
  NumberofPhaseEncodingSteps = int('00180089', 16)
  DataCollectionDiameter = int('00180090', 16)
  EchoTrainLength = int('00180091', 16)
  PercentSampling = int('00180093', 16)
  PercentPhaseFieldofView = int('00180094', 16)
  PixelBandwidth = int('00180095', 16)
  DeviceSerialNumber = int('00181000', 16)
  DeviceUID = int('00181002', 16)
  DeviceID = int('00181003', 16)
  PlateID = int('00181004', 16)
  GeneratorID = int('00181005', 16)
  GridID = int('00181006', 16)
  CassetteID = int('00181007', 16)
  GantryID = int('00181008', 16)
  SecondaryCaptureDeviceID = int('00181010', 16)
  HardcopyCreationDeviceID = int('00181011', 16)
  DateofSecondaryCapture = int('00181012', 16)
  TimeofSecondaryCapture = int('00181014', 16)
  SecondaryCaptureDeviceManufacturer = int('00181016', 16)
  HardcopyDeviceManufacturer = int('00181017', 16)
  SecondaryCaptureDeviceManufacturersModelName = int('00181018', 16)
  SecondaryCaptureDeviceSoftwareVersions = int('00181019', 16)
  HardcopyDeviceSoftwareVersion = int('0018101A', 16)
  HardcopyDeviceManufacturersModelName = int('0018101B', 16)
  SoftwareVersions = int('00181020', 16)
  VideoImageFormatAcquired = int('00181022', 16)
  DigitalImageFormatAcquired = int('00181023', 16)
  ProtocolName = int('00181030', 16)
  ContrastBolusRoute = int('00181040', 16)
  ContrastBolusVolume = int('00181041', 16)
  ContrastBolusStartTime = int('00181042', 16)
  ContrastBolusStopTime = int('00181043', 16)
  ContrastBolusTotalDose = int('00181044', 16)
  SyringeCounts = int('00181045', 16)
  ContrastFlowRate = int('00181046', 16)
  ContrastFlowDuration = int('00181047', 16)
  ContrastBolusIngredient = int('00181048', 16)
  ContrastBolusIngredientConcentration = int('00181049', 16)
  SpatialResolution = int('00181050', 16)
  TriggerTime = int('00181060', 16)
  TriggerSourceorType = int('00181061', 16)
  NominalInterval = int('00181062', 16)
  FrameTime = int('00181063', 16)
  CardiacFramingType = int('00181064', 16)
  FrameTimeVector = int('00181065', 16)
  FrameDelay = int('00181066', 16)
  ImageTriggerDelay = int('00181067', 16)
  MultiplexGroupTimeOffset = int('00181068', 16)
  TriggerTimeOffset = int('00181069', 16)
  SynchronizationTrigger = int('0018106A', 16)
  SynchronizationChannel = int('0018106C', 16)
  TriggerSamplePosition = int('0018106E', 16)
  RadiopharmaceuticalRoute = int('00181070', 16)
  RadiopharmaceuticalVolume = int('00181071', 16)
  RadiopharmaceuticalStartTime = int('00181072', 16)
  RadiopharmaceuticalStopTime = int('00181073', 16)
  RadionuclideTotalDose = int('00181074', 16)
  RadionuclideHalfLife = int('00181075', 16)
  RadionuclidePositronFraction = int('00181076', 16)
  RadiopharmaceuticalSpecificActivity = int('00181077', 16)
  RadiopharmaceuticalStartDateTime = int('00181078', 16)
  RadiopharmaceuticalStopDateTime = int('00181079', 16)
  BeatRejectionFlag = int('00181080', 16)
  LowRRValue = int('00181081', 16)
  HighRRValue = int('00181082', 16)
  IntervalsAcquired = int('00181083', 16)
  IntervalsRejected = int('00181084', 16)
  PVCRejection = int('00181085', 16)
  SkipBeats = int('00181086', 16)
  HeartRate = int('00181088', 16)
  CardiacNumberofImages = int('00181090', 16)
  TriggerWindow = int('00181094', 16)
  ReconstructionDiameter = int('00181100', 16)
  DistanceSourcetoDetector = int('00181110', 16)
  DistanceSourcetoPatient = int('00181111', 16)
  EstimatedRadiographicMagnificationFactor = int('00181114', 16)
  GantryDetectorTilt = int('00181120', 16)
  GantryDetectorSlew = int('00181121', 16)
  TableHeight = int('00181130', 16)
  TableTraverse = int('00181131', 16)
  TableMotion = int('00181134', 16)
  TableVerticalIncrement = int('00181135', 16)
  TableLateralIncrement = int('00181136', 16)
  TableLongitudinalIncrement = int('00181137', 16)
  TableAngle = int('00181138', 16)
  TableType = int('0018113A', 16)
  RotationDirection = int('00181140', 16)
  AngularPosition = int('00181141', 16)
  RadialPosition = int('00181142', 16)
  ScanArc = int('00181143', 16)
  AngularStep = int('00181144', 16)
  CenterofRotationOffset = int('00181145', 16)
  RotationOffset = int('00181146', 16)
  FieldofViewShape = int('00181147', 16)
  FieldofViewDimensions = int('00181149', 16)
  ExposureTime = int('00181150', 16)
  XRayTubeCurrent = int('00181151', 16)
  Exposure = int('00181152', 16)
  ExposureinAs = int('00181153', 16)
  AveragePulseWidth = int('00181154', 16)
  RadiationSetting = int('00181155', 16)
  RectificationType = int('00181156', 16)
  RadiationMode = int('0018115A', 16)
  ImageandFluoroscopyAreaDoseProduct = int('0018115E', 16)
  FilterType = int('00181160', 16)
  TypeofFilters = int('00181161', 16)
  IntensifierSize = int('00181162', 16)
  ImagerPixelSpacing = int('00181164', 16)
  Grid = int('00181166', 16)
  GeneratorPower = int('00181170', 16)
  CollimatorgridName = int('00181180', 16)
  CollimatorType = int('00181181', 16)
  FocalDistance = int('00181182', 16)
  XFocusCenter = int('00181183', 16)
  YFocusCenter = int('00181184', 16)
  FocalSpots = int('00181190', 16)
  AnodeTargetMaterial = int('00181191', 16)
  BodyPartThickness = int('001811A0', 16)
  CompressionForce = int('001811A2', 16)
  PaddleDescription = int('001811A4', 16)
  DateofLastCalibration = int('00181200', 16)
  TimeofLastCalibration = int('00181201', 16)
  DateTimeofLastCalibration = int('00181202', 16)
  ConvolutionKernel = int('00181210', 16)
  UpperLowerPixelValues = int('00181240', 16)
  ActualFrameDuration = int('00181242', 16)
  CountRate = int('00181243', 16)
  PreferredPlaybackSequencing = int('00181244', 16)
  ReceiveCoilName = int('00181250', 16)
  TransmitCoilName = int('00181251', 16)
  PlateType = int('00181260', 16)
  PhosphorType = int('00181261', 16)
  WaterEquivalentDiameter = int('00181271', 16)
  WaterEquivalentDiameterCalculationMethodCodeSequence = int('00181272', 16)
  ScanVelocity = int('00181300', 16)
  WholeBodyTechnique = int('00181301', 16)
  ScanLength = int('00181302', 16)
  AcquisitionMatrix = int('00181310', 16)
  InplanePhaseEncodingDirection = int('00181312', 16)
  FlipAngle = int('00181314', 16)
  VariableFlipAngleFlag = int('00181315', 16)
  SAR = int('00181316', 16)
  dBdt = int('00181318', 16)
  B1rms = int('00181320', 16)
  AcquisitionDeviceProcessingDescription = int('00181400', 16)
  AcquisitionDeviceProcessingCode = int('00181401', 16)
  CassetteOrientation = int('00181402', 16)
  CassetteSize = int('00181403', 16)
  ExposuresonPlate = int('00181404', 16)
  RelativeXRayExposure = int('00181405', 16)
  ExposureIndex = int('00181411', 16)
  TargetExposureIndex = int('00181412', 16)
  DeviationIndex = int('00181413', 16)
  ColumnAngulation = int('00181450', 16)
  TomoLayerHeight = int('00181460', 16)
  TomoAngle = int('00181470', 16)
  TomoTime = int('00181480', 16)
  TomoType = int('00181490', 16)
  TomoClass = int('00181491', 16)
  NumberofTomosynthesisSourceImages = int('00181495', 16)
  PositionerMotion = int('00181500', 16)
  PositionerType = int('00181508', 16)
  PositionerPrimaryAngle = int('00181510', 16)
  PositionerSecondaryAngle = int('00181511', 16)
  PositionerPrimaryAngleIncrement = int('00181520', 16)
  PositionerSecondaryAngleIncrement = int('00181521', 16)
  DetectorPrimaryAngle = int('00181530', 16)
  DetectorSecondaryAngle = int('00181531', 16)
  ShutterShape = int('00181600', 16)
  ShutterLeftVerticalEdge = int('00181602', 16)
  ShutterRightVerticalEdge = int('00181604', 16)
  ShutterUpperHorizontalEdge = int('00181606', 16)
  ShutterLowerHorizontalEdge = int('00181608', 16)
  CenterofCircularShutter = int('00181610', 16)
  RadiusofCircularShutter = int('00181612', 16)
  VerticesofthePolygonalShutter = int('00181620', 16)
  ShutterPresentationValue = int('00181622', 16)
  ShutterOverlayGroup = int('00181623', 16)
  ShutterPresentationColorCIELabValue = int('00181624', 16)
  CollimatorShape = int('00181700', 16)
  CollimatorLeftVerticalEdge = int('00181702', 16)
  CollimatorRightVerticalEdge = int('00181704', 16)
  CollimatorUpperHorizontalEdge = int('00181706', 16)
  CollimatorLowerHorizontalEdge = int('00181708', 16)
  CenterofCircularCollimator = int('00181710', 16)
  RadiusofCircularCollimator = int('00181712', 16)
  VerticesofthePolygonalCollimator = int('00181720', 16)
  AcquisitionTimeSynchronized = int('00181800', 16)
  TimeSource = int('00181801', 16)
  TimeDistributionProtocol = int('00181802', 16)
  NTPSourceAddress = int('00181803', 16)
  PageNumberVector = int('00182001', 16)
  FrameLabelVector = int('00182002', 16)
  FramePrimaryAngleVector = int('00182003', 16)
  FrameSecondaryAngleVector = int('00182004', 16)
  SliceLocationVector = int('00182005', 16)
  DisplayWindowLabelVector = int('00182006', 16)
  NominalScannedPixelSpacing = int('00182010', 16)
  DigitizingDeviceTransportDirection = int('00182020', 16)
  RotationofScannedFilm = int('00182030', 16)
  BiopsyTargetSequence = int('00182041', 16)
  TargetUID = int('00182042', 16)
  LocalizingCursorPosition = int('00182043', 16)
  CalculatedTargetPosition = int('00182044', 16)
  TargetLabel = int('00182045', 16)
  DisplayedZValue = int('00182046', 16)
  IVUSAcquisition = int('00183100', 16)
  IVUSPullbackRate = int('00183101', 16)
  IVUSGatedRate = int('00183102', 16)
  IVUSPullbackStartFrameNumber = int('00183103', 16)
  IVUSPullbackStopFrameNumber = int('00183104', 16)
  LesionNumber = int('00183105', 16)
  AcquisitionComments = int('00184000', 16)
  OutputPower = int('00185000', 16)
  TransducerData = int('00185010', 16)
  FocusDepth = int('00185012', 16)
  ProcessingFunction = int('00185020', 16)
  PostprocessingFunction = int('00185021', 16)
  MechanicalIndex = int('00185022', 16)
  BoneThermalIndex = int('00185024', 16)
  CranialThermalIndex = int('00185026', 16)
  SoftTissueThermalIndex = int('00185027', 16)
  SoftTissuefocusThermalIndex = int('00185028', 16)
  SoftTissuesurfaceThermalIndex = int('00185029', 16)
  DynamicRange = int('00185030', 16)
  TotalGain = int('00185040', 16)
  DepthofScanField = int('00185050', 16)
  PatientPosition = int('00185100', 16)
  ViewPosition = int('00185101', 16)
  ProjectionEponymousNameCodeSequence = int('00185104', 16)
  ImageTransformationMatrix = int('00185210', 16)
  ImageTranslationVector = int('00185212', 16)
  Sensitivity = int('00186000', 16)
  SequenceofUltrasoundRegions = int('00186011', 16)
  RegionSpatialFormat = int('00186012', 16)
  RegionDataType = int('00186014', 16)
  RegionFlags = int('00186016', 16)
  RegionLocationMinX0 = int('00186018', 16)
  RegionLocationMinY0 = int('0018601A', 16)
  RegionLocationMaxX1 = int('0018601C', 16)
  RegionLocationMaxY1 = int('0018601E', 16)
  ReferencePixelX0 = int('00186020', 16)
  ReferencePixelY0 = int('00186022', 16)
  PhysicalUnitsXDirection = int('00186024', 16)
  PhysicalUnitsYDirection = int('00186026', 16)
  ReferencePixelPhysicalValueX = int('00186028', 16)
  ReferencePixelPhysicalValueY = int('0018602A', 16)
  PhysicalDeltaX = int('0018602C', 16)
  PhysicalDeltaY = int('0018602E', 16)
  TransducerFrequency = int('00186030', 16)
  TransducerType = int('00186031', 16)
  PulseRepetitionFrequency = int('00186032', 16)
  DopplerCorrectionAngle = int('00186034', 16)
  SteeringAngle = int('00186036', 16)
  DopplerSampleVolumeXPositionRetired = int('00186038', 16)
  DopplerSampleVolumeXPosition = int('00186039', 16)
  DopplerSampleVolumeYPositionRetired = int('0018603A', 16)
  DopplerSampleVolumeYPosition = int('0018603B', 16)
  TMLinePositionX0Retired = int('0018603C', 16)
  TMLinePositionX0 = int('0018603D', 16)
  TMLinePositionY0Retired = int('0018603E', 16)
  TMLinePositionY0 = int('0018603F', 16)
  TMLinePositionX1Retired = int('00186040', 16)
  TMLinePositionX1 = int('00186041', 16)
  TMLinePositionY1Retired = int('00186042', 16)
  TMLinePositionY1 = int('00186043', 16)
  PixelComponentOrganization = int('00186044', 16)
  PixelComponentMask = int('00186046', 16)
  PixelComponentRangeStart = int('00186048', 16)
  PixelComponentRangeStop = int('0018604A', 16)
  PixelComponentPhysicalUnits = int('0018604C', 16)
  PixelComponentDataType = int('0018604E', 16)
  NumberofTableBreakPoints = int('00186050', 16)
  TableofXBreakPoints = int('00186052', 16)
  TableofYBreakPoints = int('00186054', 16)
  NumberofTableEntries = int('00186056', 16)
  TableofPixelValues = int('00186058', 16)
  TableofParameterValues = int('0018605A', 16)
  RWaveTimeVector = int('00186060', 16)
  DetectorConditionsNominalFlag = int('00187000', 16)
  DetectorTemperature = int('00187001', 16)
  DetectorType = int('00187004', 16)
  DetectorConfiguration = int('00187005', 16)
  DetectorDescription = int('00187006', 16)
  DetectorMode = int('00187008', 16)
  DetectorID = int('0018700A', 16)
  DateofLastDetectorCalibration = int('0018700C', 16)
  TimeofLastDetectorCalibration = int('0018700E', 16)
  ExposuresonDetectorSinceLastCalibration = int('00187010', 16)
  ExposuresonDetectorSinceManufactured = int('00187011', 16)
  DetectorTimeSinceLastExposure = int('00187012', 16)
  DetectorActiveTime = int('00187014', 16)
  DetectorActivationOffsetFromExposure = int('00187016', 16)
  DetectorBinning = int('0018701A', 16)
  DetectorElementPhysicalSize = int('00187020', 16)
  DetectorElementSpacing = int('00187022', 16)
  DetectorActiveShape = int('00187024', 16)
  DetectorActiveDimensions = int('00187026', 16)
  DetectorActiveOrigin = int('00187028', 16)
  DetectorManufacturerName = int('0018702A', 16)
  DetectorManufacturersModelName = int('0018702B', 16)
  FieldofViewOrigin = int('00187030', 16)
  FieldofViewRotation = int('00187032', 16)
  FieldofViewHorizontalFlip = int('00187034', 16)
  PixelDataAreaOriginRelativeToFOV = int('00187036', 16)
  PixelDataAreaRotationAngleRelativeToFOV = int('00187038', 16)
  GridAbsorbingMaterial = int('00187040', 16)
  GridSpacingMaterial = int('00187041', 16)
  GridThickness = int('00187042', 16)
  GridPitch = int('00187044', 16)
  GridAspectRatio = int('00187046', 16)
  GridPeriod = int('00187048', 16)
  GridFocalDistance = int('0018704C', 16)
  FilterMaterial = int('00187050', 16)
  FilterThicknessMinimum = int('00187052', 16)
  FilterThicknessMaximum = int('00187054', 16)
  FilterBeamPathLengthMinimum = int('00187056', 16)
  FilterBeamPathLengthMaximum = int('00187058', 16)
  ExposureControlMode = int('00187060', 16)
  ExposureControlModeDescription = int('00187062', 16)
  ExposureStatus = int('00187064', 16)
  PhototimerSetting = int('00187065', 16)
  ExposureTimeinS = int('00188150', 16)
  XRayTubeCurrentinA = int('00188151', 16)
  ContentQualification = int('00189004', 16)
  PulseSequenceName = int('00189005', 16)
  MRImagingModifierSequence = int('00189006', 16)
  EchoPulseSequence = int('00189008', 16)
  InversionRecovery = int('00189009', 16)
  FlowCompensation = int('00189010', 16)
  MultipleSpinEcho = int('00189011', 16)
  MultiplanarExcitation = int('00189012', 16)
  PhaseContrast = int('00189014', 16)
  TimeofFlightContrast = int('00189015', 16)
  Spoiling = int('00189016', 16)
  SteadyStatePulseSequence = int('00189017', 16)
  EchoPlanarPulseSequence = int('00189018', 16)
  TagAngleFirstAxis = int('00189019', 16)
  MagnetizationTransfer = int('00189020', 16)
  T2Preparation = int('00189021', 16)
  BloodSignalNulling = int('00189022', 16)
  SaturationRecovery = int('00189024', 16)
  SpectrallySelectedSuppression = int('00189025', 16)
  SpectrallySelectedExcitation = int('00189026', 16)
  SpatialPresaturation = int('00189027', 16)
  Tagging = int('00189028', 16)
  OversamplingPhase = int('00189029', 16)
  TagSpacingFirstDimension = int('00189030', 16)
  GeometryofkSpaceTraversal = int('00189032', 16)
  SegmentedkSpaceTraversal = int('00189033', 16)
  RectilinearPhaseEncodeReordering = int('00189034', 16)
  TagThickness = int('00189035', 16)
  PartialFourierDirection = int('00189036', 16)
  CardiacSynchronizationTechnique = int('00189037', 16)
  ReceiveCoilManufacturerName = int('00189041', 16)
  MRReceiveCoilSequence = int('00189042', 16)
  ReceiveCoilType = int('00189043', 16)
  QuadratureReceiveCoil = int('00189044', 16)
  MultiCoilDefinitionSequence = int('00189045', 16)
  MultiCoilConfiguration = int('00189046', 16)
  MultiCoilElementName = int('00189047', 16)
  MultiCoilElementUsed = int('00189048', 16)
  MRTransmitCoilSequence = int('00189049', 16)
  TransmitCoilManufacturerName = int('00189050', 16)
  TransmitCoilType = int('00189051', 16)
  SpectralWidth = int('00189052', 16)
  ChemicalShiftReference = int('00189053', 16)
  VolumeLocalizationTechnique = int('00189054', 16)
  MRAcquisitionFrequencyEncodingSteps = int('00189058', 16)
  Decoupling = int('00189059', 16)
  DecoupledNucleus = int('00189060', 16)
  DecouplingFrequency = int('00189061', 16)
  DecouplingMethod = int('00189062', 16)
  DecouplingChemicalShiftReference = int('00189063', 16)
  kspaceFiltering = int('00189064', 16)
  TimeDomainFiltering = int('00189065', 16)
  NumberofZeroFills = int('00189066', 16)
  BaselineCorrection = int('00189067', 16)
  ParallelReductionFactorInplane = int('00189069', 16)
  CardiacRRIntervalSpecified = int('00189070', 16)
  AcquisitionDuration = int('00189073', 16)
  FrameAcquisitionDateTime = int('00189074', 16)
  DiffusionDirectionality = int('00189075', 16)
  DiffusionGradientDirectionSequence = int('00189076', 16)
  ParallelAcquisition = int('00189077', 16)
  ParallelAcquisitionTechnique = int('00189078', 16)
  InversionTimes = int('00189079', 16)
  MetaboliteMapDescription = int('00189080', 16)
  PartialFourier = int('00189081', 16)
  EffectiveEchoTime = int('00189082', 16)
  MetaboliteMapCodeSequence = int('00189083', 16)
  ChemicalShiftSequence = int('00189084', 16)
  CardiacSignalSource = int('00189085', 16)
  Diffusionbvalue = int('00189087', 16)
  DiffusionGradientOrientation = int('00189089', 16)
  VelocityEncodingDirection = int('00189090', 16)
  VelocityEncodingMinimumValue = int('00189091', 16)
  VelocityEncodingAcquisitionSequence = int('00189092', 16)
  NumberofkSpaceTrajectories = int('00189093', 16)
  CoverageofkSpace = int('00189094', 16)
  SpectroscopyAcquisitionPhaseRows = int('00189095', 16)
  ParallelReductionFactorInplaneRetired = int('00189096', 16)
  TransmitterFrequency = int('00189098', 16)
  ResonantNucleus = int('00189100', 16)
  FrequencyCorrection = int('00189101', 16)
  MRSpectroscopyFOVGeometrySequence = int('00189103', 16)
  SlabThickness = int('00189104', 16)
  SlabOrientation = int('00189105', 16)
  MidSlabPosition = int('00189106', 16)
  MRSpatialSaturationSequence = int('00189107', 16)
  MRTimingandRelatedParametersSequence = int('00189112', 16)
  MREchoSequence = int('00189114', 16)
  MRModifierSequence = int('00189115', 16)
  MRDiffusionSequence = int('00189117', 16)
  CardiacSynchronizationSequence = int('00189118', 16)
  MRAveragesSequence = int('00189119', 16)
  MRFOVGeometrySequence = int('00189125', 16)
  VolumeLocalizationSequence = int('00189126', 16)
  SpectroscopyAcquisitionDataColumns = int('00189127', 16)
  DiffusionAnisotropyType = int('00189147', 16)
  FrameReferenceDateTime = int('00189151', 16)
  MRMetaboliteMapSequence = int('00189152', 16)
  ParallelReductionFactoroutofplane = int('00189155', 16)
  SpectroscopyAcquisitionOutofplanePhaseSteps = int('00189159', 16)
  BulkMotionStatus = int('00189166', 16)
  ParallelReductionFactorSecondInplane = int('00189168', 16)
  CardiacBeatRejectionTechnique = int('00189169', 16)
  RespiratoryMotionCompensationTechnique = int('00189170', 16)
  RespiratorySignalSource = int('00189171', 16)
  BulkMotionCompensationTechnique = int('00189172', 16)
  BulkMotionSignalSource = int('00189173', 16)
  ApplicableSafetyStandardAgency = int('00189174', 16)
  ApplicableSafetyStandardDescription = int('00189175', 16)
  OperatingModeSequence = int('00189176', 16)
  OperatingModeType = int('00189177', 16)
  OperatingMode = int('00189178', 16)
  SpecificAbsorptionRateDefinition = int('00189179', 16)
  GradientOutputType = int('00189180', 16)
  SpecificAbsorptionRateValue = int('00189181', 16)
  GradientOutput = int('00189182', 16)
  FlowCompensationDirection = int('00189183', 16)
  TaggingDelay = int('00189184', 16)
  RespiratoryMotionCompensationTechniqueDescription = int('00189185', 16)
  RespiratorySignalSourceID = int('00189186', 16)
  ChemicalShiftMinimumIntegrationLimitinHz = int('00189195', 16)
  ChemicalShiftMaximumIntegrationLimitinHz = int('00189196', 16)
  MRVelocityEncodingSequence = int('00189197', 16)
  FirstOrderPhaseCorrection = int('00189198', 16)
  WaterReferencedPhaseCorrection = int('00189199', 16)
  MRSpectroscopyAcquisitionType = int('00189200', 16)
  RespiratoryCyclePosition = int('00189214', 16)
  VelocityEncodingMaximumValue = int('00189217', 16)
  TagSpacingSecondDimension = int('00189218', 16)
  TagAngleSecondAxis = int('00189219', 16)
  FrameAcquisitionDuration = int('00189220', 16)
  MRImageFrameTypeSequence = int('00189226', 16)
  MRSpectroscopyFrameTypeSequence = int('00189227', 16)
  MRAcquisitionPhaseEncodingStepsinplane = int('00189231', 16)
  MRAcquisitionPhaseEncodingStepsoutofplane = int('00189232', 16)
  SpectroscopyAcquisitionPhaseColumns = int('00189234', 16)
  CardiacCyclePosition = int('00189236', 16)
  SpecificAbsorptionRateSequence = int('00189239', 16)
  RFEchoTrainLength = int('00189240', 16)
  GradientEchoTrainLength = int('00189241', 16)
  ArterialSpinLabelingContrast = int('00189250', 16)
  MRArterialSpinLabelingSequence = int('00189251', 16)
  ASLTechniqueDescription = int('00189252', 16)
  ASLSlabNumber = int('00189253', 16)
  ASLSlabThickness = int('00189254', 16)
  ASLSlabOrientation = int('00189255', 16)
  ASLMidSlabPosition = int('00189256', 16)
  ASLContext = int('00189257', 16)
  ASLPulseTrainDuration = int('00189258', 16)
  ASLCrusherFlag = int('00189259', 16)
  ASLCrusherFlowLimit = int('0018925A', 16)
  ASLCrusherDescription = int('0018925B', 16)
  ASLBolusCutoffFlag = int('0018925C', 16)
  ASLBolusCutoffTimingSequence = int('0018925D', 16)
  ASLBolusCutoffTechnique = int('0018925E', 16)
  ASLBolusCutoffDelayTime = int('0018925F', 16)
  ASLSlabSequence = int('00189260', 16)
  ChemicalShiftMinimumIntegrationLimitinppm = int('00189295', 16)
  ChemicalShiftMaximumIntegrationLimitinppm = int('00189296', 16)
  WaterReferenceAcquisition = int('00189297', 16)
  EchoPeakPosition = int('00189298', 16)
  CTAcquisitionTypeSequence = int('00189301', 16)
  AcquisitionType = int('00189302', 16)
  TubeAngle = int('00189303', 16)
  CTAcquisitionDetailsSequence = int('00189304', 16)
  RevolutionTime = int('00189305', 16)
  SingleCollimationWidth = int('00189306', 16)
  TotalCollimationWidth = int('00189307', 16)
  CTTableDynamicsSequence = int('00189308', 16)
  TableSpeed = int('00189309', 16)
  TableFeedperRotation = int('00189310', 16)
  SpiralPitchFactor = int('00189311', 16)
  CTGeometrySequence = int('00189312', 16)
  DataCollectionCenterPatient = int('00189313', 16)
  CTReconstructionSequence = int('00189314', 16)
  ReconstructionAlgorithm = int('00189315', 16)
  ConvolutionKernelGroup = int('00189316', 16)
  ReconstructionFieldofView = int('00189317', 16)
  ReconstructionTargetCenterPatient = int('00189318', 16)
  ReconstructionAngle = int('00189319', 16)
  ImageFilter = int('00189320', 16)
  CTExposureSequence = int('00189321', 16)
  ReconstructionPixelSpacing = int('00189322', 16)
  ExposureModulationType = int('00189323', 16)
  EstimatedDoseSaving = int('00189324', 16)
  CTXRayDetailsSequence = int('00189325', 16)
  CTPositionSequence = int('00189326', 16)
  TablePosition = int('00189327', 16)
  ExposureTimeinms = int('00189328', 16)
  CTImageFrameTypeSequence = int('00189329', 16)
  XRayTubeCurrentinmA = int('00189330', 16)
  ExposureinmAs = int('00189332', 16)
  ConstantVolumeFlag = int('00189333', 16)
  FluoroscopyFlag = int('00189334', 16)
  DistanceSourcetoDataCollectionCenter = int('00189335', 16)
  ContrastBolusAgentNumber = int('00189337', 16)
  ContrastBolusIngredientCodeSequence = int('00189338', 16)
  ContrastAdministrationProfileSequence = int('00189340', 16)
  ContrastBolusUsageSequence = int('00189341', 16)
  ContrastBolusAgentAdministered = int('00189342', 16)
  ContrastBolusAgentDetected = int('00189343', 16)
  ContrastBolusAgentPhase = int('00189344', 16)
  CTDIvol = int('00189345', 16)
  CTDIPhantomTypeCodeSequence = int('00189346', 16)
  CalciumScoringMassFactorPatient = int('00189351', 16)
  CalciumScoringMassFactorDevice = int('00189352', 16)
  EnergyWeightingFactor = int('00189353', 16)
  CTAdditionalXRaySourceSequence = int('00189360', 16)
  ProjectionPixelCalibrationSequence = int('00189401', 16)
  DistanceSourcetoIsocenter = int('00189402', 16)
  DistanceObjecttoTableTop = int('00189403', 16)
  ObjectPixelSpacinginCenterofBeam = int('00189404', 16)
  PositionerPositionSequence = int('00189405', 16)
  TablePositionSequence = int('00189406', 16)
  CollimatorShapeSequence = int('00189407', 16)
  PlanesinAcquisition = int('00189410', 16)
  XAXRFFrameCharacteristicsSequence = int('00189412', 16)
  FrameAcquisitionSequence = int('00189417', 16)
  XRayReceptorType = int('00189420', 16)
  AcquisitionProtocolName = int('00189423', 16)
  AcquisitionProtocolDescription = int('00189424', 16)
  ContrastBolusIngredientOpaque = int('00189425', 16)
  DistanceReceptorPlanetoDetectorHousing = int('00189426', 16)
  IntensifierActiveShape = int('00189427', 16)
  IntensifierActiveDimensions = int('00189428', 16)
  PhysicalDetectorSize = int('00189429', 16)
  PositionofIsocenterProjection = int('00189430', 16)
  FieldofViewSequence = int('00189432', 16)
  FieldofViewDescription = int('00189433', 16)
  ExposureControlSensingRegionsSequence = int('00189434', 16)
  ExposureControlSensingRegionShape = int('00189435', 16)
  ExposureControlSensingRegionLeftVerticalEdge = int('00189436', 16)
  ExposureControlSensingRegionRightVerticalEdge = int('00189437', 16)
  ExposureControlSensingRegionUpperHorizontalEdge = int('00189438', 16)
  ExposureControlSensingRegionLowerHorizontalEdge = int('00189439', 16)
  CenterofCircularExposureControlSensingRegion = int('00189440', 16)
  RadiusofCircularExposureControlSensingRegion = int('00189441', 16)
  VerticesofthePolygonalExposureControlSensingRegion = int('00189442', 16)
  ColumnAngulationPatient = int('00189447', 16)
  BeamAngle = int('00189449', 16)
  FrameDetectorParametersSequence = int('00189451', 16)
  CalculatedAnatomyThickness = int('00189452', 16)
  CalibrationSequence = int('00189455', 16)
  ObjectThicknessSequence = int('00189456', 16)
  PlaneIdentification = int('00189457', 16)
  FieldofViewDimensionsinFloat = int('00189461', 16)
  IsocenterReferenceSystemSequence = int('00189462', 16)
  PositionerIsocenterPrimaryAngle = int('00189463', 16)
  PositionerIsocenterSecondaryAngle = int('00189464', 16)
  PositionerIsocenterDetectorRotationAngle = int('00189465', 16)
  TableXPositiontoIsocenter = int('00189466', 16)
  TableYPositiontoIsocenter = int('00189467', 16)
  TableZPositiontoIsocenter = int('00189468', 16)
  TableHorizontalRotationAngle = int('00189469', 16)
  TableHeadTiltAngle = int('00189470', 16)
  TableCradleTiltAngle = int('00189471', 16)
  FrameDisplayShutterSequence = int('00189472', 16)
  AcquiredImageAreaDoseProduct = int('00189473', 16)
  CarmPositionerTabletopRelationship = int('00189474', 16)
  XRayGeometrySequence = int('00189476', 16)
  IrradiationEventIdentificationSequence = int('00189477', 16)
  XRay3DFrameTypeSequence = int('00189504', 16)
  ContributingSourcesSequence = int('00189506', 16)
  XRay3DAcquisitionSequence = int('00189507', 16)
  PrimaryPositionerScanArc = int('00189508', 16)
  SecondaryPositionerScanArc = int('00189509', 16)
  PrimaryPositionerScanStartAngle = int('00189510', 16)
  SecondaryPositionerScanStartAngle = int('00189511', 16)
  PrimaryPositionerIncrement = int('00189514', 16)
  SecondaryPositionerIncrement = int('00189515', 16)
  StartAcquisitionDateTime = int('00189516', 16)
  EndAcquisitionDateTime = int('00189517', 16)
  PrimaryPositionerIncrementSign = int('00189518', 16)
  SecondaryPositionerIncrementSign = int('00189519', 16)
  ApplicationName = int('00189524', 16)
  ApplicationVersion = int('00189525', 16)
  ApplicationManufacturer = int('00189526', 16)
  AlgorithmType = int('00189527', 16)
  AlgorithmDescription = int('00189528', 16)
  XRay3DReconstructionSequence = int('00189530', 16)
  ReconstructionDescription = int('00189531', 16)
  PerProjectionAcquisitionSequence = int('00189538', 16)
  DetectorPositionSequence = int('00189541', 16)
  XRayAcquisitionDoseSequence = int('00189542', 16)
  XRaySourceIsocenterPrimaryAngle = int('00189543', 16)
  XRaySourceIsocenterSecondaryAngle = int('00189544', 16)
  BreastSupportIsocenterPrimaryAngle = int('00189545', 16)
  BreastSupportIsocenterSecondaryAngle = int('00189546', 16)
  BreastSupportXPositiontoIsocenter = int('00189547', 16)
  BreastSupportYPositiontoIsocenter = int('00189548', 16)
  BreastSupportZPositiontoIsocenter = int('00189549', 16)
  DetectorIsocenterPrimaryAngle = int('00189550', 16)
  DetectorIsocenterSecondaryAngle = int('00189551', 16)
  DetectorXPositiontoIsocenter = int('00189552', 16)
  DetectorYPositiontoIsocenter = int('00189553', 16)
  DetectorZPositiontoIsocenter = int('00189554', 16)
  XRayGridSequence = int('00189555', 16)
  XRayFilterSequence = int('00189556', 16)
  DetectorActiveAreaTLHCPosition = int('00189557', 16)
  DetectorActiveAreaOrientation = int('00189558', 16)
  PositionerPrimaryAngleDirection = int('00189559', 16)
  DiffusionbmatrixSequence = int('00189601', 16)
  DiffusionbvalueXX = int('00189602', 16)
  DiffusionbvalueXY = int('00189603', 16)
  DiffusionbvalueXZ = int('00189604', 16)
  DiffusionbvalueYY = int('00189605', 16)
  DiffusionbvalueYZ = int('00189606', 16)
  DiffusionbvalueZZ = int('00189607', 16)
  FunctionalMRSequence = int('00189621', 16)
  FunctionalSettlingPhaseFramesPresent = int('00189622', 16)
  FunctionalSyncPulse = int('00189623', 16)
  SettlingPhaseFrame = int('00189624', 16)
  DecayCorrectionDateTime = int('00189701', 16)
  StartDensityThreshold = int('00189715', 16)
  StartRelativeDensityDifferenceThreshold = int('00189716', 16)
  StartCardiacTriggerCountThreshold = int('00189717', 16)
  StartRespiratoryTriggerCountThreshold = int('00189718', 16)
  TerminationCountsThreshold = int('00189719', 16)
  TerminationDensityThreshold = int('00189720', 16)
  TerminationRelativeDensityThreshold = int('00189721', 16)
  TerminationTimeThreshold = int('00189722', 16)
  TerminationCardiacTriggerCountThreshold = int('00189723', 16)
  TerminationRespiratoryTriggerCountThreshold = int('00189724', 16)
  DetectorGeometry = int('00189725', 16)
  TransverseDetectorSeparation = int('00189726', 16)
  AxialDetectorDimension = int('00189727', 16)
  RadiopharmaceuticalAgentNumber = int('00189729', 16)
  PETFrameAcquisitionSequence = int('00189732', 16)
  PETDetectorMotionDetailsSequence = int('00189733', 16)
  PETTableDynamicsSequence = int('00189734', 16)
  PETPositionSequence = int('00189735', 16)
  PETFrameCorrectionFactorsSequence = int('00189736', 16)
  RadiopharmaceuticalUsageSequence = int('00189737', 16)
  AttenuationCorrectionSource = int('00189738', 16)
  NumberofIterations = int('00189739', 16)
  NumberofSubsets = int('00189740', 16)
  PETReconstructionSequence = int('00189749', 16)
  PETFrameTypeSequence = int('00189751', 16)
  TimeofFlightInformationUsed = int('00189755', 16)
  ReconstructionType = int('00189756', 16)
  DecayCorrected = int('00189758', 16)
  AttenuationCorrected = int('00189759', 16)
  ScatterCorrected = int('00189760', 16)
  DeadTimeCorrected = int('00189761', 16)
  GantryMotionCorrected = int('00189762', 16)
  PatientMotionCorrected = int('00189763', 16)
  CountLossNormalizationCorrected = int('00189764', 16)
  RandomsCorrected = int('00189765', 16)
  NonuniformRadialSamplingCorrected = int('00189766', 16)
  SensitivityCalibrated = int('00189767', 16)
  DetectorNormalizationCorrection = int('00189768', 16)
  IterativeReconstructionMethod = int('00189769', 16)
  AttenuationCorrectionTemporalRelationship = int('00189770', 16)
  PatientPhysiologicalStateSequence = int('00189771', 16)
  PatientPhysiologicalStateCodeSequence = int('00189772', 16)
  DepthsofFocus = int('00189801', 16)
  ExcludedIntervalsSequence = int('00189803', 16)
  ExclusionStartDateTime = int('00189804', 16)
  ExclusionDuration = int('00189805', 16)
  USImageDescriptionSequence = int('00189806', 16)
  ImageDataTypeSequence = int('00189807', 16)
  DataType = int('00189808', 16)
  TransducerScanPatternCodeSequence = int('00189809', 16)
  AliasedDataType = int('0018980B', 16)
  PositionMeasuringDeviceUsed = int('0018980C', 16)
  TransducerGeometryCodeSequence = int('0018980D', 16)
  TransducerBeamSteeringCodeSequence = int('0018980E', 16)
  TransducerApplicationCodeSequence = int('0018980F', 16)
  ZeroVelocityPixelValue = int('00189810', 16)
  ContributingEquipmentSequence = int('0018A001', 16)
  ContributionDateTime = int('0018A002', 16)
  ContributionDescription = int('0018A003', 16)
  StudyInstanceUID = int('0020000D', 16)
  SeriesInstanceUID = int('0020000E', 16)
  StudyID = int('00200010', 16)
  SeriesNumber = int('00200011', 16)
  AcquisitionNumber = int('00200012', 16)
  InstanceNumber = int('00200013', 16)
  IsotopeNumber = int('00200014', 16)
  PhaseNumber = int('00200015', 16)
  IntervalNumber = int('00200016', 16)
  TimeSlotNumber = int('00200017', 16)
  AngleNumber = int('00200018', 16)
  ItemNumber = int('00200019', 16)
  PatientOrientation = int('00200020', 16)
  OverlayNumber = int('00200022', 16)
  CurveNumber = int('00200024', 16)
  LUTNumber = int('00200026', 16)
  ImagePosition = int('00200030', 16)
  ImagePositionPatient = int('00200032', 16)
  ImageOrientation = int('00200035', 16)
  ImageOrientationPatient = int('00200037', 16)
  Location = int('00200050', 16)
  FrameofReferenceUID = int('00200052', 16)
  Laterality = int('00200060', 16)
  ImageLaterality = int('00200062', 16)
  ImageGeometryType = int('00200070', 16)
  MaskingImage = int('00200080', 16)
  ReportNumber = int('002000AA', 16)
  TemporalPositionIdentifier = int('00200100', 16)
  NumberofTemporalPositions = int('00200105', 16)
  TemporalResolution = int('00200110', 16)
  SynchronizationFrameofReferenceUID = int('00200200', 16)
  SOPInstanceUIDofConcatenationSource = int('00200242', 16)
  SeriesinStudy = int('00201000', 16)
  AcquisitionsinSeries = int('00201001', 16)
  ImagesinAcquisition = int('00201002', 16)
  ImagesinSeries = int('00201003', 16)
  AcquisitionsinStudy = int('00201004', 16)
  ImagesinStudy = int('00201005', 16)
  Reference = int('00201020', 16)
  PositionReferenceIndicator = int('00201040', 16)
  SliceLocation = int('00201041', 16)
  OtherStudyNumbers = int('00201070', 16)
  NumberofPatientRelatedStudies = int('00201200', 16)
  NumberofPatientRelatedSeries = int('00201202', 16)
  NumberofPatientRelatedInstances = int('00201204', 16)
  NumberofStudyRelatedSeries = int('00201206', 16)
  NumberofStudyRelatedInstances = int('00201208', 16)
  NumberofSeriesRelatedInstances = int('00201209', 16)
  ModifyingDeviceID = int('00203401', 16)
  ModifiedImageID = int('00203402', 16)
  ModifiedImageDate = int('00203403', 16)
  ModifyingDeviceManufacturer = int('00203404', 16)
  ModifiedImageTime = int('00203405', 16)
  ModifiedImageDescription = int('00203406', 16)
  ImageComments = int('00204000', 16)
  OriginalImageIdentification = int('00205000', 16)
  OriginalImageIdentificationNomenclature = int('00205002', 16)
  StackID = int('00209056', 16)
  InStackPositionNumber = int('00209057', 16)
  FrameAnatomySequence = int('00209071', 16)
  FrameLaterality = int('00209072', 16)
  FrameContentSequence = int('00209111', 16)
  PlanePositionSequence = int('00209113', 16)
  PlaneOrientationSequence = int('00209116', 16)
  TemporalPositionIndex = int('00209128', 16)
  NominalCardiacTriggerDelayTime = int('00209153', 16)
  NominalCardiacTriggerTimePriorToRPeak = int('00209154', 16)
  ActualCardiacTriggerTimePriorToRPeak = int('00209155', 16)
  FrameAcquisitionNumber = int('00209156', 16)
  DimensionIndexValues = int('00209157', 16)
  FrameComments = int('00209158', 16)
  ConcatenationUID = int('00209161', 16)
  InconcatenationNumber = int('00209162', 16)
  InconcatenationTotalNumber = int('00209163', 16)
  DimensionOrganizationUID = int('00209164', 16)
  DimensionIndexPointer = int('00209165', 16)
  FunctionalGroupPointer = int('00209167', 16)
  UnassignedSharedConvertedAttributesSequence = int('00209170', 16)
  UnassignedPerFrameConvertedAttributesSequence = int('00209171', 16)
  ConversionSourceAttributesSequence = int('00209172', 16)
  DimensionIndexPrivateCreator = int('00209213', 16)
  DimensionOrganizationSequence = int('00209221', 16)
  DimensionIndexSequence = int('00209222', 16)
  ConcatenationFrameOffsetNumber = int('00209228', 16)
  FunctionalGroupPrivateCreator = int('00209238', 16)
  NominalPercentageofCardiacPhase = int('00209241', 16)
  NominalPercentageofRespiratoryPhase = int('00209245', 16)
  StartingRespiratoryAmplitude = int('00209246', 16)
  StartingRespiratoryPhase = int('00209247', 16)
  EndingRespiratoryAmplitude = int('00209248', 16)
  EndingRespiratoryPhase = int('00209249', 16)
  RespiratoryTriggerType = int('00209250', 16)
  RRIntervalTimeNominal = int('00209251', 16)
  ActualCardiacTriggerDelayTime = int('00209252', 16)
  RespiratorySynchronizationSequence = int('00209253', 16)
  RespiratoryIntervalTime = int('00209254', 16)
  NominalRespiratoryTriggerDelayTime = int('00209255', 16)
  RespiratoryTriggerDelayThreshold = int('00209256', 16)
  ActualRespiratoryTriggerDelayTime = int('00209257', 16)
  ImagePositionVolume = int('00209301', 16)
  ImageOrientationVolume = int('00209302', 16)
  UltrasoundAcquisitionGeometry = int('00209307', 16)
  ApexPosition = int('00209308', 16)
  VolumetoTransducerMappingMatrix = int('00209309', 16)
  VolumetoTableMappingMatrix = int('0020930A', 16)
  VolumetoTransducerRelationship = int('0020930B', 16)
  PatientFrameofReferenceSource = int('0020930C', 16)
  TemporalPositionTimeOffset = int('0020930D', 16)
  PlanePositionVolumeSequence = int('0020930E', 16)
  PlaneOrientationVolumeSequence = int('0020930F', 16)
  TemporalPositionSequence = int('00209310', 16)
  DimensionOrganizationType = int('00209311', 16)
  VolumeFrameofReferenceUID = int('00209312', 16)
  TableFrameofReferenceUID = int('00209313', 16)
  DimensionDescriptionLabel = int('00209421', 16)
  PatientOrientationinFrameSequence = int('00209450', 16)
  FrameLabel = int('00209453', 16)
  AcquisitionIndex = int('00209518', 16)
  ContributingSOPInstancesReferenceSequence = int('00209529', 16)
  ReconstructionIndex = int('00209536', 16)
  LightPathFilterPassThroughWavelength = int('00220001', 16)
  LightPathFilterPassBand = int('00220002', 16)
  ImagePathFilterPassThroughWavelength = int('00220003', 16)
  ImagePathFilterPassBand = int('00220004', 16)
  PatientEyeMovementCommanded = int('00220005', 16)
  PatientEyeMovementCommandCodeSequence = int('00220006', 16)
  SphericalLensPower = int('00220007', 16)
  CylinderLensPower = int('00220008', 16)
  CylinderAxis = int('00220009', 16)
  EmmetropicMagnification = int('0022000A', 16)
  IntraOcularPressure = int('0022000B', 16)
  HorizontalFieldofView = int('0022000C', 16)
  PupilDilated = int('0022000D', 16)
  DegreeofDilation = int('0022000E', 16)
  StereoBaselineAngle = int('00220010', 16)
  StereoBaselineDisplacement = int('00220011', 16)
  StereoHorizontalPixelOffset = int('00220012', 16)
  StereoVerticalPixelOffset = int('00220013', 16)
  StereoRotation = int('00220014', 16)
  AcquisitionDeviceTypeCodeSequence = int('00220015', 16)
  IlluminationTypeCodeSequence = int('00220016', 16)
  LightPathFilterTypeStackCodeSequence = int('00220017', 16)
  ImagePathFilterTypeStackCodeSequence = int('00220018', 16)
  LensesCodeSequence = int('00220019', 16)
  ChannelDescriptionCodeSequence = int('0022001A', 16)
  RefractiveStateSequence = int('0022001B', 16)
  MydriaticAgentCodeSequence = int('0022001C', 16)
  RelativeImagePositionCodeSequence = int('0022001D', 16)
  CameraAngleofView = int('0022001E', 16)
  StereoPairsSequence = int('00220020', 16)
  LeftImageSequence = int('00220021', 16)
  RightImageSequence = int('00220022', 16)
  StereoPairsPresent = int('00220028', 16)
  AxialLengthoftheEye = int('00220030', 16)
  OphthalmicFrameLocationSequence = int('00220031', 16)
  ReferenceCoordinates = int('00220032', 16)
  DepthSpatialResolution = int('00220035', 16)
  MaximumDepthDistortion = int('00220036', 16)
  AlongscanSpatialResolution = int('00220037', 16)
  MaximumAlongscanDistortion = int('00220038', 16)
  OphthalmicImageOrientation = int('00220039', 16)
  DepthofTransverseImage = int('00220041', 16)
  MydriaticAgentConcentrationUnitsSequence = int('00220042', 16)
  AcrossscanSpatialResolution = int('00220048', 16)
  MaximumAcrossscanDistortion = int('00220049', 16)
  MydriaticAgentConcentration = int('0022004E', 16)
  IlluminationWaveLength = int('00220055', 16)
  IlluminationPower = int('00220056', 16)
  IlluminationBandwidth = int('00220057', 16)
  MydriaticAgentSequence = int('00220058', 16)
  OphthalmicAxialMeasurementsRightEyeSequence = int('00221007', 16)
  OphthalmicAxialMeasurementsLeftEyeSequence = int('00221008', 16)
  OphthalmicAxialMeasurementsDeviceType = int('00221009', 16)
  OphthalmicAxialLengthMeasurementsType = int('00221010', 16)
  OphthalmicAxialLengthSequence = int('00221012', 16)
  OphthalmicAxialLength = int('00221019', 16)
  LensStatusCodeSequence = int('00221024', 16)
  VitreousStatusCodeSequence = int('00221025', 16)
  IOLFormulaCodeSequence = int('00221028', 16)
  IOLFormulaDetail = int('00221029', 16)
  KeratometerIndex = int('00221033', 16)
  SourceofOphthalmicAxialLengthCodeSequence = int('00221035', 16)
  TargetRefraction = int('00221037', 16)
  RefractiveProcedureOccurred = int('00221039', 16)
  RefractiveSurgeryTypeCodeSequence = int('00221040', 16)
  OphthalmicUltrasoundMethodCodeSequence = int('00221044', 16)
  OphthalmicAxialLengthMeasurementsSequence = int('00221050', 16)
  IOLPower = int('00221053', 16)
  PredictedRefractiveError = int('00221054', 16)
  OphthalmicAxialLengthVelocity = int('00221059', 16)
  LensStatusDescription = int('00221065', 16)
  VitreousStatusDescription = int('00221066', 16)
  IOLPowerSequence = int('00221090', 16)
  LensConstantSequence = int('00221092', 16)
  IOLManufacturer = int('00221093', 16)
  LensConstantDescription = int('00221094', 16)
  ImplantName = int('00221095', 16)
  KeratometryMeasurementTypeCodeSequence = int('00221096', 16)
  ImplantPartNumber = int('00221097', 16)
  ReferencedOphthalmicAxialMeasurementsSequence = int('00221100', 16)
  OphthalmicAxialLengthMeasurementsSegmentNameCodeSequence = int(
      '00221101', 16)
  RefractiveErrorBeforeRefractiveSurgeryCodeSequence = int('00221103', 16)
  IOLPowerForExactEmmetropia = int('00221121', 16)
  IOLPowerForExactTargetRefraction = int('00221122', 16)
  AnteriorChamberDepthDefinitionCodeSequence = int('00221125', 16)
  LensThicknessSequence = int('00221127', 16)
  AnteriorChamberDepthSequence = int('00221128', 16)
  LensThickness = int('00221130', 16)
  AnteriorChamberDepth = int('00221131', 16)
  SourceofLensThicknessDataCodeSequence = int('00221132', 16)
  SourceofAnteriorChamberDepthDataCodeSequence = int('00221133', 16)
  SourceofRefractiveMeasurementsSequence = int('00221134', 16)
  SourceofRefractiveMeasurementsCodeSequence = int('00221135', 16)
  OphthalmicAxialLengthMeasurementModified = int('00221140', 16)
  OphthalmicAxialLengthDataSourceCodeSequence = int('00221150', 16)
  OphthalmicAxialLengthAcquisitionMethodCodeSequence = int('00221153', 16)
  SignaltoNoiseRatio = int('00221155', 16)
  OphthalmicAxialLengthDataSourceDescription = int('00221159', 16)
  OphthalmicAxialLengthMeasurementsTotalLengthSequence = int('00221210', 16)
  OphthalmicAxialLengthMeasurementsSegmentalLengthSequence = int(
      '00221211', 16)
  OphthalmicAxialLengthMeasurementsLengthSummationSequence = int(
      '00221212', 16)
  UltrasoundOphthalmicAxialLengthMeasurementsSequence = int('00221220', 16)
  OpticalOphthalmicAxialLengthMeasurementsSequence = int('00221225', 16)
  UltrasoundSelectedOphthalmicAxialLengthSequence = int('00221230', 16)
  OphthalmicAxialLengthSelectionMethodCodeSequence = int('00221250', 16)
  OpticalSelectedOphthalmicAxialLengthSequence = int('00221255', 16)
  SelectedSegmentalOphthalmicAxialLengthSequence = int('00221257', 16)
  SelectedTotalOphthalmicAxialLengthSequence = int('00221260', 16)
  OphthalmicAxialLengthQualityMetricSequence = int('00221262', 16)
  OphthalmicAxialLengthQualityMetricTypeCodeSequence = int('00221265', 16)
  OphthalmicAxialLengthQualityMetricTypeDescription = int('00221273', 16)
  IntraocularLensCalculationsRightEyeSequence = int('00221300', 16)
  IntraocularLensCalculationsLeftEyeSequence = int('00221310', 16)
  ReferencedOphthalmicAxialLengthMeasurementQCImageSequence = int(
      '00221330', 16)
  OphthalmicMappingDeviceType = int('00221415', 16)
  AcquisitionMethodCodeSequence = int('00221420', 16)
  AcquisitionMethodAlgorithmSequence = int('00221423', 16)
  OphthalmicThicknessMapTypeCodeSequence = int('00221436', 16)
  OphthalmicThicknessMappingNormalsSequence = int('00221443', 16)
  RetinalThicknessDefinitionCodeSequence = int('00221445', 16)
  PixelValueMappingtoCodedConceptSequence = int('00221450', 16)
  MappedPixelValue = int('00221452', 16)
  PixelValueMappingExplanation = int('00221454', 16)
  OphthalmicThicknessMapQualityThresholdSequence = int('00221458', 16)
  OphthalmicThicknessMapThresholdQualityRating = int('00221460', 16)
  AnatomicStructureReferencePoint = int('00221463', 16)
  RegistrationtoLocalizerSequence = int('00221465', 16)
  RegisteredLocalizerUnits = int('00221466', 16)
  RegisteredLocalizerTopLeftHandCorner = int('00221467', 16)
  RegisteredLocalizerBottomRightHandCorner = int('00221468', 16)
  OphthalmicThicknessMapQualityRatingSequence = int('00221470', 16)
  RelevantOPTAttributesSequence = int('00221472', 16)
  TransformationMethodCodeSequence = int('00221512', 16)
  TransformationAlgorithmSequence = int('00221513', 16)
  OphthalmicAxialLengthMethod = int('00221515', 16)
  OphthalmicFOV = int('00221517', 16)
  TwoDimensionaltoThreeDimensionalMapSequence = int('00221518', 16)
  WideFieldOphthalmicPhotographyQualityRatingSequence = int('00221525', 16)
  WideFieldOphthalmicPhotographyQualityThresholdSequence = int(
      '00221526', 16)
  WideFieldOphthalmicPhotographyThresholdQualityRating = int('00221527', 16)
  XCoordinatesCenterPixelViewAngle = int('00221528', 16)
  YCoordinatesCenterPixelViewAngle = int('00221529', 16)
  NumberofMapPoints = int('00221530', 16)
  TwoDimensionaltoThreeDimensionalMapData = int('00221531', 16)
  VisualFieldHorizontalExtent = int('00240010', 16)
  VisualFieldVerticalExtent = int('00240011', 16)
  VisualFieldShape = int('00240012', 16)
  ScreeningTestModeCodeSequence = int('00240016', 16)
  MaximumStimulusLuminance = int('00240018', 16)
  BackgroundLuminance = int('00240020', 16)
  StimulusColorCodeSequence = int('00240021', 16)
  BackgroundIlluminationColorCodeSequence = int('00240024', 16)
  StimulusArea = int('00240025', 16)
  StimulusPresentationTime = int('00240028', 16)
  FixationSequence = int('00240032', 16)
  FixationMonitoringCodeSequence = int('00240033', 16)
  VisualFieldCatchTrialSequence = int('00240034', 16)
  FixationCheckedQuantity = int('00240035', 16)
  PatientNotProperlyFixatedQuantity = int('00240036', 16)
  PresentedVisualStimuliDataFlag = int('00240037', 16)
  NumberofVisualStimuli = int('00240038', 16)
  ExcessiveFixationLossesDataFlag = int('00240039', 16)
  ExcessiveFixationLosses = int('00240040', 16)
  StimuliRetestingQuantity = int('00240042', 16)
  CommentsonPatientsPerformanceofVisualField = int('00240044', 16)
  FalseNegativesEstimateFlag = int('00240045', 16)
  FalseNegativesEstimate = int('00240046', 16)
  NegativeCatchTrialsQuantity = int('00240048', 16)
  FalseNegativesQuantity = int('00240050', 16)
  ExcessiveFalseNegativesDataFlag = int('00240051', 16)
  ExcessiveFalseNegatives = int('00240052', 16)
  FalsePositivesEstimateFlag = int('00240053', 16)
  FalsePositivesEstimate = int('00240054', 16)
  CatchTrialsDataFlag = int('00240055', 16)
  PositiveCatchTrialsQuantity = int('00240056', 16)
  TestPointNormalsDataFlag = int('00240057', 16)
  TestPointNormalsSequence = int('00240058', 16)
  GlobalDeviationProbabilityNormalsFlag = int('00240059', 16)
  FalsePositivesQuantity = int('00240060', 16)
  ExcessiveFalsePositivesDataFlag = int('00240061', 16)
  ExcessiveFalsePositives = int('00240062', 16)
  VisualFieldTestNormalsFlag = int('00240063', 16)
  ResultsNormalsSequence = int('00240064', 16)
  AgeCorrectedSensitivityDeviationAlgorithmSequence = int('00240065', 16)
  GlobalDeviationFromNormal = int('00240066', 16)
  GeneralizedDefectSensitivityDeviationAlgorithmSequence = int(
      '00240067', 16)
  LocalizedDeviationFromNormal = int('00240068', 16)
  PatientReliabilityIndicator = int('00240069', 16)
  VisualFieldMeanSensitivity = int('00240070', 16)
  GlobalDeviationProbability = int('00240071', 16)
  LocalDeviationProbabilityNormalsFlag = int('00240072', 16)
  LocalizedDeviationProbability = int('00240073', 16)
  ShortTermFluctuationCalculated = int('00240074', 16)
  ShortTermFluctuation = int('00240075', 16)
  ShortTermFluctuationProbabilityCalculated = int('00240076', 16)
  ShortTermFluctuationProbability = int('00240077', 16)
  CorrectedLocalizedDeviationFromNormalCalculated = int('00240078', 16)
  CorrectedLocalizedDeviationFromNormal = int('00240079', 16)
  CorrectedLocalizedDeviationFromNormalProbabilityCalculated = int(
      '00240080', 16)
  CorrectedLocalizedDeviationFromNormalProbability = int('00240081', 16)
  GlobalDeviationProbabilitySequence = int('00240083', 16)
  LocalizedDeviationProbabilitySequence = int('00240085', 16)
  FovealSensitivityMeasured = int('00240086', 16)
  FovealSensitivity = int('00240087', 16)
  VisualFieldTestDuration = int('00240088', 16)
  VisualFieldTestPointSequence = int('00240089', 16)
  VisualFieldTestPointXCoordinate = int('00240090', 16)
  VisualFieldTestPointYCoordinate = int('00240091', 16)
  AgeCorrectedSensitivityDeviationValue = int('00240092', 16)
  StimulusResults = int('00240093', 16)
  SensitivityValue = int('00240094', 16)
  RetestStimulusSeen = int('00240095', 16)
  RetestSensitivityValue = int('00240096', 16)
  VisualFieldTestPointNormalsSequence = int('00240097', 16)
  QuantifiedDefect = int('00240098', 16)
  AgeCorrectedSensitivityDeviationProbabilityValue = int('00240100', 16)
  GeneralizedDefectCorrectedSensitivityDeviationFlag = int('00240102', 16)
  GeneralizedDefectCorrectedSensitivityDeviationValue = int('00240103', 16)
  GeneralizedDefectCorrectedSensitivityDeviationProbabilityValue = int(
      '00240104', 16)
  MinimumSensitivityValue = int('00240105', 16)
  BlindSpotLocalized = int('00240106', 16)
  BlindSpotXCoordinate = int('00240107', 16)
  BlindSpotYCoordinate = int('00240108', 16)
  VisualAcuityMeasurementSequence = int('00240110', 16)
  RefractiveParametersUsedonPatientSequence = int('00240112', 16)
  MeasurementLaterality = int('00240113', 16)
  OphthalmicPatientClinicalInformationLeftEyeSequence = int('00240114', 16)
  OphthalmicPatientClinicalInformationRightEyeSequence = int('00240115', 16)
  FovealPointNormativeDataFlag = int('00240117', 16)
  FovealPointProbabilityValue = int('00240118', 16)
  ScreeningBaselineMeasured = int('00240120', 16)
  ScreeningBaselineMeasuredSequence = int('00240122', 16)
  ScreeningBaselineType = int('00240124', 16)
  ScreeningBaselineValue = int('00240126', 16)
  AlgorithmSource = int('00240202', 16)
  DataSetName = int('00240306', 16)
  DataSetVersion = int('00240307', 16)
  DataSetSource = int('00240308', 16)
  DataSetDescription = int('00240309', 16)
  VisualFieldTestReliabilityGlobalIndexSequence = int('00240317', 16)
  VisualFieldGlobalResultsIndexSequence = int('00240320', 16)
  DataObservationSequence = int('00240325', 16)
  IndexNormalsFlag = int('00240338', 16)
  IndexProbability = int('00240341', 16)
  IndexProbabilitySequence = int('00240344', 16)
  SamplesperPixel = int('00280002', 16)
  SamplesperPixelUsed = int('00280003', 16)
  PhotometricInterpretation = int('00280004', 16)
  ImageDimensions = int('00280005', 16)
  PlanarConfiguration = int('00280006', 16)
  NumberofFrames = int('00280008', 16)
  FrameIncrementPointer = int('00280009', 16)
  FrameDimensionPointer = int('0028000A', 16)
  Rows = int('00280010', 16)
  Columns = int('00280011', 16)
  Planes = int('00280012', 16)
  UltrasoundColorDataPresent = int('00280014', 16)
  PixelSpacing = int('00280030', 16)
  ZoomFactor = int('00280031', 16)
  ZoomCenter = int('00280032', 16)
  PixelAspectRatio = int('00280034', 16)
  ImageFormat = int('00280040', 16)
  ManipulatedImage = int('00280050', 16)
  CorrectedImage = int('00280051', 16)
  CompressionRecognitionCode = int('0028005F', 16)
  CompressionCode = int('00280060', 16)
  CompressionOriginator = int('00280061', 16)
  CompressionLabel = int('00280062', 16)
  CompressionDescription = int('00280063', 16)
  CompressionSequence = int('00280065', 16)
  CompressionStepPointers = int('00280066', 16)
  RepeatInterval = int('00280068', 16)
  BitsGrouped = int('00280069', 16)
  PerimeterTable = int('00280070', 16)
  PerimeterValue = int('00280071', 16)
  PredictorRows = int('00280080', 16)
  PredictorColumns = int('00280081', 16)
  PredictorConstants = int('00280082', 16)
  BlockedPixels = int('00280090', 16)
  BlockRows = int('00280091', 16)
  BlockColumns = int('00280092', 16)
  RowOverlap = int('00280093', 16)
  ColumnOverlap = int('00280094', 16)
  BitsAllocated = int('00280100', 16)
  BitsStored = int('00280101', 16)
  HighBit = int('00280102', 16)
  PixelRepresentation = int('00280103', 16)
  SmallestValidPixelValue = int('00280104', 16)
  LargestValidPixelValue = int('00280105', 16)
  SmallestImagePixelValue = int('00280106', 16)
  LargestImagePixelValue = int('00280107', 16)
  SmallestPixelValueinSeries = int('00280108', 16)
  LargestPixelValueinSeries = int('00280109', 16)
  SmallestImagePixelValueinPlane = int('00280110', 16)
  LargestImagePixelValueinPlane = int('00280111', 16)
  PixelPaddingValue = int('00280120', 16)
  PixelPaddingRangeLimit = int('00280121', 16)
  FloatPixelPaddingValue = int('00280122', 16)
  DoubleFloatPixelPaddingValue = int('00280123', 16)
  FloatPixelPaddingRangeLimit = int('00280124', 16)
  DoubleFloatPixelPaddingRangeLimit = int('00280125', 16)
  ImageLocation = int('00280200', 16)
  QualityControlImage = int('00280300', 16)
  BurnedInAnnotation = int('00280301', 16)
  RecognizableVisualFeatures = int('00280302', 16)
  LongitudinalTemporalInformationModified = int('00280303', 16)
  ReferencedColorPaletteInstanceUID = int('00280304', 16)
  TransformLabel = int('00280400', 16)
  TransformVersionNumber = int('00280401', 16)
  NumberofTransformSteps = int('00280402', 16)
  SequenceofCompressedData = int('00280403', 16)
  DetailsofCoefficients = int('00280404', 16)
  DCTLabel = int('00280700', 16)
  DataBlockDescription = int('00280701', 16)
  DataBlock = int('00280702', 16)
  NormalizationFactorFormat = int('00280710', 16)
  ZonalMapNumberFormat = int('00280720', 16)
  ZonalMapLocation = int('00280721', 16)
  ZonalMapFormat = int('00280722', 16)
  AdaptiveMapFormat = int('00280730', 16)
  CodeNumberFormat = int('00280740', 16)
  PixelSpacingCalibrationType = int('00280A02', 16)
  PixelSpacingCalibrationDescription = int('00280A04', 16)
  PixelIntensityRelationship = int('00281040', 16)
  PixelIntensityRelationshipSign = int('00281041', 16)
  WindowCenter = int('00281050', 16)
  WindowWidth = int('00281051', 16)
  RescaleIntercept = int('00281052', 16)
  RescaleSlope = int('00281053', 16)
  RescaleType = int('00281054', 16)
  WindowCenterWidthExplanation = int('00281055', 16)
  VOILUTFunction = int('00281056', 16)
  GrayScale = int('00281080', 16)
  RecommendedViewingMode = int('00281090', 16)
  GrayLookupTableDescriptor = int('00281100', 16)
  RedPaletteColorLookupTableDescriptor = int('00281101', 16)
  GreenPaletteColorLookupTableDescriptor = int('00281102', 16)
  BluePaletteColorLookupTableDescriptor = int('00281103', 16)
  AlphaPaletteColorLookupTableDescriptor = int('00281104', 16)
  LargeRedPaletteColorLookupTableDescriptor = int('00281111', 16)
  LargeGreenPaletteColorLookupTableDescriptor = int('00281112', 16)
  LargeBluePaletteColorLookupTableDescriptor = int('00281113', 16)
  PaletteColorLookupTableUID = int('00281199', 16)
  GrayLookupTableData = int('00281200', 16)
  RedPaletteColorLookupTableData = int('00281201', 16)
  GreenPaletteColorLookupTableData = int('00281202', 16)
  BluePaletteColorLookupTableData = int('00281203', 16)
  AlphaPaletteColorLookupTableData = int('00281204', 16)
  LargeRedPaletteColorLookupTableData = int('00281211', 16)
  LargeGreenPaletteColorLookupTableData = int('00281212', 16)
  LargeBluePaletteColorLookupTableData = int('00281213', 16)
  LargePaletteColorLookupTableUID = int('00281214', 16)
  SegmentedRedPaletteColorLookupTableData = int('00281221', 16)
  SegmentedGreenPaletteColorLookupTableData = int('00281222', 16)
  SegmentedBluePaletteColorLookupTableData = int('00281223', 16)
  SegmentedAlphaPaletteColorLookupTableData = int('00281224', 16)
  BreastImplantPresent = int('00281300', 16)
  PartialView = int('00281350', 16)
  PartialViewDescription = int('00281351', 16)
  PartialViewCodeSequence = int('00281352', 16)
  SpatialLocationsPreserved = int('0028135A', 16)
  DataFrameAssignmentSequence = int('00281401', 16)
  DataPathAssignment = int('00281402', 16)
  BitsMappedtoColorLookupTable = int('00281403', 16)
  BlendingLUT1Sequence = int('00281404', 16)
  BlendingLUT1TransferFunction = int('00281405', 16)
  BlendingWeightConstant = int('00281406', 16)
  BlendingLookupTableDescriptor = int('00281407', 16)
  BlendingLookupTableData = int('00281408', 16)
  EnhancedPaletteColorLookupTableSequence = int('0028140B', 16)
  BlendingLUT2Sequence = int('0028140C', 16)
  BlendingLUT2TransferFunction = int('0028140D', 16)
  DataPathID = int('0028140E', 16)
  RGBLUTTransferFunction = int('0028140F', 16)
  AlphaLUTTransferFunction = int('00281410', 16)
  ICCProfile = int('00282000', 16)
  ColorSpace = int('00282002', 16)
  LossyImageCompression = int('00282110', 16)
  LossyImageCompressionRatio = int('00282112', 16)
  LossyImageCompressionMethod = int('00282114', 16)
  ModalityLUTSequence = int('00283000', 16)
  LUTDescriptor = int('00283002', 16)
  LUTExplanation = int('00283003', 16)
  ModalityLUTType = int('00283004', 16)
  LUTData = int('00283006', 16)
  VOILUTSequence = int('00283010', 16)
  SoftcopyVOILUTSequence = int('00283110', 16)
  ImagePresentationComments = int('00284000', 16)
  BiPlaneAcquisitionSequence = int('00285000', 16)
  RepresentativeFrameNumber = int('00286010', 16)
  FrameNumbersofInterestFOI = int('00286020', 16)
  FrameofInterestDescription = int('00286022', 16)
  FrameofInterestType = int('00286023', 16)
  MaskPointers = int('00286030', 16)
  RWavePointer = int('00286040', 16)
  MaskSubtractionSequence = int('00286100', 16)
  MaskOperation = int('00286101', 16)
  ApplicableFrameRange = int('00286102', 16)
  MaskFrameNumbers = int('00286110', 16)
  ContrastFrameAveraging = int('00286112', 16)
  MaskSubpixelShift = int('00286114', 16)
  TIDOffset = int('00286120', 16)
  MaskOperationExplanation = int('00286190', 16)
  EquipmentAdministratorSequence = int('00287000', 16)
  NumberofDisplaySubsystems = int('00287001', 16)
  CurrentConfigurationID = int('00287002', 16)
  DisplaySubsystemID = int('00287003', 16)
  DisplaySubsystemName = int('00287004', 16)
  DisplaySubsystemDescription = int('00287005', 16)
  SystemStatus = int('00287006', 16)
  SystemStatusComment = int('00287007', 16)
  TargetLuminanceCharacteristicsSequence = int('00287008', 16)
  LuminanceCharacteristicsID = int('00287009', 16)
  DisplaySubsystemConfigurationSequence = int('0028700A', 16)
  ConfigurationID = int('0028700B', 16)
  ConfigurationName = int('0028700C', 16)
  ConfigurationDescription = int('0028700D', 16)
  ReferencedTargetLuminanceCharacteristicsID = int('0028700E', 16)
  QAResultsSequence = int('0028700F', 16)
  DisplaySubsystemQAResultsSequence = int('00287010', 16)
  ConfigurationQAResultsSequence = int('00287011', 16)
  MeasurementEquipmentSequence = int('00287012', 16)
  MeasurementFunctions = int('00287013', 16)
  MeasurementEquipmentType = int('00287014', 16)
  VisualEvaluationResultSequence = int('00287015', 16)
  DisplayCalibrationResultSequence = int('00287016', 16)
  DDLValue = int('00287017', 16)
  CIExyWhitePoint = int('00287018', 16)
  DisplayFunctionType = int('00287019', 16)
  GammaValue = int('0028701A', 16)
  NumberofLuminancePoints = int('0028701B', 16)
  LuminanceResponseSequence = int('0028701C', 16)
  TargetMinimumLuminance = int('0028701D', 16)
  TargetMaximumLuminance = int('0028701E', 16)
  LuminanceValue = int('0028701F', 16)
  LuminanceResponseDescription = int('00287020', 16)
  WhitePointFlag = int('00287021', 16)
  DisplayDeviceTypeCodeSequence = int('00287022', 16)
  DisplaySubsystemSequence = int('00287023', 16)
  LuminanceResultSequence = int('00287024', 16)
  AmbientLightValueSource = int('00287025', 16)
  MeasuredCharacteristics = int('00287026', 16)
  LuminanceUniformityResultSequence = int('00287027', 16)
  VisualEvaluationTestSequence = int('00287028', 16)
  TestResult = int('00287029', 16)
  TestResultComment = int('0028702A', 16)
  TestImageValidation = int('0028702B', 16)
  TestPatternCodeSequence = int('0028702C', 16)
  MeasurementPatternCodeSequence = int('0028702D', 16)
  VisualEvaluationMethodCodeSequence = int('0028702E', 16)
  PixelDataProviderURL = int('00287FE0', 16)
  DataPointRows = int('00289001', 16)
  DataPointColumns = int('00289002', 16)
  SignalDomainColumns = int('00289003', 16)
  LargestMonochromePixelValue = int('00289099', 16)
  DataRepresentation = int('00289108', 16)
  PixelMeasuresSequence = int('00289110', 16)
  FrameVOILUTSequence = int('00289132', 16)
  PixelValueTransformationSequence = int('00289145', 16)
  SignalDomainRows = int('00289235', 16)
  DisplayFilterPercentage = int('00289411', 16)
  FramePixelShiftSequence = int('00289415', 16)
  SubtractionItemID = int('00289416', 16)
  PixelIntensityRelationshipLUTSequence = int('00289422', 16)
  FramePixelDataPropertiesSequence = int('00289443', 16)
  GeometricalProperties = int('00289444', 16)
  GeometricMaximumDistortion = int('00289445', 16)
  ImageProcessingApplied = int('00289446', 16)
  MaskSelectionMode = int('00289454', 16)
  LUTFunction = int('00289474', 16)
  MaskVisibilityPercentage = int('00289478', 16)
  PixelShiftSequence = int('00289501', 16)
  RegionPixelShiftSequence = int('00289502', 16)
  VerticesoftheRegion = int('00289503', 16)
  MultiframePresentationSequence = int('00289505', 16)
  PixelShiftFrameRange = int('00289506', 16)
  LUTFrameRange = int('00289507', 16)
  ImagetoEquipmentMappingMatrix = int('00289520', 16)
  EquipmentCoordinateSystemIdentification = int('00289537', 16)
  StudyStatusID = int('0032000A', 16)
  StudyPriorityID = int('0032000C', 16)
  StudyIDIssuer = int('00320012', 16)
  StudyVerifiedDate = int('00320032', 16)
  StudyVerifiedTime = int('00320033', 16)
  StudyReadDate = int('00320034', 16)
  StudyReadTime = int('00320035', 16)
  ScheduledStudyStartDate = int('00321000', 16)
  ScheduledStudyStartTime = int('00321001', 16)
  ScheduledStudyStopDate = int('00321010', 16)
  ScheduledStudyStopTime = int('00321011', 16)
  ScheduledStudyLocation = int('00321020', 16)
  ScheduledStudyLocationAETitle = int('00321021', 16)
  ReasonforStudy = int('00321030', 16)
  RequestingPhysicianIdentificationSequence = int('00321031', 16)
  RequestingPhysician = int('00321032', 16)
  RequestingService = int('00321033', 16)
  RequestingServiceCodeSequence = int('00321034', 16)
  StudyArrivalDate = int('00321040', 16)
  StudyArrivalTime = int('00321041', 16)
  StudyCompletionDate = int('00321050', 16)
  StudyCompletionTime = int('00321051', 16)
  StudyComponentStatusID = int('00321055', 16)
  RequestedProcedureDescription = int('00321060', 16)
  RequestedProcedureCodeSequence = int('00321064', 16)
  RequestedContrastAgent = int('00321070', 16)
  StudyComments = int('00324000', 16)
  ReferencedPatientAliasSequence = int('00380004', 16)
  VisitStatusID = int('00380008', 16)
  AdmissionID = int('00380010', 16)
  IssuerofAdmissionID = int('00380011', 16)
  IssuerofAdmissionIDSequence = int('00380014', 16)
  RouteofAdmissions = int('00380016', 16)
  ScheduledAdmissionDate = int('0038001A', 16)
  ScheduledAdmissionTime = int('0038001B', 16)
  ScheduledDischargeDate = int('0038001C', 16)
  ScheduledDischargeTime = int('0038001D', 16)
  ScheduledPatientInstitutionResidence = int('0038001E', 16)
  AdmittingDate = int('00380020', 16)
  AdmittingTime = int('00380021', 16)
  DischargeDate = int('00380030', 16)
  DischargeTime = int('00380032', 16)
  DischargeDiagnosisDescription = int('00380040', 16)
  DischargeDiagnosisCodeSequence = int('00380044', 16)
  SpecialNeeds = int('00380050', 16)
  ServiceEpisodeID = int('00380060', 16)
  IssuerofServiceEpisodeID = int('00380061', 16)
  ServiceEpisodeDescription = int('00380062', 16)
  IssuerofServiceEpisodeIDSequence = int('00380064', 16)
  PertinentDocumentsSequence = int('00380100', 16)
  PertinentResourcesSequence = int('00380101', 16)
  ResourceDescription = int('00380102', 16)
  CurrentPatientLocation = int('00380300', 16)
  PatientsInstitutionResidence = int('00380400', 16)
  PatientState = int('00380500', 16)
  PatientClinicalTrialParticipationSequence = int('00380502', 16)
  VisitComments = int('00384000', 16)
  WaveformOriginality = int('003A0004', 16)
  NumberofWaveformChannels = int('003A0005', 16)
  NumberofWaveformSamples = int('003A0010', 16)
  SamplingFrequency = int('003A001A', 16)
  MultiplexGroupLabel = int('003A0020', 16)
  ChannelDefinitionSequence = int('003A0200', 16)
  WaveformChannelNumber = int('003A0202', 16)
  ChannelLabel = int('003A0203', 16)
  ChannelStatus = int('003A0205', 16)
  ChannelSourceSequence = int('003A0208', 16)
  ChannelSourceModifiersSequence = int('003A0209', 16)
  SourceWaveformSequence = int('003A020A', 16)
  ChannelDerivationDescription = int('003A020C', 16)
  ChannelSensitivity = int('003A0210', 16)
  ChannelSensitivityUnitsSequence = int('003A0211', 16)
  ChannelSensitivityCorrectionFactor = int('003A0212', 16)
  ChannelBaseline = int('003A0213', 16)
  ChannelTimeSkew = int('003A0214', 16)
  ChannelSampleSkew = int('003A0215', 16)
  ChannelOffset = int('003A0218', 16)
  WaveformBitsStored = int('003A021A', 16)
  FilterLowFrequency = int('003A0220', 16)
  FilterHighFrequency = int('003A0221', 16)
  NotchFilterFrequency = int('003A0222', 16)
  NotchFilterBandwidth = int('003A0223', 16)
  WaveformDataDisplayScale = int('003A0230', 16)
  WaveformDisplayBackgroundCIELabValue = int('003A0231', 16)
  WaveformPresentationGroupSequence = int('003A0240', 16)
  PresentationGroupNumber = int('003A0241', 16)
  ChannelDisplaySequence = int('003A0242', 16)
  ChannelRecommendedDisplayCIELabValue = int('003A0244', 16)
  ChannelPosition = int('003A0245', 16)
  DisplayShadingFlag = int('003A0246', 16)
  FractionalChannelDisplayScale = int('003A0247', 16)
  AbsoluteChannelDisplayScale = int('003A0248', 16)
  MultiplexedAudioChannelsDescriptionCodeSequence = int('003A0300', 16)
  ChannelIdentificationCode = int('003A0301', 16)
  ChannelMode = int('003A0302', 16)
  ScheduledStationAETitle = int('00400001', 16)
  ScheduledProcedureStepStartDate = int('00400002', 16)
  ScheduledProcedureStepStartTime = int('00400003', 16)
  ScheduledProcedureStepEndDate = int('00400004', 16)
  ScheduledProcedureStepEndTime = int('00400005', 16)
  ScheduledPerformingPhysiciansName = int('00400006', 16)
  ScheduledProcedureStepDescription = int('00400007', 16)
  ScheduledProtocolCodeSequence = int('00400008', 16)
  ScheduledProcedureStepID = int('00400009', 16)
  StageCodeSequence = int('0040000A', 16)
  ScheduledPerformingPhysicianIdentificationSequence = int('0040000B', 16)
  ScheduledStationName = int('00400010', 16)
  ScheduledProcedureStepLocation = int('00400011', 16)
  PreMedication = int('00400012', 16)
  ScheduledProcedureStepStatus = int('00400020', 16)
  OrderPlacerIdentifierSequence = int('00400026', 16)
  OrderFillerIdentifierSequence = int('00400027', 16)
  LocalNamespaceEntityID = int('00400031', 16)
  UniversalEntityID = int('00400032', 16)
  UniversalEntityIDType = int('00400033', 16)
  IdentifierTypeCode = int('00400035', 16)
  AssigningFacilitySequence = int('00400036', 16)
  AssigningJurisdictionCodeSequence = int('00400039', 16)
  AssigningAgencyorDepartmentCodeSequence = int('0040003A', 16)
  ScheduledProcedureStepSequence = int('00400100', 16)
  ReferencedNonImageCompositeSOPInstanceSequence = int('00400220', 16)
  PerformedStationAETitle = int('00400241', 16)
  PerformedStationName = int('00400242', 16)
  PerformedLocation = int('00400243', 16)
  PerformedProcedureStepStartDate = int('00400244', 16)
  PerformedProcedureStepStartTime = int('00400245', 16)
  PerformedProcedureStepEndDate = int('00400250', 16)
  PerformedProcedureStepEndTime = int('00400251', 16)
  PerformedProcedureStepStatus = int('00400252', 16)
  PerformedProcedureStepID = int('00400253', 16)
  PerformedProcedureStepDescription = int('00400254', 16)
  PerformedProcedureTypeDescription = int('00400255', 16)
  PerformedProtocolCodeSequence = int('00400260', 16)
  PerformedProtocolType = int('00400261', 16)
  ScheduledStepAttributesSequence = int('00400270', 16)
  RequestAttributesSequence = int('00400275', 16)
  CommentsonthePerformedProcedureStep = int('00400280', 16)
  PerformedProcedureStepDiscontinuationReasonCodeSequence = int(
      '00400281', 16)
  QuantitySequence = int('00400293', 16)
  Quantity = int('00400294', 16)
  MeasuringUnitsSequence = int('00400295', 16)
  BillingItemSequence = int('00400296', 16)
  TotalTimeofFluoroscopy = int('00400300', 16)
  TotalNumberofExposures = int('00400301', 16)
  EntranceDose = int('00400302', 16)
  ExposedArea = int('00400303', 16)
  DistanceSourcetoEntrance = int('00400306', 16)
  DistanceSourcetoSupport = int('00400307', 16)
  ExposureDoseSequence = int('0040030E', 16)
  CommentsonRadiationDose = int('00400310', 16)
  XRayOutput = int('00400312', 16)
  HalfValueLayer = int('00400314', 16)
  OrganDose = int('00400316', 16)
  OrganExposed = int('00400318', 16)
  BillingProcedureStepSequence = int('00400320', 16)
  FilmConsumptionSequence = int('00400321', 16)
  BillingSuppliesandDevicesSequence = int('00400324', 16)
  ReferencedProcedureStepSequence = int('00400330', 16)
  PerformedSeriesSequence = int('00400340', 16)
  CommentsontheScheduledProcedureStep = int('00400400', 16)
  ProtocolContextSequence = int('00400440', 16)
  ContentItemModifierSequence = int('00400441', 16)
  ScheduledSpecimenSequence = int('00400500', 16)
  SpecimenAccessionNumber = int('0040050A', 16)
  ContainerIdentifier = int('00400512', 16)
  IssueroftheContainerIdentifierSequence = int('00400513', 16)
  AlternateContainerIdentifierSequence = int('00400515', 16)
  ContainerTypeCodeSequence = int('00400518', 16)
  ContainerDescription = int('0040051A', 16)
  ContainerComponentSequence = int('00400520', 16)
  SpecimenSequence = int('00400550', 16)
  SpecimenIdentifier = int('00400551', 16)
  SpecimenDescriptionSequenceTrial = int('00400552', 16)
  SpecimenDescriptionTrial = int('00400553', 16)
  SpecimenUID = int('00400554', 16)
  AcquisitionContextSequence = int('00400555', 16)
  AcquisitionContextDescription = int('00400556', 16)
  SpecimenTypeCodeSequence = int('0040059A', 16)
  SpecimenDescriptionSequence = int('00400560', 16)
  IssueroftheSpecimenIdentifierSequence = int('00400562', 16)
  SpecimenShortDescription = int('00400600', 16)
  SpecimenDetailedDescription = int('00400602', 16)
  SpecimenPreparationSequence = int('00400610', 16)
  SpecimenPreparationStepContentItemSequence = int('00400612', 16)
  SpecimenLocalizationContentItemSequence = int('00400620', 16)
  SlideIdentifier = int('004006FA', 16)
  ImageCenterPointCoordinatesSequence = int('0040071A', 16)
  XOffsetinSlideCoordinateSystem = int('0040072A', 16)
  YOffsetinSlideCoordinateSystem = int('0040073A', 16)
  ZOffsetinSlideCoordinateSystem = int('0040074A', 16)
  PixelSpacingSequence = int('004008D8', 16)
  CoordinateSystemAxisCodeSequence = int('004008DA', 16)
  MeasurementUnitsCodeSequence = int('004008EA', 16)
  VitalStainCodeSequenceTrial = int('004009F8', 16)
  RequestedProcedureID = int('00401001', 16)
  ReasonfortheRequestedProcedure = int('00401002', 16)
  RequestedProcedurePriority = int('00401003', 16)
  PatientTransportArrangements = int('00401004', 16)
  RequestedProcedureLocation = int('00401005', 16)
  PlacerOrderNumberProcedure = int('00401006', 16)
  FillerOrderNumberProcedure = int('00401007', 16)
  ConfidentialityCode = int('00401008', 16)
  ReportingPriority = int('00401009', 16)
  ReasonforRequestedProcedureCodeSequence = int('0040100A', 16)
  NamesofIntendedRecipientsofResults = int('00401010', 16)
  IntendedRecipientsofResultsIdentificationSequence = int('00401011', 16)
  ReasonForPerformedProcedureCodeSequence = int('00401012', 16)
  RequestedProcedureDescriptionTrial = int('00401060', 16)
  PersonIdentificationCodeSequence = int('00401101', 16)
  PersonsAddress = int('00401102', 16)
  PersonsTelephoneNumbers = int('00401103', 16)
  PersonsTelecomInformation = int('00401104', 16)
  RequestedProcedureComments = int('00401400', 16)
  ReasonfortheImagingServiceRequest = int('00402001', 16)
  IssueDateofImagingServiceRequest = int('00402004', 16)
  IssueTimeofImagingServiceRequest = int('00402005', 16)
  PlacerOrderNumberImagingServiceRequestRetired = int('00402006', 16)
  FillerOrderNumberImagingServiceRequestRetired = int('00402007', 16)
  OrderEnteredBy = int('00402008', 16)
  OrderEnterersLocation = int('00402009', 16)
  OrderCallbackPhoneNumber = int('00402010', 16)
  OrderCallbackTelecomInformation = int('00402011', 16)
  PlacerOrderNumberImagingServiceRequest = int('00402016', 16)
  FillerOrderNumberImagingServiceRequest = int('00402017', 16)
  ImagingServiceRequestComments = int('00402400', 16)
  ConfidentialityConstraintonPatientDataDescription = int('00403001', 16)
  GeneralPurposeScheduledProcedureStepStatus = int('00404001', 16)
  GeneralPurposePerformedProcedureStepStatus = int('00404002', 16)
  GeneralPurposeScheduledProcedureStepPriority = int('00404003', 16)
  ScheduledProcessingApplicationsCodeSequence = int('00404004', 16)
  ScheduledProcedureStepStartDateTime = int('00404005', 16)
  MultipleCopiesFlag = int('00404006', 16)
  PerformedProcessingApplicationsCodeSequence = int('00404007', 16)
  HumanPerformerCodeSequence = int('00404009', 16)
  ScheduledProcedureStepModificationDateTime = int('00404010', 16)
  ExpectedCompletionDateTime = int('00404011', 16)
  ResultingGeneralPurposePerformedProcedureStepsSequence = int(
      '00404015', 16)
  ReferencedGeneralPurposeScheduledProcedureStepSequence = int(
      '00404016', 16)
  ScheduledWorkitemCodeSequence = int('00404018', 16)
  PerformedWorkitemCodeSequence = int('00404019', 16)
  InputAvailabilityFlag = int('00404020', 16)
  InputInformationSequence = int('00404021', 16)
  RelevantInformationSequence = int('00404022', 16)
  ReferencedGeneralPurposeScheduledProcedureStepTransactionUID = int(
      '00404023', 16)
  ScheduledStationNameCodeSequence = int('00404025', 16)
  ScheduledStationClassCodeSequence = int('00404026', 16)
  ScheduledStationGeographicLocationCodeSequence = int('00404027', 16)
  PerformedStationNameCodeSequence = int('00404028', 16)
  PerformedStationClassCodeSequence = int('00404029', 16)
  PerformedStationGeographicLocationCodeSequence = int('00404030', 16)
  RequestedSubsequentWorkitemCodeSequence = int('00404031', 16)
  NonDICOMOutputCodeSequence = int('00404032', 16)
  OutputInformationSequence = int('00404033', 16)
  ScheduledHumanPerformersSequence = int('00404034', 16)
  ActualHumanPerformersSequence = int('00404035', 16)
  HumanPerformersOrganization = int('00404036', 16)
  HumanPerformersName = int('00404037', 16)
  RawDataHandling = int('00404040', 16)
  InputReadinessState = int('00404041', 16)
  PerformedProcedureStepStartDateTime = int('00404050', 16)
  PerformedProcedureStepEndDateTime = int('00404051', 16)
  ProcedureStepCancellationDateTime = int('00404052', 16)
  OutputDestinationSequence = int('00404070', 16)
  DICOMStorageSequence = int('00404071', 16)
  STOWRSStorageSequence = int('00404072', 16)
  StorageURL = int('00404073', 16)
  XDSStorageSequence = int('00404074', 16)
  EntranceDoseinmGy = int('00408302', 16)
  ParametricMapFrameTypeSequence = int('00409092', 16)
  ReferencedImageRealWorldValueMappingSequence = int('00409094', 16)
  RealWorldValueMappingSequence = int('00409096', 16)
  PixelValueMappingCodeSequence = int('00409098', 16)
  LUTLabel = int('00409210', 16)
  RealWorldValueLastValueMapped = int('00409211', 16)
  RealWorldValueLUTData = int('00409212', 16)
  DoubleFloatRealWorldValueLastValueMapped = int('00409213', 16)
  DoubleFloatRealWorldValueFirstValueMapped = int('00409214', 16)
  RealWorldValueFirstValueMapped = int('00409216', 16)
  QuantityDefinitionSequence = int('00409220', 16)
  RealWorldValueIntercept = int('00409224', 16)
  RealWorldValueSlope = int('00409225', 16)
  FindingsFlagTrial = int('0040A007', 16)
  RelationshipType = int('0040A010', 16)
  FindingsSequenceTrial = int('0040A020', 16)
  FindingsGroupUIDTrial = int('0040A021', 16)
  ReferencedFindingsGroupUIDTrial = int('0040A022', 16)
  FindingsGroupRecordingDateTrial = int('0040A023', 16)
  FindingsGroupRecordingTimeTrial = int('0040A024', 16)
  FindingsSourceCategoryCodeSequenceTrial = int('0040A026', 16)
  VerifyingOrganization = int('0040A027', 16)
  DocumentingOrganizationIdentifierCodeSequenceTrial = int('0040A028', 16)
  VerificationDateTime = int('0040A030', 16)
  ObservationDateTime = int('0040A032', 16)
  ValueType = int('0040A040', 16)
  ConceptNameCodeSequence = int('0040A043', 16)
  MeasurementPrecisionDescriptionTrial = int('0040A047', 16)
  ContinuityOfContent = int('0040A050', 16)
  UrgencyorPriorityAlertsTrial = int('0040A057', 16)
  SequencingIndicatorTrial = int('0040A060', 16)
  DocumentIdentifierCodeSequenceTrial = int('0040A066', 16)
  DocumentAuthorTrial = int('0040A067', 16)
  DocumentAuthorIdentifierCodeSequenceTrial = int('0040A068', 16)
  IdentifierCodeSequenceTrial = int('0040A070', 16)
  VerifyingObserverSequence = int('0040A073', 16)
  ObjectBinaryIdentifierTrial = int('0040A074', 16)
  VerifyingObserverName = int('0040A075', 16)
  DocumentingObserverIdentifierCodeSequenceTrial = int('0040A076', 16)
  AuthorObserverSequence = int('0040A078', 16)
  ParticipantSequence = int('0040A07A', 16)
  CustodialOrganizationSequence = int('0040A07C', 16)
  ParticipationType = int('0040A080', 16)
  ParticipationDateTime = int('0040A082', 16)
  ObserverType = int('0040A084', 16)
  ProcedureIdentifierCodeSequenceTrial = int('0040A085', 16)
  VerifyingObserverIdentificationCodeSequence = int('0040A088', 16)
  ObjectDirectoryBinaryIdentifierTrial = int('0040A089', 16)
  EquivalentCDADocumentSequence = int('0040A090', 16)
  ReferencedWaveformChannels = int('0040A0B0', 16)
  DateofDocumentorVerbalTransactionTrial = int('0040A110', 16)
  TimeofDocumentCreationorVerbalTransactionTrial = int('0040A112', 16)
  DateTime = int('0040A120', 16)
  Date = int('0040A121', 16)
  Time = int('0040A122', 16)
  PersonName = int('0040A123', 16)
  UID = int('0040A124', 16)
  ReportStatusIDTrial = int('0040A125', 16)
  TemporalRangeType = int('0040A130', 16)
  ReferencedSamplePositions = int('0040A132', 16)
  ReferencedFrameNumbers = int('0040A136', 16)
  ReferencedTimeOffsets = int('0040A138', 16)
  ReferencedDateTime = int('0040A13A', 16)
  TextValue = int('0040A160', 16)
  FloatingPointValue = int('0040A161', 16)
  RationalNumeratorValue = int('0040A162', 16)
  RationalDenominatorValue = int('0040A163', 16)
  ObservationCategoryCodeSequenceTrial = int('0040A167', 16)
  ConceptCodeSequence = int('0040A168', 16)
  BibliographicCitationTrial = int('0040A16A', 16)
  PurposeofReferenceCodeSequence = int('0040A170', 16)
  ObservationUID = int('0040A171', 16)
  ReferencedObservationUIDTrial = int('0040A172', 16)
  ReferencedObservationClassTrial = int('0040A173', 16)
  ReferencedObjectObservationClassTrial = int('0040A174', 16)
  AnnotationGroupNumber = int('0040A180', 16)
  ObservationDateTrial = int('0040A192', 16)
  ObservationTimeTrial = int('0040A193', 16)
  MeasurementAutomationTrial = int('0040A194', 16)
  ModifierCodeSequence = int('0040A195', 16)
  IdentificationDescriptionTrial = int('0040A224', 16)
  CoordinatesSetGeometricTypeTrial = int('0040A290', 16)
  AlgorithmCodeSequenceTrial = int('0040A296', 16)
  AlgorithmDescriptionTrial = int('0040A297', 16)
  PixelCoordinatesSetTrial = int('0040A29A', 16)
  MeasuredValueSequence = int('0040A300', 16)
  NumericValueQualifierCodeSequence = int('0040A301', 16)
  CurrentObserverTrial = int('0040A307', 16)
  NumericValue = int('0040A30A', 16)
  ReferencedAccessionSequenceTrial = int('0040A313', 16)
  ReportStatusCommentTrial = int('0040A33A', 16)
  ProcedureContextSequenceTrial = int('0040A340', 16)
  VerbalSourceTrial = int('0040A352', 16)
  AddressTrial = int('0040A353', 16)
  TelephoneNumberTrial = int('0040A354', 16)
  VerbalSourceIdentifierCodeSequenceTrial = int('0040A358', 16)
  PredecessorDocumentsSequence = int('0040A360', 16)
  ReferencedRequestSequence = int('0040A370', 16)
  PerformedProcedureCodeSequence = int('0040A372', 16)
  CurrentRequestedProcedureEvidenceSequence = int('0040A375', 16)
  ReportDetailSequenceTrial = int('0040A380', 16)
  PertinentOtherEvidenceSequence = int('0040A385', 16)
  HL7StructuredDocumentReferenceSequence = int('0040A390', 16)
  ObservationSubjectUIDTrial = int('0040A402', 16)
  ObservationSubjectClassTrial = int('0040A403', 16)
  ObservationSubjectTypeCodeSequenceTrial = int('0040A404', 16)
  CompletionFlag = int('0040A491', 16)
  CompletionFlagDescription = int('0040A492', 16)
  VerificationFlag = int('0040A493', 16)
  ArchiveRequested = int('0040A494', 16)
  PreliminaryFlag = int('0040A496', 16)
  ContentTemplateSequence = int('0040A504', 16)
  IdenticalDocumentsSequence = int('0040A525', 16)
  ObservationSubjectContextFlagTrial = int('0040A600', 16)
  ObserverContextFlagTrial = int('0040A601', 16)
  ProcedureContextFlagTrial = int('0040A603', 16)
  ContentSequence = int('0040A730', 16)
  RelationshipSequenceTrial = int('0040A731', 16)
  RelationshipTypeCodeSequenceTrial = int('0040A732', 16)
  LanguageCodeSequenceTrial = int('0040A744', 16)
  UniformResourceLocatorTrial = int('0040A992', 16)
  WaveformAnnotationSequence = int('0040B020', 16)
  TemplateIdentifier = int('0040DB00', 16)
  TemplateVersion = int('0040DB06', 16)
  TemplateLocalVersion = int('0040DB07', 16)
  TemplateExtensionFlag = int('0040DB0B', 16)
  TemplateExtensionOrganizationUID = int('0040DB0C', 16)
  TemplateExtensionCreatorUID = int('0040DB0D', 16)
  ReferencedContentItemIdentifier = int('0040DB73', 16)
  HL7InstanceIdentifier = int('0040E001', 16)
  HL7DocumentEffectiveTime = int('0040E004', 16)
  HL7DocumentTypeCodeSequence = int('0040E006', 16)
  DocumentClassCodeSequence = int('0040E008', 16)
  RetrieveURI = int('0040E010', 16)
  RetrieveLocationUID = int('0040E011', 16)
  TypeofInstances = int('0040E020', 16)
  DICOMRetrievalSequence = int('0040E021', 16)
  DICOMMediaRetrievalSequence = int('0040E022', 16)
  WADORetrievalSequence = int('0040E023', 16)
  XDSRetrievalSequence = int('0040E024', 16)
  WADORSRetrievalSequence = int('0040E025', 16)
  RepositoryUniqueID = int('0040E030', 16)
  HomeCommunityID = int('0040E031', 16)
  DocumentTitle = int('00420010', 16)
  EncapsulatedDocument = int('00420011', 16)
  MIMETypeofEncapsulatedDocument = int('00420012', 16)
  SourceInstanceSequence = int('00420013', 16)
  ListofMIMETypes = int('00420014', 16)
  ProductPackageIdentifier = int('00440001', 16)
  SubstanceAdministrationApproval = int('00440002', 16)
  ApprovalStatusFurtherDescription = int('00440003', 16)
  ApprovalStatusDateTime = int('00440004', 16)
  ProductTypeCodeSequence = int('00440007', 16)
  ProductName = int('00440008', 16)
  ProductDescription = int('00440009', 16)
  ProductLotIdentifier = int('0044000A', 16)
  ProductExpirationDateTime = int('0044000B', 16)
  SubstanceAdministrationDateTime = int('00440010', 16)
  SubstanceAdministrationNotes = int('00440011', 16)
  SubstanceAdministrationDeviceID = int('00440012', 16)
  ProductParameterSequence = int('00440013', 16)
  SubstanceAdministrationParameterSequence = int('00440019', 16)
  LensDescription = int('00460012', 16)
  RightLensSequence = int('00460014', 16)
  LeftLensSequence = int('00460015', 16)
  UnspecifiedLateralityLensSequence = int('00460016', 16)
  CylinderSequence = int('00460018', 16)
  PrismSequence = int('00460028', 16)
  HorizontalPrismPower = int('00460030', 16)
  HorizontalPrismBase = int('00460032', 16)
  VerticalPrismPower = int('00460034', 16)
  VerticalPrismBase = int('00460036', 16)
  LensSegmentType = int('00460038', 16)
  OpticalTransmittance = int('00460040', 16)
  ChannelWidth = int('00460042', 16)
  PupilSize = int('00460044', 16)
  CornealSize = int('00460046', 16)
  AutorefractionRightEyeSequence = int('00460050', 16)
  AutorefractionLeftEyeSequence = int('00460052', 16)
  DistancePupillaryDistance = int('00460060', 16)
  NearPupillaryDistance = int('00460062', 16)
  IntermediatePupillaryDistance = int('00460063', 16)
  OtherPupillaryDistance = int('00460064', 16)
  KeratometryRightEyeSequence = int('00460070', 16)
  KeratometryLeftEyeSequence = int('00460071', 16)
  SteepKeratometricAxisSequence = int('00460074', 16)
  RadiusofCurvature = int('00460075', 16)
  KeratometricPower = int('00460076', 16)
  KeratometricAxis = int('00460077', 16)
  FlatKeratometricAxisSequence = int('00460080', 16)
  BackgroundColor = int('00460092', 16)
  Optotype = int('00460094', 16)
  OptotypePresentation = int('00460095', 16)
  SubjectiveRefractionRightEyeSequence = int('00460097', 16)
  SubjectiveRefractionLeftEyeSequence = int('00460098', 16)
  AddNearSequence = int('00460100', 16)
  AddIntermediateSequence = int('00460101', 16)
  AddOtherSequence = int('00460102', 16)
  AddPower = int('00460104', 16)
  ViewingDistance = int('00460106', 16)
  VisualAcuityTypeCodeSequence = int('00460121', 16)
  VisualAcuityRightEyeSequence = int('00460122', 16)
  VisualAcuityLeftEyeSequence = int('00460123', 16)
  VisualAcuityBothEyesOpenSequence = int('00460124', 16)
  ViewingDistanceType = int('00460125', 16)
  VisualAcuityModifiers = int('00460135', 16)
  DecimalVisualAcuity = int('00460137', 16)
  OptotypeDetailedDefinition = int('00460139', 16)
  ReferencedRefractiveMeasurementsSequence = int('00460145', 16)
  SpherePower = int('00460146', 16)
  CylinderPower = int('00460147', 16)
  CornealTopographySurface = int('00460201', 16)
  CornealVertexLocation = int('00460202', 16)
  PupilCentroidXCoordinate = int('00460203', 16)
  PupilCentroidYCoordinate = int('00460204', 16)
  EquivalentPupilRadius = int('00460205', 16)
  CornealTopographyMapTypeCodeSequence = int('00460207', 16)
  VerticesoftheOutlineofPupil = int('00460208', 16)
  CornealTopographyMappingNormalsSequence = int('00460210', 16)
  MaximumCornealCurvatureSequence = int('00460211', 16)
  MaximumCornealCurvature = int('00460212', 16)
  MaximumCornealCurvatureLocation = int('00460213', 16)
  MinimumKeratometricSequence = int('00460215', 16)
  SimulatedKeratometricCylinderSequence = int('00460218', 16)
  AverageCornealPower = int('00460220', 16)
  CornealISValue = int('00460224', 16)
  AnalyzedArea = int('00460227', 16)
  SurfaceRegularityIndex = int('00460230', 16)
  SurfaceAsymmetryIndex = int('00460232', 16)
  CornealEccentricityIndex = int('00460234', 16)
  KeratoconusPredictionIndex = int('00460236', 16)
  DecimalPotentialVisualAcuity = int('00460238', 16)
  CornealTopographyMapQualityEvaluation = int('00460242', 16)
  SourceImageCornealProcessedDataSequence = int('00460244', 16)
  CornealPointLocation = int('00460247', 16)
  CornealPointEstimated = int('00460248', 16)
  AxialPower = int('00460249', 16)
  TangentialPower = int('00460250', 16)
  RefractivePower = int('00460251', 16)
  RelativeElevation = int('00460252', 16)
  CornealWavefront = int('00460253', 16)
  ImagedVolumeWidth = int('00480001', 16)
  ImagedVolumeHeight = int('00480002', 16)
  ImagedVolumeDepth = int('00480003', 16)
  TotalPixelMatrixColumns = int('00480006', 16)
  TotalPixelMatrixRows = int('00480007', 16)
  TotalPixelMatrixOriginSequence = int('00480008', 16)
  SpecimenLabelinImage = int('00480010', 16)
  FocusMethod = int('00480011', 16)
  ExtendedDepthofField = int('00480012', 16)
  NumberofFocalPlanes = int('00480013', 16)
  DistanceBetweenFocalPlanes = int('00480014', 16)
  RecommendedAbsentPixelCIELabValue = int('00480015', 16)
  IlluminatorTypeCodeSequence = int('00480100', 16)
  ImageOrientationSlide = int('00480102', 16)
  OpticalPathSequence = int('00480105', 16)
  OpticalPathIdentifier = int('00480106', 16)
  OpticalPathDescription = int('00480107', 16)
  IlluminationColorCodeSequence = int('00480108', 16)
  SpecimenReferenceSequence = int('00480110', 16)
  CondenserLensPower = int('00480111', 16)
  ObjectiveLensPower = int('00480112', 16)
  ObjectiveLensNumericalAperture = int('00480113', 16)
  PaletteColorLookupTableSequence = int('00480120', 16)
  ReferencedImageNavigationSequence = int('00480200', 16)
  TopLeftHandCornerofLocalizerArea = int('00480201', 16)
  BottomRightHandCornerofLocalizerArea = int('00480202', 16)
  OpticalPathIdentificationSequence = int('00480207', 16)
  PlanePositionSlideSequence = int('0048021A', 16)
  ColumnPositionInTotalImagePixelMatrix = int('0048021E', 16)
  RowPositionInTotalImagePixelMatrix = int('0048021F', 16)
  PixelOriginInterpretation = int('00480301', 16)
  CalibrationImage = int('00500004', 16)
  DeviceSequence = int('00500010', 16)
  ContainerComponentTypeCodeSequence = int('00500012', 16)
  ContainerComponentThickness = int('00500013', 16)
  DeviceLength = int('00500014', 16)
  ContainerComponentWidth = int('00500015', 16)
  DeviceDiameter = int('00500016', 16)
  DeviceDiameterUnits = int('00500017', 16)
  DeviceVolume = int('00500018', 16)
  InterMarkerDistance = int('00500019', 16)
  ContainerComponentMaterial = int('0050001A', 16)
  ContainerComponentID = int('0050001B', 16)
  ContainerComponentLength = int('0050001C', 16)
  ContainerComponentDiameter = int('0050001D', 16)
  ContainerComponentDescription = int('0050001E', 16)
  DeviceDescription = int('00500020', 16)
  ContrastBolusIngredientPercentbyVolume = int('00520001', 16)
  OCTFocalDistance = int('00520002', 16)
  BeamSpotSize = int('00520003', 16)
  EffectiveRefractiveIndex = int('00520004', 16)
  OCTAcquisitionDomain = int('00520006', 16)
  OCTOpticalCenterWavelength = int('00520007', 16)
  AxialResolution = int('00520008', 16)
  RangingDepth = int('00520009', 16)
  AlineRate = int('00520011', 16)
  AlinesPerFrame = int('00520012', 16)
  CatheterRotationalRate = int('00520013', 16)
  AlinePixelSpacing = int('00520014', 16)
  ModeofPercutaneousAccessSequence = int('00520016', 16)
  IntravascularOCTFrameTypeSequence = int('00520025', 16)
  OCTZOffsetApplied = int('00520026', 16)
  IntravascularFrameContentSequence = int('00520027', 16)
  IntravascularLongitudinalDistance = int('00520028', 16)
  IntravascularOCTFrameContentSequence = int('00520029', 16)
  OCTZOffsetCorrection = int('00520030', 16)
  CatheterDirectionofRotation = int('00520031', 16)
  SeamLineLocation = int('00520033', 16)
  FirstAlineLocation = int('00520034', 16)
  SeamLineIndex = int('00520036', 16)
  NumberofPaddedAlines = int('00520038', 16)
  InterpolationType = int('00520039', 16)
  RefractiveIndexApplied = int('0052003A', 16)
  EnergyWindowVector = int('00540010', 16)
  NumberofEnergyWindows = int('00540011', 16)
  EnergyWindowInformationSequence = int('00540012', 16)
  EnergyWindowRangeSequence = int('00540013', 16)
  EnergyWindowLowerLimit = int('00540014', 16)
  EnergyWindowUpperLimit = int('00540015', 16)
  RadiopharmaceuticalInformationSequence = int('00540016', 16)
  ResidualSyringeCounts = int('00540017', 16)
  EnergyWindowName = int('00540018', 16)
  DetectorVector = int('00540020', 16)
  NumberofDetectors = int('00540021', 16)
  DetectorInformationSequence = int('00540022', 16)
  PhaseVector = int('00540030', 16)
  NumberofPhases = int('00540031', 16)
  PhaseInformationSequence = int('00540032', 16)
  NumberofFramesinPhase = int('00540033', 16)
  PhaseDelay = int('00540036', 16)
  PauseBetweenFrames = int('00540038', 16)
  PhaseDescription = int('00540039', 16)
  RotationVector = int('00540050', 16)
  NumberofRotations = int('00540051', 16)
  RotationInformationSequence = int('00540052', 16)
  NumberofFramesinRotation = int('00540053', 16)
  RRIntervalVector = int('00540060', 16)
  NumberofRRIntervals = int('00540061', 16)
  GatedInformationSequence = int('00540062', 16)
  DataInformationSequence = int('00540063', 16)
  TimeSlotVector = int('00540070', 16)
  NumberofTimeSlots = int('00540071', 16)
  TimeSlotInformationSequence = int('00540072', 16)
  TimeSlotTime = int('00540073', 16)
  SliceVector = int('00540080', 16)
  NumberofSlices = int('00540081', 16)
  AngularViewVector = int('00540090', 16)
  TimeSliceVector = int('00540100', 16)
  NumberofTimeSlices = int('00540101', 16)
  StartAngle = int('00540200', 16)
  TypeofDetectorMotion = int('00540202', 16)
  TriggerVector = int('00540210', 16)
  NumberofTriggersinPhase = int('00540211', 16)
  ViewCodeSequence = int('00540220', 16)
  ViewModifierCodeSequence = int('00540222', 16)
  RadionuclideCodeSequence = int('00540300', 16)
  AdministrationRouteCodeSequence = int('00540302', 16)
  RadiopharmaceuticalCodeSequence = int('00540304', 16)
  CalibrationDataSequence = int('00540306', 16)
  EnergyWindowNumber = int('00540308', 16)
  ImageID = int('00540400', 16)
  PatientOrientationCodeSequence = int('00540410', 16)
  PatientOrientationModifierCodeSequence = int('00540412', 16)
  PatientGantryRelationshipCodeSequence = int('00540414', 16)
  SliceProgressionDirection = int('00540500', 16)
  ScanProgressionDirection = int('00540501', 16)
  SeriesType = int('00541000', 16)
  Units = int('00541001', 16)
  CountsSource = int('00541002', 16)
  ReprojectionMethod = int('00541004', 16)
  SUVType = int('00541006', 16)
  RandomsCorrectionMethod = int('00541100', 16)
  AttenuationCorrectionMethod = int('00541101', 16)
  DecayCorrection = int('00541102', 16)
  ReconstructionMethod = int('00541103', 16)
  DetectorLinesofResponseUsed = int('00541104', 16)
  ScatterCorrectionMethod = int('00541105', 16)
  AxialAcceptance = int('00541200', 16)
  AxialMash = int('00541201', 16)
  TransverseMash = int('00541202', 16)
  DetectorElementSize = int('00541203', 16)
  CoincidenceWindowWidth = int('00541210', 16)
  SecondaryCountsType = int('00541220', 16)
  FrameReferenceTime = int('00541300', 16)
  PrimaryPromptsCountsAccumulated = int('00541310', 16)
  SecondaryCountsAccumulated = int('00541311', 16)
  SliceSensitivityFactor = int('00541320', 16)
  DecayFactor = int('00541321', 16)
  DoseCalibrationFactor = int('00541322', 16)
  ScatterFractionFactor = int('00541323', 16)
  DeadTimeFactor = int('00541324', 16)
  ImageIndex = int('00541330', 16)
  CountsIncluded = int('00541400', 16)
  DeadTimeCorrectionFlag = int('00541401', 16)
  HistogramSequence = int('00603000', 16)
  HistogramNumberofBins = int('00603002', 16)
  HistogramFirstBinValue = int('00603004', 16)
  HistogramLastBinValue = int('00603006', 16)
  HistogramBinWidth = int('00603008', 16)
  HistogramExplanation = int('00603010', 16)
  HistogramData = int('00603020', 16)
  SegmentationType = int('00620001', 16)
  SegmentSequence = int('00620002', 16)
  SegmentedPropertyCategoryCodeSequence = int('00620003', 16)
  SegmentNumber = int('00620004', 16)
  SegmentLabel = int('00620005', 16)
  SegmentDescription = int('00620006', 16)
  SegmentAlgorithmType = int('00620008', 16)
  SegmentAlgorithmName = int('00620009', 16)
  SegmentIdentificationSequence = int('0062000A', 16)
  ReferencedSegmentNumber = int('0062000B', 16)
  RecommendedDisplayGrayscaleValue = int('0062000C', 16)
  RecommendedDisplayCIELabValue = int('0062000D', 16)
  MaximumFractionalValue = int('0062000E', 16)
  SegmentedPropertyTypeCodeSequence = int('0062000F', 16)
  SegmentationFractionalType = int('00620010', 16)
  SegmentedPropertyTypeModifierCodeSequence = int('00620011', 16)
  UsedSegmentsSequence = int('00620012', 16)
  TrackingID = int('00620020', 16)
  TrackingUID = int('00620021', 16)
  DeformableRegistrationSequence = int('00640002', 16)
  SourceFrameofReferenceUID = int('00640003', 16)
  DeformableRegistrationGridSequence = int('00640005', 16)
  GridDimensions = int('00640007', 16)
  GridResolution = int('00640008', 16)
  VectorGridData = int('00640009', 16)
  PreDeformationMatrixRegistrationSequence = int('0064000F', 16)
  PostDeformationMatrixRegistrationSequence = int('00640010', 16)
  NumberofSurfaces = int('00660001', 16)
  SurfaceSequence = int('00660002', 16)
  SurfaceNumber = int('00660003', 16)
  SurfaceComments = int('00660004', 16)
  SurfaceProcessing = int('00660009', 16)
  SurfaceProcessingRatio = int('0066000A', 16)
  SurfaceProcessingDescription = int('0066000B', 16)
  RecommendedPresentationOpacity = int('0066000C', 16)
  RecommendedPresentationType = int('0066000D', 16)
  FiniteVolume = int('0066000E', 16)
  Manifold = int('00660010', 16)
  SurfacePointsSequence = int('00660011', 16)
  SurfacePointsNormalsSequence = int('00660012', 16)
  SurfaceMeshPrimitivesSequence = int('00660013', 16)
  NumberofSurfacePoints = int('00660015', 16)
  PointCoordinatesData = int('00660016', 16)
  PointPositionAccuracy = int('00660017', 16)
  MeanPointDistance = int('00660018', 16)
  MaximumPointDistance = int('00660019', 16)
  PointsBoundingBoxCoordinates = int('0066001A', 16)
  AxisofRotation = int('0066001B', 16)
  CenterofRotation = int('0066001C', 16)
  NumberofVectors = int('0066001E', 16)
  VectorDimensionality = int('0066001F', 16)
  VectorAccuracy = int('00660020', 16)
  VectorCoordinateData = int('00660021', 16)
  TrianglePointIndexList = int('00660023', 16)
  EdgePointIndexList = int('00660024', 16)
  VertexPointIndexList = int('00660025', 16)
  TriangleStripSequence = int('00660026', 16)
  TriangleFanSequence = int('00660027', 16)
  LineSequence = int('00660028', 16)
  PrimitivePointIndexList = int('00660029', 16)
  SurfaceCount = int('0066002A', 16)
  ReferencedSurfaceSequence = int('0066002B', 16)
  ReferencedSurfaceNumber = int('0066002C', 16)
  SegmentSurfaceGenerationAlgorithmIdentificationSequence = int(
      '0066002D', 16)
  SegmentSurfaceSourceInstanceSequence = int('0066002E', 16)
  AlgorithmFamilyCodeSequence = int('0066002F', 16)
  AlgorithmNameCodeSequence = int('00660030', 16)
  AlgorithmVersion = int('00660031', 16)
  AlgorithmParameters = int('00660032', 16)
  FacetSequence = int('00660034', 16)
  SurfaceProcessingAlgorithmIdentificationSequence = int('00660035', 16)
  AlgorithmName = int('00660036', 16)
  RecommendedPointRadius = int('00660037', 16)
  RecommendedLineThickness = int('00660038', 16)
  LongPrimitivePointIndexList = int('00660040', 16)
  LongTrianglePointIndexList = int('00660041', 16)
  LongEdgePointIndexList = int('00660042', 16)
  LongVertexPointIndexList = int('00660043', 16)
  TrackSetSequence = int('00660101', 16)
  TrackSequence = int('00660102', 16)
  RecommendedDisplayCIELabValueList = int('00660103', 16)
  TrackingAlgorithmIdentificationSequence = int('00660104', 16)
  TrackSetNumber = int('00660105', 16)
  TrackSetLabel = int('00660106', 16)
  TrackSetDescription = int('00660107', 16)
  TrackSetAnatomicalTypeCodeSequence = int('00660108', 16)
  MeasurementsSequence = int('00660121', 16)
  TrackSetStatisticsSequence = int('00660124', 16)
  FloatingPointValues = int('00660125', 16)
  TrackPointIndexList = int('00660129', 16)
  TrackStatisticsSequence = int('00660130', 16)
  MeasurementValuesSequence = int('00660132', 16)
  DiffusionAcquisitionCodeSequence = int('00660133', 16)
  DiffusionModelCodeSequence = int('00660134', 16)
  ImplantSize = int('00686210', 16)
  ImplantTemplateVersion = int('00686221', 16)
  ReplacedImplantTemplateSequence = int('00686222', 16)
  ImplantType = int('00686223', 16)
  DerivationImplantTemplateSequence = int('00686224', 16)
  OriginalImplantTemplateSequence = int('00686225', 16)
  EffectiveDateTime = int('00686226', 16)
  ImplantTargetAnatomySequence = int('00686230', 16)
  InformationFromManufacturerSequence = int('00686260', 16)
  NotificationFromManufacturerSequence = int('00686265', 16)
  InformationIssueDateTime = int('00686270', 16)
  InformationSummary = int('00686280', 16)
  ImplantRegulatoryDisapprovalCodeSequence = int('006862A0', 16)
  OverallTemplateSpatialTolerance = int('006862A5', 16)
  HPGLDocumentSequence = int('006862C0', 16)
  HPGLDocumentID = int('006862D0', 16)
  HPGLDocumentLabel = int('006862D5', 16)
  ViewOrientationCodeSequence = int('006862E0', 16)
  ViewOrientationModifier = int('006862F0', 16)
  HPGLDocumentScaling = int('006862F2', 16)
  HPGLDocument = int('00686300', 16)
  HPGLContourPenNumber = int('00686310', 16)
  HPGLPenSequence = int('00686320', 16)
  HPGLPenNumber = int('00686330', 16)
  HPGLPenLabel = int('00686340', 16)
  HPGLPenDescription = int('00686345', 16)
  RecommendedRotationPoint = int('00686346', 16)
  BoundingRectangle = int('00686347', 16)
  ImplantTemplate3DModelSurfaceNumber = int('00686350', 16)
  SurfaceModelDescriptionSequence = int('00686360', 16)
  SurfaceModelLabel = int('00686380', 16)
  SurfaceModelScalingFactor = int('00686390', 16)
  MaterialsCodeSequence = int('006863A0', 16)
  CoatingMaterialsCodeSequence = int('006863A4', 16)
  ImplantTypeCodeSequence = int('006863A8', 16)
  FixationMethodCodeSequence = int('006863AC', 16)
  MatingFeatureSetsSequence = int('006863B0', 16)
  MatingFeatureSetID = int('006863C0', 16)
  MatingFeatureSetLabel = int('006863D0', 16)
  MatingFeatureSequence = int('006863E0', 16)
  MatingFeatureID = int('006863F0', 16)
  MatingFeatureDegreeofFreedomSequence = int('00686400', 16)
  DegreeofFreedomID = int('00686410', 16)
  DegreeofFreedomType = int('00686420', 16)
  TwoDMatingFeatureCoordinatesSequence = int('00686430', 16)
  ReferencedHPGLDocumentID = int('00686440', 16)
  TwoDMatingPoint = int('00686450', 16)
  TwoDMatingAxes = int('00686460', 16)
  TwoDDegreeofFreedomSequence = int('00686470', 16)
  ThreeDDegreeofFreedomAxis = int('00686490', 16)
  RangeofFreedom = int('006864A0', 16)
  ThreeDMatingPoint = int('006864C0', 16)
  ThreeDMatingAxes = int('006864D0', 16)
  TwoDDegreeofFreedomAxis = int('006864F0', 16)
  PlanningLandmarkPointSequence = int('00686500', 16)
  PlanningLandmarkLineSequence = int('00686510', 16)
  PlanningLandmarkPlaneSequence = int('00686520', 16)
  PlanningLandmarkID = int('00686530', 16)
  PlanningLandmarkDescription = int('00686540', 16)
  PlanningLandmarkIdentificationCodeSequence = int('00686545', 16)
  TwoDPointCoordinatesSequence = int('00686550', 16)
  TwoDPointCoordinates = int('00686560', 16)
  ThreeDPointCoordinates = int('00686590', 16)
  TwoDLineCoordinatesSequence = int('006865A0', 16)
  TwoDLineCoordinates = int('006865B0', 16)
  ThreeDLineCoordinates = int('006865D0', 16)
  TwoDPlaneCoordinatesSequence = int('006865E0', 16)
  TwoDPlaneIntersection = int('006865F0', 16)
  ThreeDPlaneOrigin = int('00686610', 16)
  ThreeDPlaneNormal = int('00686620', 16)
  GraphicAnnotationSequence = int('00700001', 16)
  GraphicLayer = int('00700002', 16)
  BoundingBoxAnnotationUnits = int('00700003', 16)
  AnchorPointAnnotationUnits = int('00700004', 16)
  GraphicAnnotationUnits = int('00700005', 16)
  UnformattedTextValue = int('00700006', 16)
  TextObjectSequence = int('00700008', 16)
  GraphicObjectSequence = int('00700009', 16)
  BoundingBoxTopLeftHandCorner = int('00700010', 16)
  BoundingBoxBottomRightHandCorner = int('00700011', 16)
  BoundingBoxTextHorizontalJustification = int('00700012', 16)
  AnchorPoint = int('00700014', 16)
  AnchorPointVisibility = int('00700015', 16)
  GraphicDimensions = int('00700020', 16)
  NumberofGraphicPoints = int('00700021', 16)
  GraphicData = int('00700022', 16)
  GraphicType = int('00700023', 16)
  GraphicFilled = int('00700024', 16)
  ImageRotationRetired = int('00700040', 16)
  ImageHorizontalFlip = int('00700041', 16)
  ImageRotation = int('00700042', 16)
  DisplayedAreaTopLeftHandCornerTrial = int('00700050', 16)
  DisplayedAreaBottomRightHandCornerTrial = int('00700051', 16)
  DisplayedAreaTopLeftHandCorner = int('00700052', 16)
  DisplayedAreaBottomRightHandCorner = int('00700053', 16)
  DisplayedAreaSelectionSequence = int('0070005A', 16)
  GraphicLayerSequence = int('00700060', 16)
  GraphicLayerOrder = int('00700062', 16)
  GraphicLayerRecommendedDisplayGrayscaleValue = int('00700066', 16)
  GraphicLayerRecommendedDisplayRGBValue = int('00700067', 16)
  GraphicLayerDescription = int('00700068', 16)
  ContentLabel = int('00700080', 16)
  ContentDescription = int('00700081', 16)
  PresentationCreationDate = int('00700082', 16)
  PresentationCreationTime = int('00700083', 16)
  ContentCreatorsName = int('00700084', 16)
  ContentCreatorsIdentificationCodeSequence = int('00700086', 16)
  AlternateContentDescriptionSequence = int('00700087', 16)
  PresentationSizeMode = int('00700100', 16)
  PresentationPixelSpacing = int('00700101', 16)
  PresentationPixelAspectRatio = int('00700102', 16)
  PresentationPixelMagnificationRatio = int('00700103', 16)
  GraphicGroupLabel = int('00700207', 16)
  GraphicGroupDescription = int('00700208', 16)
  CompoundGraphicSequence = int('00700209', 16)
  CompoundGraphicInstanceID = int('00700226', 16)
  FontName = int('00700227', 16)
  FontNameType = int('00700228', 16)
  CSSFontName = int('00700229', 16)
  RotationAngle = int('00700230', 16)
  TextStyleSequence = int('00700231', 16)
  LineStyleSequence = int('00700232', 16)
  FillStyleSequence = int('00700233', 16)
  GraphicGroupSequence = int('00700234', 16)
  TextColorCIELabValue = int('00700241', 16)
  HorizontalAlignment = int('00700242', 16)
  VerticalAlignment = int('00700243', 16)
  ShadowStyle = int('00700244', 16)
  ShadowOffsetX = int('00700245', 16)
  ShadowOffsetY = int('00700246', 16)
  ShadowColorCIELabValue = int('00700247', 16)
  Underlined = int('00700248', 16)
  Bold = int('00700249', 16)
  Italic = int('00700250', 16)
  PatternOnColorCIELabValue = int('00700251', 16)
  PatternOffColorCIELabValue = int('00700252', 16)
  LineThickness = int('00700253', 16)
  LineDashingStyle = int('00700254', 16)
  LinePattern = int('00700255', 16)
  FillPattern = int('00700256', 16)
  FillMode = int('00700257', 16)
  ShadowOpacity = int('00700258', 16)
  GapLength = int('00700261', 16)
  DiameterofVisibility = int('00700262', 16)
  RotationPoint = int('00700273', 16)
  TickAlignment = int('00700274', 16)
  ShowTickLabel = int('00700278', 16)
  TickLabelAlignment = int('00700279', 16)
  CompoundGraphicUnits = int('00700282', 16)
  PatternOnOpacity = int('00700284', 16)
  PatternOffOpacity = int('00700285', 16)
  MajorTicksSequence = int('00700287', 16)
  TickPosition = int('00700288', 16)
  TickLabel = int('00700289', 16)
  CompoundGraphicType = int('00700294', 16)
  GraphicGroupID = int('00700295', 16)
  ShapeType = int('00700306', 16)
  RegistrationSequence = int('00700308', 16)
  MatrixRegistrationSequence = int('00700309', 16)
  MatrixSequence = int('0070030A', 16)
  FrameofReferencetoDisplayedCoordinateSystemTransformationMatrix = int(
      '0070030B', 16)
  FrameofReferenceTransformationMatrixType = int('0070030C', 16)
  RegistrationTypeCodeSequence = int('0070030D', 16)
  FiducialDescription = int('0070030F', 16)
  FiducialIdentifier = int('00700310', 16)
  FiducialIdentifierCodeSequence = int('00700311', 16)
  ContourUncertaintyRadius = int('00700312', 16)
  UsedFiducialsSequence = int('00700314', 16)
  GraphicCoordinatesDataSequence = int('00700318', 16)
  FiducialUID = int('0070031A', 16)
  FiducialSetSequence = int('0070031C', 16)
  FiducialSequence = int('0070031E', 16)
  GraphicLayerRecommendedDisplayCIELabValue = int('00700401', 16)
  BlendingSequence = int('00700402', 16)
  RelativeOpacity = int('00700403', 16)
  ReferencedSpatialRegistrationSequence = int('00700404', 16)
  BlendingPosition = int('00700405', 16)
  PresentationDisplayCollectionUID = int('00701101', 16)
  PresentationSequenceCollectionUID = int('00701102', 16)
  PresentationSequencePositionIndex = int('00701103', 16)
  RenderedImageReferenceSequence = int('00701104', 16)
  VolumetricPresentationStateInputSequence = int('00701201', 16)
  PresentationInputType = int('00701202', 16)
  InputSequencePositionIndex = int('00701203', 16)
  Crop = int('00701204', 16)
  CroppingSpecificationIndex = int('00701205', 16)
  CompositingMethod = int('00701206', 16)
  VolumetricPresentationInputNumber = int('00701207', 16)
  ImageVolumeGeometry = int('00701208', 16)
  VolumeCroppingSequence = int('00701301', 16)
  VolumeCroppingMethod = int('00701302', 16)
  BoundingBoxCrop = int('00701303', 16)
  ObliqueCroppingPlaneSequence = int('00701304', 16)
  Plane = int('00701305', 16)
  PlaneNormal = int('00701306', 16)
  CroppingSpecificationNumber = int('00701309', 16)
  MultiPlanarReconstructionStyle = int('00701501', 16)
  MPRThicknessType = int('00701502', 16)
  MPRSlabThickness = int('00701503', 16)
  MPRTopLeftHandCorner = int('00701505', 16)
  MPRViewWidthDirection = int('00701507', 16)
  MPRViewWidth = int('00701508', 16)
  NumberofVolumetricCurvePoints = int('0070150C', 16)
  VolumetricCurvePoints = int('0070150D', 16)
  MPRViewHeightDirection = int('00701511', 16)
  MPRViewHeight = int('00701512', 16)
  PresentationStateClassificationComponentSequence = int('00701801', 16)
  ComponentType = int('00701802', 16)
  ComponentInputSequence = int('00701803', 16)
  VolumetricPresentationInputIndex = int('00701804', 16)
  PresentationStateCompositorComponentSequence = int('00701805', 16)
  WeightingTransferFunctionSequence = int('00701806', 16)
  WeightingLookupTableDescriptor = int('00701807', 16)
  WeightingLookupTableData = int('00701808', 16)
  VolumetricAnnotationSequence = int('00701901', 16)
  ReferencedStructuredContextSequence = int('00701903', 16)
  ReferencedContentItem = int('00701904', 16)
  VolumetricPresentationInputAnnotationSequence = int('00701905', 16)
  AnnotationClipping = int('00701907', 16)
  PresentationAnimationStyle = int('00701A01', 16)
  RecommendedAnimationRate = int('00701A03', 16)
  AnimationCurveSequence = int('00701A04', 16)
  AnimationStepSize = int('00701A05', 16)
  HangingProtocolName = int('00720002', 16)
  HangingProtocolDescription = int('00720004', 16)
  HangingProtocolLevel = int('00720006', 16)
  HangingProtocolCreator = int('00720008', 16)
  HangingProtocolCreationDateTime = int('0072000A', 16)
  HangingProtocolDefinitionSequence = int('0072000C', 16)
  HangingProtocolUserIdentificationCodeSequence = int('0072000E', 16)
  HangingProtocolUserGroupName = int('00720010', 16)
  SourceHangingProtocolSequence = int('00720012', 16)
  NumberofPriorsReferenced = int('00720014', 16)
  ImageSetsSequence = int('00720020', 16)
  ImageSetSelectorSequence = int('00720022', 16)
  ImageSetSelectorUsageFlag = int('00720024', 16)
  SelectorAttribute = int('00720026', 16)
  SelectorValueNumber = int('00720028', 16)
  TimeBasedImageSetsSequence = int('00720030', 16)
  ImageSetNumber = int('00720032', 16)
  ImageSetSelectorCategory = int('00720034', 16)
  RelativeTime = int('00720038', 16)
  RelativeTimeUnits = int('0072003A', 16)
  AbstractPriorValue = int('0072003C', 16)
  AbstractPriorCodeSequence = int('0072003E', 16)
  ImageSetLabel = int('00720040', 16)
  SelectorAttributeVR = int('00720050', 16)
  SelectorSequencePointer = int('00720052', 16)
  SelectorSequencePointerPrivateCreator = int('00720054', 16)
  SelectorAttributePrivateCreator = int('00720056', 16)
  SelectorAEValue = int('0072005E', 16)
  SelectorASValue = int('0072005F', 16)
  SelectorATValue = int('00720060', 16)
  SelectorDAValue = int('00720061', 16)
  SelectorCSValue = int('00720062', 16)
  SelectorDTValue = int('00720063', 16)
  SelectorISValue = int('00720064', 16)
  SelectorOBValue = int('00720065', 16)
  SelectorLOValue = int('00720066', 16)
  SelectorOFValue = int('00720067', 16)
  SelectorLTValue = int('00720068', 16)
  SelectorOWValue = int('00720069', 16)
  SelectorPNValue = int('0072006A', 16)
  SelectorTMValue = int('0072006B', 16)
  SelectorSHValue = int('0072006C', 16)
  SelectorUNValue = int('0072006D', 16)
  SelectorSTValue = int('0072006E', 16)
  SelectorUCValue = int('0072006F', 16)
  SelectorUTValue = int('00720070', 16)
  SelectorURValue = int('00720071', 16)
  SelectorDSValue = int('00720072', 16)
  SelectorODValue = int('00720073', 16)
  SelectorFDValue = int('00720074', 16)
  SelectorOLValue = int('00720075', 16)
  SelectorFLValue = int('00720076', 16)
  SelectorULValue = int('00720078', 16)
  SelectorUSValue = int('0072007A', 16)
  SelectorSLValue = int('0072007C', 16)
  SelectorSSValue = int('0072007E', 16)
  SelectorUIValue = int('0072007F', 16)
  SelectorCodeSequenceValue = int('00720080', 16)
  NumberofScreens = int('00720100', 16)
  NominalScreenDefinitionSequence = int('00720102', 16)
  NumberofVerticalPixels = int('00720104', 16)
  NumberofHorizontalPixels = int('00720106', 16)
  DisplayEnvironmentSpatialPosition = int('00720108', 16)
  ScreenMinimumGrayscaleBitDepth = int('0072010A', 16)
  ScreenMinimumColorBitDepth = int('0072010C', 16)
  ApplicationMaximumRepaintTime = int('0072010E', 16)
  DisplaySetsSequence = int('00720200', 16)
  DisplaySetNumber = int('00720202', 16)
  DisplaySetLabel = int('00720203', 16)
  DisplaySetPresentationGroup = int('00720204', 16)
  DisplaySetPresentationGroupDescription = int('00720206', 16)
  PartialDataDisplayHandling = int('00720208', 16)
  SynchronizedScrollingSequence = int('00720210', 16)
  DisplaySetScrollingGroup = int('00720212', 16)
  NavigationIndicatorSequence = int('00720214', 16)
  NavigationDisplaySet = int('00720216', 16)
  ReferenceDisplaySets = int('00720218', 16)
  ImageBoxesSequence = int('00720300', 16)
  ImageBoxNumber = int('00720302', 16)
  ImageBoxLayoutType = int('00720304', 16)
  ImageBoxTileHorizontalDimension = int('00720306', 16)
  ImageBoxTileVerticalDimension = int('00720308', 16)
  ImageBoxScrollDirection = int('00720310', 16)
  ImageBoxSmallScrollType = int('00720312', 16)
  ImageBoxSmallScrollAmount = int('00720314', 16)
  ImageBoxLargeScrollType = int('00720316', 16)
  ImageBoxLargeScrollAmount = int('00720318', 16)
  ImageBoxOverlapPriority = int('00720320', 16)
  CineRelativetoRealTime = int('00720330', 16)
  FilterOperationsSequence = int('00720400', 16)
  FilterbyCategory = int('00720402', 16)
  FilterbyAttributePresence = int('00720404', 16)
  FilterbyOperator = int('00720406', 16)
  StructuredDisplayBackgroundCIELabValue = int('00720420', 16)
  EmptyImageBoxCIELabValue = int('00720421', 16)
  StructuredDisplayImageBoxSequence = int('00720422', 16)
  StructuredDisplayTextBoxSequence = int('00720424', 16)
  ReferencedFirstFrameSequence = int('00720427', 16)
  ImageBoxSynchronizationSequence = int('00720430', 16)
  SynchronizedImageBoxList = int('00720432', 16)
  TypeofSynchronization = int('00720434', 16)
  BlendingOperationType = int('00720500', 16)
  ReformattingOperationType = int('00720510', 16)
  ReformattingThickness = int('00720512', 16)
  ReformattingInterval = int('00720514', 16)
  ReformattingOperationInitialViewDirection = int('00720516', 16)
  ThreeDRenderingType = int('00720520', 16)
  SortingOperationsSequence = int('00720600', 16)
  SortbyCategory = int('00720602', 16)
  SortingDirection = int('00720604', 16)
  DisplaySetPatientOrientation = int('00720700', 16)
  VOIType = int('00720702', 16)
  PseudoColorType = int('00720704', 16)
  PseudoColorPaletteInstanceReferenceSequence = int('00720705', 16)
  ShowGrayscaleInverted = int('00720706', 16)
  ShowImageTrueSizeFlag = int('00720710', 16)
  ShowGraphicAnnotationFlag = int('00720712', 16)
  ShowPatientDemographicsFlag = int('00720714', 16)
  ShowAcquisitionTechniquesFlag = int('00720716', 16)
  DisplaySetHorizontalJustification = int('00720717', 16)
  DisplaySetVerticalJustification = int('00720718', 16)
  ContinuationStartMeterset = int('00740120', 16)
  ContinuationEndMeterset = int('00740121', 16)
  ProcedureStepState = int('00741000', 16)
  ProcedureStepProgressInformationSequence = int('00741002', 16)
  ProcedureStepProgress = int('00741004', 16)
  ProcedureStepProgressDescription = int('00741006', 16)
  ProcedureStepCommunicationsURISequence = int('00741008', 16)
  ContactURI = int('0074100A', 16)
  ContactDisplayName = int('0074100C', 16)
  ProcedureStepDiscontinuationReasonCodeSequence = int('0074100E', 16)
  BeamTaskSequence = int('00741020', 16)
  BeamTaskType = int('00741022', 16)
  BeamOrderIndexTrial = int('00741024', 16)
  AutosequenceFlag = int('00741025', 16)
  TableTopVerticalAdjustedPosition = int('00741026', 16)
  TableTopLongitudinalAdjustedPosition = int('00741027', 16)
  TableTopLateralAdjustedPosition = int('00741028', 16)
  PatientSupportAdjustedAngle = int('0074102A', 16)
  TableTopEccentricAdjustedAngle = int('0074102B', 16)
  TableTopPitchAdjustedAngle = int('0074102C', 16)
  TableTopRollAdjustedAngle = int('0074102D', 16)
  DeliveryVerificationImageSequence = int('00741030', 16)
  VerificationImageTiming = int('00741032', 16)
  DoubleExposureFlag = int('00741034', 16)
  DoubleExposureOrdering = int('00741036', 16)
  DoubleExposureMetersetTrial = int('00741038', 16)
  DoubleExposureFieldDeltaTrial = int('0074103A', 16)
  RelatedReferenceRTImageSequence = int('00741040', 16)
  GeneralMachineVerificationSequence = int('00741042', 16)
  ConventionalMachineVerificationSequence = int('00741044', 16)
  IonMachineVerificationSequence = int('00741046', 16)
  FailedAttributesSequence = int('00741048', 16)
  OverriddenAttributesSequence = int('0074104A', 16)
  ConventionalControlPointVerificationSequence = int('0074104C', 16)
  IonControlPointVerificationSequence = int('0074104E', 16)
  AttributeOccurrenceSequence = int('00741050', 16)
  AttributeOccurrencePointer = int('00741052', 16)
  AttributeItemSelector = int('00741054', 16)
  AttributeOccurrencePrivateCreator = int('00741056', 16)
  SelectorSequencePointerItems = int('00741057', 16)
  ScheduledProcedureStepPriority = int('00741200', 16)
  WorklistLabel = int('00741202', 16)
  ProcedureStepLabel = int('00741204', 16)
  ScheduledProcessingParametersSequence = int('00741210', 16)
  PerformedProcessingParametersSequence = int('00741212', 16)
  UnifiedProcedureStepPerformedProcedureSequence = int('00741216', 16)
  RelatedProcedureStepSequence = int('00741220', 16)
  ProcedureStepRelationshipType = int('00741222', 16)
  ReplacedProcedureStepSequence = int('00741224', 16)
  DeletionLock = int('00741230', 16)
  ReceivingAE = int('00741234', 16)
  RequestingAE = int('00741236', 16)
  ReasonforCancellation = int('00741238', 16)
  SCPStatus = int('00741242', 16)
  SubscriptionListStatus = int('00741244', 16)
  UnifiedProcedureStepListStatus = int('00741246', 16)
  BeamOrderIndex = int('00741324', 16)
  DoubleExposureMeterset = int('00741338', 16)
  DoubleExposureFieldDelta = int('0074133A', 16)
  BrachyTaskSequence = int('00741401', 16)
  ContinuationStartTotalReferenceAirKerma = int('00741402', 16)
  ContinuationEndTotalReferenceAirKerma = int('00741403', 16)
  ContinuationPulseNumber = int('00741404', 16)
  ChannelDeliveryOrderSequence = int('00741405', 16)
  ReferencedChannelNumber = int('00741406', 16)
  StartCumulativeTimeWeight = int('00741407', 16)
  EndCumulativeTimeWeight = int('00741408', 16)
  OmittedChannelSequence = int('00741409', 16)
  ReasonforChannelOmission = int('0074140A', 16)
  ReasonforChannelOmissionDescription = int('0074140B', 16)
  ChannelDeliveryOrderIndex = int('0074140C', 16)
  ChannelDeliveryContinuationSequence = int('0074140D', 16)
  OmittedApplicationSetupSequence = int('0074140E', 16)
  ImplantAssemblyTemplateName = int('00760001', 16)
  ImplantAssemblyTemplateIssuer = int('00760003', 16)
  ImplantAssemblyTemplateVersion = int('00760006', 16)
  ReplacedImplantAssemblyTemplateSequence = int('00760008', 16)
  ImplantAssemblyTemplateType = int('0076000A', 16)
  OriginalImplantAssemblyTemplateSequence = int('0076000C', 16)
  DerivationImplantAssemblyTemplateSequence = int('0076000E', 16)
  ImplantAssemblyTemplateTargetAnatomySequence = int('00760010', 16)
  ProcedureTypeCodeSequence = int('00760020', 16)
  SurgicalTechnique = int('00760030', 16)
  ComponentTypesSequence = int('00760032', 16)
  ComponentTypeCodeSequence = int('00760034', 16)
  ExclusiveComponentType = int('00760036', 16)
  MandatoryComponentType = int('00760038', 16)
  ComponentSequence = int('00760040', 16)
  ComponentID = int('00760055', 16)
  ComponentAssemblySequence = int('00760060', 16)
  Component1ReferencedID = int('00760070', 16)
  Component1ReferencedMatingFeatureSetID = int('00760080', 16)
  Component1ReferencedMatingFeatureID = int('00760090', 16)
  Component2ReferencedID = int('007600A0', 16)
  Component2ReferencedMatingFeatureSetID = int('007600B0', 16)
  Component2ReferencedMatingFeatureID = int('007600C0', 16)
  ImplantTemplateGroupName = int('00780001', 16)
  ImplantTemplateGroupDescription = int('00780010', 16)
  ImplantTemplateGroupIssuer = int('00780020', 16)
  ImplantTemplateGroupVersion = int('00780024', 16)
  ReplacedImplantTemplateGroupSequence = int('00780026', 16)
  ImplantTemplateGroupTargetAnatomySequence = int('00780028', 16)
  ImplantTemplateGroupMembersSequence = int('0078002A', 16)
  ImplantTemplateGroupMemberID = int('0078002E', 16)
  ThreeDImplantTemplateGroupMemberMatchingPoint = int('00780050', 16)
  ThreeDImplantTemplateGroupMemberMatchingAxes = int('00780060', 16)
  ImplantTemplateGroupMemberMatching2DCoordinatesSequence = int(
      '00780070', 16)
  TwoDImplantTemplateGroupMemberMatchingPoint = int('00780090', 16)
  TwoDImplantTemplateGroupMemberMatchingAxes = int('007800A0', 16)
  ImplantTemplateGroupVariationDimensionSequence = int('007800B0', 16)
  ImplantTemplateGroupVariationDimensionName = int('007800B2', 16)
  ImplantTemplateGroupVariationDimensionRankSequence = int('007800B4', 16)
  ReferencedImplantTemplateGroupMemberID = int('007800B6', 16)
  ImplantTemplateGroupVariationDimensionRank = int('007800B8', 16)
  SurfaceScanAcquisitionTypeCodeSequence = int('00800001', 16)
  SurfaceScanModeCodeSequence = int('00800002', 16)
  RegistrationMethodCodeSequence = int('00800003', 16)
  ShotDurationTime = int('00800004', 16)
  ShotOffsetTime = int('00800005', 16)
  SurfacePointPresentationValueData = int('00800006', 16)
  SurfacePointColorCIELabValueData = int('00800007', 16)
  UVMappingSequence = int('00800008', 16)
  TextureLabel = int('00800009', 16)
  UValueData = int('00800010', 16)
  VValueData = int('00800011', 16)
  ReferencedTextureSequence = int('00800012', 16)
  ReferencedSurfaceDataSequence = int('00800013', 16)
  AssessmentSummary = int('00820001', 16)
  AssessmentSummaryDescription = int('00820003', 16)
  AssessedSOPInstanceSequence = int('00820004', 16)
  ReferencedComparisonSOPInstanceSequence = int('00820005', 16)
  NumberofAssessmentObservations = int('00820006', 16)
  AssessmentObservationsSequence = int('00820007', 16)
  ObservationSignificance = int('00820008', 16)
  ObservationDescription = int('0082000A', 16)
  StructuredConstraintObservationSequence = int('0082000C', 16)
  AssessedAttributeValueSequence = int('00820010', 16)
  AssessmentSetID = int('00820016', 16)
  AssessmentRequesterSequence = int('00820017', 16)
  SelectorAttributeName = int('00820018', 16)
  SelectorAttributeKeyword = int('00820019', 16)
  AssessmentTypeCodeSequence = int('00820021', 16)
  ObservationBasisCodeSequence = int('00820022', 16)
  AssessmentLabel = int('00820023', 16)
  ConstraintType = int('00820032', 16)
  SpecificationSelectionGuidance = int('00820033', 16)
  ConstraintValueSequence = int('00820034', 16)
  RecommendedDefaultValueSequence = int('00820035', 16)
  ConstraintViolationSignificance = int('00820036', 16)
  ConstraintViolationCondition = int('00820037', 16)
  StorageMediaFilesetID = int('00880130', 16)
  StorageMediaFilesetUID = int('00880140', 16)
  IconImageSequence = int('00880200', 16)
  TopicTitle = int('00880904', 16)
  TopicSubject = int('00880906', 16)
  TopicAuthor = int('00880910', 16)
  TopicKeywords = int('00880912', 16)
  SOPInstanceStatus = int('01000410', 16)
  SOPAuthorizationDateTime = int('01000420', 16)
  SOPAuthorizationComment = int('01000424', 16)
  AuthorizationEquipmentCertificationNumber = int('01000426', 16)
  MACIDNumber = int('04000005', 16)
  MACCalculationTransferSyntaxUID = int('04000010', 16)
  MACAlgorithm = int('04000015', 16)
  DataElementsSigned = int('04000020', 16)
  DigitalSignatureUID = int('04000100', 16)
  DigitalSignatureDateTime = int('04000105', 16)
  CertificateType = int('04000110', 16)
  CertificateofSigner = int('04000115', 16)
  Signature = int('04000120', 16)
  CertifiedTimestampType = int('04000305', 16)
  CertifiedTimestamp = int('04000310', 16)
  DigitalSignaturePurposeCodeSequence = int('04000401', 16)
  ReferencedDigitalSignatureSequence = int('04000402', 16)
  ReferencedSOPInstanceMACSequence = int('04000403', 16)
  MAC = int('04000404', 16)
  EncryptedAttributesSequence = int('04000500', 16)
  EncryptedContentTransferSyntaxUID = int('04000510', 16)
  EncryptedContent = int('04000520', 16)
  ModifiedAttributesSequence = int('04000550', 16)
  OriginalAttributesSequence = int('04000561', 16)
  AttributeModificationDateTime = int('04000562', 16)
  ModifyingSystem = int('04000563', 16)
  SourceofPreviousValues = int('04000564', 16)
  ReasonfortheAttributeModification = int('04000565', 16)
  NumberofCopies = int('20000010', 16)
  PrinterConfigurationSequence = int('2000001E', 16)
  PrintPriority = int('20000020', 16)
  MediumType = int('20000030', 16)
  FilmDestination = int('20000040', 16)
  FilmSessionLabel = int('20000050', 16)
  MemoryAllocation = int('20000060', 16)
  MaximumMemoryAllocation = int('20000061', 16)
  ColorImagePrintingFlag = int('20000062', 16)
  CollationFlag = int('20000063', 16)
  AnnotationFlag = int('20000065', 16)
  ImageOverlayFlag = int('20000067', 16)
  PresentationLUTFlag = int('20000069', 16)
  ImageBoxPresentationLUTFlag = int('2000006A', 16)
  MemoryBitDepth = int('200000A0', 16)
  PrintingBitDepth = int('200000A1', 16)
  MediaInstalledSequence = int('200000A2', 16)
  OtherMediaAvailableSequence = int('200000A4', 16)
  SupportedImageDisplayFormatsSequence = int('200000A8', 16)
  ReferencedFilmBoxSequence = int('20000500', 16)
  ReferencedStoredPrintSequence = int('20000510', 16)
  ImageDisplayFormat = int('20100010', 16)
  AnnotationDisplayFormatID = int('20100030', 16)
  FilmOrientation = int('20100040', 16)
  FilmSizeID = int('20100050', 16)
  PrinterResolutionID = int('20100052', 16)
  DefaultPrinterResolutionID = int('20100054', 16)
  MagnificationType = int('20100060', 16)
  SmoothingType = int('20100080', 16)
  DefaultMagnificationType = int('201000A6', 16)
  OtherMagnificationTypesAvailable = int('201000A7', 16)
  DefaultSmoothingType = int('201000A8', 16)
  OtherSmoothingTypesAvailable = int('201000A9', 16)
  BorderDensity = int('20100100', 16)
  EmptyImageDensity = int('20100110', 16)
  MinDensity = int('20100120', 16)
  MaxDensity = int('20100130', 16)
  Trim = int('20100140', 16)
  ConfigurationInformation = int('20100150', 16)
  ConfigurationInformationDescription = int('20100152', 16)
  MaximumCollatedFilms = int('20100154', 16)
  Illumination = int('2010015E', 16)
  ReflectedAmbientLight = int('20100160', 16)
  PrinterPixelSpacing = int('20100376', 16)
  ReferencedFilmSessionSequence = int('20100500', 16)
  ReferencedImageBoxSequence = int('20100510', 16)
  ReferencedBasicAnnotationBoxSequence = int('20100520', 16)
  ImageBoxPosition = int('20200010', 16)
  Polarity = int('20200020', 16)
  RequestedImageSize = int('20200030', 16)
  RequestedDecimateCropBehavior = int('20200040', 16)
  RequestedResolutionID = int('20200050', 16)
  RequestedImageSizeFlag = int('202000A0', 16)
  DecimateCropResult = int('202000A2', 16)
  BasicGrayscaleImageSequence = int('20200110', 16)
  BasicColorImageSequence = int('20200111', 16)
  ReferencedImageOverlayBoxSequence = int('20200130', 16)
  ReferencedVOILUTBoxSequence = int('20200140', 16)
  AnnotationPosition = int('20300010', 16)
  TextString = int('20300020', 16)
  ReferencedOverlayPlaneSequence = int('20400010', 16)
  ReferencedOverlayPlaneGroups = int('20400011', 16)
  OverlayPixelDataSequence = int('20400020', 16)
  OverlayMagnificationType = int('20400060', 16)
  OverlaySmoothingType = int('20400070', 16)
  OverlayorImageMagnification = int('20400072', 16)
  MagnifytoNumberofColumns = int('20400074', 16)
  OverlayForegroundDensity = int('20400080', 16)
  OverlayBackgroundDensity = int('20400082', 16)
  OverlayMode = int('20400090', 16)
  ThresholdDensity = int('20400100', 16)
  ReferencedImageBoxSequenceRetired = int('20400500', 16)
  PresentationLUTSequence = int('20500010', 16)
  PresentationLUTShape = int('20500020', 16)
  ReferencedPresentationLUTSequence = int('20500500', 16)
  PrintJobID = int('21000010', 16)
  ExecutionStatus = int('21000020', 16)
  ExecutionStatusInfo = int('21000030', 16)
  CreationDate = int('21000040', 16)
  CreationTime = int('21000050', 16)
  Originator = int('21000070', 16)
  DestinationAE = int('21000140', 16)
  OwnerID = int('21000160', 16)
  NumberofFilms = int('21000170', 16)
  ReferencedPrintJobSequencePullStoredPrint = int('21000500', 16)
  PrinterStatus = int('21100010', 16)
  PrinterStatusInfo = int('21100020', 16)
  PrinterName = int('21100030', 16)
  PrintQueueID = int('21100099', 16)
  QueueStatus = int('21200010', 16)
  PrintJobDescriptionSequence = int('21200050', 16)
  ReferencedPrintJobSequence = int('21200070', 16)
  PrintManagementCapabilitiesSequence = int('21300010', 16)
  PrinterCharacteristicsSequence = int('21300015', 16)
  FilmBoxContentSequence = int('21300030', 16)
  ImageBoxContentSequence = int('21300040', 16)
  AnnotationContentSequence = int('21300050', 16)
  ImageOverlayBoxContentSequence = int('21300060', 16)
  PresentationLUTContentSequence = int('21300080', 16)
  ProposedStudySequence = int('213000A0', 16)
  OriginalImageSequence = int('213000C0', 16)
  LabelUsingInformationExtractedFromInstances = int('22000001', 16)
  LabelText = int('22000002', 16)
  LabelStyleSelection = int('22000003', 16)
  MediaDisposition = int('22000004', 16)
  BarcodeValue = int('22000005', 16)
  BarcodeSymbology = int('22000006', 16)
  AllowMediaSplitting = int('22000007', 16)
  IncludeNonDICOMObjects = int('22000008', 16)
  IncludeDisplayApplication = int('22000009', 16)
  PreserveCompositeInstancesAfterMediaCreation = int('2200000A', 16)
  TotalNumberofPiecesofMediaCreated = int('2200000B', 16)
  RequestedMediaApplicationProfile = int('2200000C', 16)
  ReferencedStorageMediaSequence = int('2200000D', 16)
  FailureAttributes = int('2200000E', 16)
  AllowLossyCompression = int('2200000F', 16)
  RequestPriority = int('22000020', 16)
  RTImageLabel = int('30020002', 16)
  RTImageName = int('30020003', 16)
  RTImageDescription = int('30020004', 16)
  ReportedValuesOrigin = int('3002000A', 16)
  RTImagePlane = int('3002000C', 16)
  XRayImageReceptorTranslation = int('3002000D', 16)
  XRayImageReceptorAngle = int('3002000E', 16)
  RTImageOrientation = int('30020010', 16)
  ImagePlanePixelSpacing = int('30020011', 16)
  RTImagePosition = int('30020012', 16)
  RadiationMachineName = int('30020020', 16)
  RadiationMachineSAD = int('30020022', 16)
  RadiationMachineSSD = int('30020024', 16)
  RTImageSID = int('30020026', 16)
  SourcetoReferenceObjectDistance = int('30020028', 16)
  FractionNumber = int('30020029', 16)
  ExposureSequence = int('30020030', 16)
  MetersetExposure = int('30020032', 16)
  DiaphragmPosition = int('30020034', 16)
  FluenceMapSequence = int('30020040', 16)
  FluenceDataSource = int('30020041', 16)
  FluenceDataScale = int('30020042', 16)
  PrimaryFluenceModeSequence = int('30020050', 16)
  FluenceMode = int('30020051', 16)
  FluenceModeID = int('30020052', 16)
  DVHType = int('30040001', 16)
  DoseUnits = int('30040002', 16)
  DoseType = int('30040004', 16)
  SpatialTransformofDose = int('30040005', 16)
  DoseComment = int('30040006', 16)
  NormalizationPoint = int('30040008', 16)
  DoseSummationType = int('3004000A', 16)
  GridFrameOffsetVector = int('3004000C', 16)
  DoseGridScaling = int('3004000E', 16)
  RTDoseROISequence = int('30040010', 16)
  DoseValue = int('30040012', 16)
  TissueHeterogeneityCorrection = int('30040014', 16)
  DVHNormalizationPoint = int('30040040', 16)
  DVHNormalizationDoseValue = int('30040042', 16)
  DVHSequence = int('30040050', 16)
  DVHDoseScaling = int('30040052', 16)
  DVHVolumeUnits = int('30040054', 16)
  DVHNumberofBins = int('30040056', 16)
  DVHData = int('30040058', 16)
  DVHReferencedROISequence = int('30040060', 16)
  DVHROIContributionType = int('30040062', 16)
  DVHMinimumDose = int('30040070', 16)
  DVHMaximumDose = int('30040072', 16)
  DVHMeanDose = int('30040074', 16)
  StructureSetLabel = int('30060002', 16)
  StructureSetName = int('30060004', 16)
  StructureSetDescription = int('30060006', 16)
  StructureSetDate = int('30060008', 16)
  StructureSetTime = int('30060009', 16)
  ReferencedFrameofReferenceSequence = int('30060010', 16)
  RTReferencedStudySequence = int('30060012', 16)
  RTReferencedSeriesSequence = int('30060014', 16)
  ContourImageSequence = int('30060016', 16)
  PredecessorStructureSetSequence = int('30060018', 16)
  StructureSetROISequence = int('30060020', 16)
  ROINumber = int('30060022', 16)
  ReferencedFrameofReferenceUID = int('30060024', 16)
  ROIName = int('30060026', 16)
  ROIDescription = int('30060028', 16)
  ROIDisplayColor = int('3006002A', 16)
  ROIVolume = int('3006002C', 16)
  RTRelatedROISequence = int('30060030', 16)
  RTROIRelationship = int('30060033', 16)
  ROIGenerationAlgorithm = int('30060036', 16)
  ROIGenerationDescription = int('30060038', 16)
  ROIContourSequence = int('30060039', 16)
  ContourSequence = int('30060040', 16)
  ContourGeometricType = int('30060042', 16)
  ContourSlabThickness = int('30060044', 16)
  ContourOffsetVector = int('30060045', 16)
  NumberofContourPoints = int('30060046', 16)
  ContourNumber = int('30060048', 16)
  AttachedContours = int('30060049', 16)
  ContourData = int('30060050', 16)
  RTROIObservationsSequence = int('30060080', 16)
  ObservationNumber = int('30060082', 16)
  ReferencedROINumber = int('30060084', 16)
  ROIObservationLabel = int('30060085', 16)
  RTROIIdentificationCodeSequence = int('30060086', 16)
  ROIObservationDescription = int('30060088', 16)
  RelatedRTROIObservationsSequence = int('300600A0', 16)
  RTROIInterpretedType = int('300600A4', 16)
  ROIInterpreter = int('300600A6', 16)
  ROIPhysicalPropertiesSequence = int('300600B0', 16)
  ROIPhysicalProperty = int('300600B2', 16)
  ROIPhysicalPropertyValue = int('300600B4', 16)
  ROIElementalCompositionSequence = int('300600B6', 16)
  ROIElementalCompositionAtomicNumber = int('300600B7', 16)
  ROIElementalCompositionAtomicMassFraction = int('300600B8', 16)
  AdditionalRTROIIdentificationCodeSequence = int('300600B9', 16)
  FrameofReferenceRelationshipSequence = int('300600C0', 16)
  RelatedFrameofReferenceUID = int('300600C2', 16)
  FrameofReferenceTransformationType = int('300600C4', 16)
  FrameofReferenceTransformationMatrix = int('300600C6', 16)
  FrameofReferenceTransformationComment = int('300600C8', 16)
  MeasuredDoseReferenceSequence = int('30080010', 16)
  MeasuredDoseDescription = int('30080012', 16)
  MeasuredDoseType = int('30080014', 16)
  MeasuredDoseValue = int('30080016', 16)
  TreatmentSessionBeamSequence = int('30080020', 16)
  TreatmentSessionIonBeamSequence = int('30080021', 16)
  CurrentFractionNumber = int('30080022', 16)
  TreatmentControlPointDate = int('30080024', 16)
  TreatmentControlPointTime = int('30080025', 16)
  TreatmentTerminationStatus = int('3008002A', 16)
  TreatmentTerminationCode = int('3008002B', 16)
  TreatmentVerificationStatus = int('3008002C', 16)
  ReferencedTreatmentRecordSequence = int('30080030', 16)
  SpecifiedPrimaryMeterset = int('30080032', 16)
  SpecifiedSecondaryMeterset = int('30080033', 16)
  DeliveredPrimaryMeterset = int('30080036', 16)
  DeliveredSecondaryMeterset = int('30080037', 16)
  SpecifiedTreatmentTime = int('3008003A', 16)
  DeliveredTreatmentTime = int('3008003B', 16)
  ControlPointDeliverySequence = int('30080040', 16)
  IonControlPointDeliverySequence = int('30080041', 16)
  SpecifiedMeterset = int('30080042', 16)
  DeliveredMeterset = int('30080044', 16)
  MetersetRateSet = int('30080045', 16)
  MetersetRateDelivered = int('30080046', 16)
  ScanSpotMetersetsDelivered = int('30080047', 16)
  DoseRateDelivered = int('30080048', 16)
  TreatmentSummaryCalculatedDoseReferenceSequence = int('30080050', 16)
  CumulativeDosetoDoseReference = int('30080052', 16)
  FirstTreatmentDate = int('30080054', 16)
  MostRecentTreatmentDate = int('30080056', 16)
  NumberofFractionsDelivered = int('3008005A', 16)
  OverrideSequence = int('30080060', 16)
  ParameterSequencePointer = int('30080061', 16)
  OverrideParameterPointer = int('30080062', 16)
  ParameterItemIndex = int('30080063', 16)
  MeasuredDoseReferenceNumber = int('30080064', 16)
  ParameterPointer = int('30080065', 16)
  OverrideReason = int('30080066', 16)
  CorrectedParameterSequence = int('30080068', 16)
  CorrectionValue = int('3008006A', 16)
  CalculatedDoseReferenceSequence = int('30080070', 16)
  CalculatedDoseReferenceNumber = int('30080072', 16)
  CalculatedDoseReferenceDescription = int('30080074', 16)
  CalculatedDoseReferenceDoseValue = int('30080076', 16)
  StartMeterset = int('30080078', 16)
  EndMeterset = int('3008007A', 16)
  ReferencedMeasuredDoseReferenceSequence = int('30080080', 16)
  ReferencedMeasuredDoseReferenceNumber = int('30080082', 16)
  ReferencedCalculatedDoseReferenceSequence = int('30080090', 16)
  ReferencedCalculatedDoseReferenceNumber = int('30080092', 16)
  BeamLimitingDeviceLeafPairsSequence = int('300800A0', 16)
  RecordedWedgeSequence = int('300800B0', 16)
  RecordedCompensatorSequence = int('300800C0', 16)
  RecordedBlockSequence = int('300800D0', 16)
  TreatmentSummaryMeasuredDoseReferenceSequence = int('300800E0', 16)
  RecordedSnoutSequence = int('300800F0', 16)
  RecordedRangeShifterSequence = int('300800F2', 16)
  RecordedLateralSpreadingDeviceSequence = int('300800F4', 16)
  RecordedRangeModulatorSequence = int('300800F6', 16)
  RecordedSourceSequence = int('30080100', 16)
  SourceSerialNumber = int('30080105', 16)
  TreatmentSessionApplicationSetupSequence = int('30080110', 16)
  ApplicationSetupCheck = int('30080116', 16)
  RecordedBrachyAccessoryDeviceSequence = int('30080120', 16)
  ReferencedBrachyAccessoryDeviceNumber = int('30080122', 16)
  RecordedChannelSequence = int('30080130', 16)
  SpecifiedChannelTotalTime = int('30080132', 16)
  DeliveredChannelTotalTime = int('30080134', 16)
  SpecifiedNumberofPulses = int('30080136', 16)
  DeliveredNumberofPulses = int('30080138', 16)
  SpecifiedPulseRepetitionInterval = int('3008013A', 16)
  DeliveredPulseRepetitionInterval = int('3008013C', 16)
  RecordedSourceApplicatorSequence = int('30080140', 16)
  ReferencedSourceApplicatorNumber = int('30080142', 16)
  RecordedChannelShieldSequence = int('30080150', 16)
  ReferencedChannelShieldNumber = int('30080152', 16)
  BrachyControlPointDeliveredSequence = int('30080160', 16)
  SafePositionExitDate = int('30080162', 16)
  SafePositionExitTime = int('30080164', 16)
  SafePositionReturnDate = int('30080166', 16)
  SafePositionReturnTime = int('30080168', 16)
  PulseSpecificBrachyControlPointDeliveredSequence = int('30080171', 16)
  PulseNumber = int('30080172', 16)
  BrachyPulseControlPointDeliveredSequence = int('30080173', 16)
  CurrentTreatmentStatus = int('30080200', 16)
  TreatmentStatusComment = int('30080202', 16)
  FractionGroupSummarySequence = int('30080220', 16)
  ReferencedFractionNumber = int('30080223', 16)
  FractionGroupType = int('30080224', 16)
  BeamStopperPosition = int('30080230', 16)
  FractionStatusSummarySequence = int('30080240', 16)
  TreatmentDate = int('30080250', 16)
  TreatmentTime = int('30080251', 16)
  RTPlanLabel = int('300A0002', 16)
  RTPlanName = int('300A0003', 16)
  RTPlanDescription = int('300A0004', 16)
  RTPlanDate = int('300A0006', 16)
  RTPlanTime = int('300A0007', 16)
  TreatmentProtocols = int('300A0009', 16)
  PlanIntent = int('300A000A', 16)
  TreatmentSites = int('300A000B', 16)
  RTPlanGeometry = int('300A000C', 16)
  PrescriptionDescription = int('300A000E', 16)
  DoseReferenceSequence = int('300A0010', 16)
  DoseReferenceNumber = int('300A0012', 16)
  DoseReferenceUID = int('300A0013', 16)
  DoseReferenceStructureType = int('300A0014', 16)
  NominalBeamEnergyUnit = int('300A0015', 16)
  DoseReferenceDescription = int('300A0016', 16)
  DoseReferencePointCoordinates = int('300A0018', 16)
  NominalPriorDose = int('300A001A', 16)
  DoseReferenceType = int('300A0020', 16)
  ConstraintWeight = int('300A0021', 16)
  DeliveryWarningDose = int('300A0022', 16)
  DeliveryMaximumDose = int('300A0023', 16)
  TargetMinimumDose = int('300A0025', 16)
  TargetPrescriptionDose = int('300A0026', 16)
  TargetMaximumDose = int('300A0027', 16)
  TargetUnderdoseVolumeFraction = int('300A0028', 16)
  OrganatRiskFullvolumeDose = int('300A002A', 16)
  OrganatRiskLimitDose = int('300A002B', 16)
  OrganatRiskMaximumDose = int('300A002C', 16)
  OrganatRiskOverdoseVolumeFraction = int('300A002D', 16)
  ToleranceTableSequence = int('300A0040', 16)
  ToleranceTableNumber = int('300A0042', 16)
  ToleranceTableLabel = int('300A0043', 16)
  GantryAngleTolerance = int('300A0044', 16)
  BeamLimitingDeviceAngleTolerance = int('300A0046', 16)
  BeamLimitingDeviceToleranceSequence = int('300A0048', 16)
  BeamLimitingDevicePositionTolerance = int('300A004A', 16)
  SnoutPositionTolerance = int('300A004B', 16)
  PatientSupportAngleTolerance = int('300A004C', 16)
  TableTopEccentricAngleTolerance = int('300A004E', 16)
  TableTopPitchAngleTolerance = int('300A004F', 16)
  TableTopRollAngleTolerance = int('300A0050', 16)
  TableTopVerticalPositionTolerance = int('300A0051', 16)
  TableTopLongitudinalPositionTolerance = int('300A0052', 16)
  TableTopLateralPositionTolerance = int('300A0053', 16)
  RTPlanRelationship = int('300A0055', 16)
  FractionGroupSequence = int('300A0070', 16)
  FractionGroupNumber = int('300A0071', 16)
  FractionGroupDescription = int('300A0072', 16)
  NumberofFractionsPlanned = int('300A0078', 16)
  NumberofFractionPatternDigitsPerDay = int('300A0079', 16)
  RepeatFractionCycleLength = int('300A007A', 16)
  FractionPattern = int('300A007B', 16)
  NumberofBeams = int('300A0080', 16)
  BeamDoseSpecificationPoint = int('300A0082', 16)
  BeamDose = int('300A0084', 16)
  BeamMeterset = int('300A0086', 16)
  BeamDosePointDepth = int('300A0088', 16)
  BeamDosePointEquivalentDepth = int('300A0089', 16)
  BeamDosePointSSD = int('300A008A', 16)
  BeamDoseMeaning = int('300A008B', 16)
  BeamDoseVerificationControlPointSequence = int('300A008C', 16)
  AverageBeamDosePointDepth = int('300A008D', 16)
  AverageBeamDosePointEquivalentDepth = int('300A008E', 16)
  AverageBeamDosePointSSD = int('300A008F', 16)
  BeamDoseType = int('300A0090', 16)
  AlternateBeamDose = int('300A0091', 16)
  AlternateBeamDoseType = int('300A0092', 16)
  NumberofBrachyApplicationSetups = int('300A00A0', 16)
  BrachyApplicationSetupDoseSpecificationPoint = int('300A00A2', 16)
  BrachyApplicationSetupDose = int('300A00A4', 16)
  BeamSequence = int('300A00B0', 16)
  TreatmentMachineName = int('300A00B2', 16)
  PrimaryDosimeterUnit = int('300A00B3', 16)
  SourceAxisDistance = int('300A00B4', 16)
  BeamLimitingDeviceSequence = int('300A00B6', 16)
  RTBeamLimitingDeviceType = int('300A00B8', 16)
  SourcetoBeamLimitingDeviceDistance = int('300A00BA', 16)
  IsocentertoBeamLimitingDeviceDistance = int('300A00BB', 16)
  NumberofLeafJawPairs = int('300A00BC', 16)
  LeafPositionBoundaries = int('300A00BE', 16)
  BeamNumber = int('300A00C0', 16)
  BeamName = int('300A00C2', 16)
  BeamDescription = int('300A00C3', 16)
  BeamType = int('300A00C4', 16)
  BeamDeliveryDurationLimit = int('300A00C5', 16)
  RadiationType = int('300A00C6', 16)
  HighDoseTechniqueType = int('300A00C7', 16)
  ReferenceImageNumber = int('300A00C8', 16)
  PlannedVerificationImageSequence = int('300A00CA', 16)
  ImagingDeviceSpecificAcquisitionParameters = int('300A00CC', 16)
  TreatmentDeliveryType = int('300A00CE', 16)
  NumberofWedges = int('300A00D0', 16)
  WedgeSequence = int('300A00D1', 16)
  WedgeNumber = int('300A00D2', 16)
  WedgeType = int('300A00D3', 16)
  WedgeID = int('300A00D4', 16)
  WedgeAngle = int('300A00D5', 16)
  WedgeFactor = int('300A00D6', 16)
  TotalWedgeTrayWaterEquivalentThickness = int('300A00D7', 16)
  WedgeOrientation = int('300A00D8', 16)
  IsocentertoWedgeTrayDistance = int('300A00D9', 16)
  SourcetoWedgeTrayDistance = int('300A00DA', 16)
  WedgeThinEdgePosition = int('300A00DB', 16)
  BolusID = int('300A00DC', 16)
  BolusDescription = int('300A00DD', 16)
  EffectiveWedgeAngle = int('300A00DE', 16)
  NumberofCompensators = int('300A00E0', 16)
  MaterialID = int('300A00E1', 16)
  TotalCompensatorTrayFactor = int('300A00E2', 16)
  CompensatorSequence = int('300A00E3', 16)
  CompensatorNumber = int('300A00E4', 16)
  CompensatorID = int('300A00E5', 16)
  SourcetoCompensatorTrayDistance = int('300A00E6', 16)
  CompensatorRows = int('300A00E7', 16)
  CompensatorColumns = int('300A00E8', 16)
  CompensatorPixelSpacing = int('300A00E9', 16)
  CompensatorPosition = int('300A00EA', 16)
  CompensatorTransmissionData = int('300A00EB', 16)
  CompensatorThicknessData = int('300A00EC', 16)
  NumberofBoli = int('300A00ED', 16)
  CompensatorType = int('300A00EE', 16)
  CompensatorTrayID = int('300A00EF', 16)
  NumberofBlocks = int('300A00F0', 16)
  TotalBlockTrayFactor = int('300A00F2', 16)
  TotalBlockTrayWaterEquivalentThickness = int('300A00F3', 16)
  BlockSequence = int('300A00F4', 16)
  BlockTrayID = int('300A00F5', 16)
  SourcetoBlockTrayDistance = int('300A00F6', 16)
  IsocentertoBlockTrayDistance = int('300A00F7', 16)
  BlockType = int('300A00F8', 16)
  AccessoryCode = int('300A00F9', 16)
  BlockDivergence = int('300A00FA', 16)
  BlockMountingPosition = int('300A00FB', 16)
  BlockNumber = int('300A00FC', 16)
  BlockName = int('300A00FE', 16)
  BlockThickness = int('300A0100', 16)
  BlockTransmission = int('300A0102', 16)
  BlockNumberofPoints = int('300A0104', 16)
  BlockData = int('300A0106', 16)
  ApplicatorSequence = int('300A0107', 16)
  ApplicatorID = int('300A0108', 16)
  ApplicatorType = int('300A0109', 16)
  ApplicatorDescription = int('300A010A', 16)
  CumulativeDoseReferenceCoefficient = int('300A010C', 16)
  FinalCumulativeMetersetWeight = int('300A010E', 16)
  NumberofControlPoints = int('300A0110', 16)
  ControlPointSequence = int('300A0111', 16)
  ControlPointIndex = int('300A0112', 16)
  NominalBeamEnergy = int('300A0114', 16)
  DoseRateSet = int('300A0115', 16)
  WedgePositionSequence = int('300A0116', 16)
  WedgePosition = int('300A0118', 16)
  BeamLimitingDevicePositionSequence = int('300A011A', 16)
  LeafJawPositions = int('300A011C', 16)
  GantryAngle = int('300A011E', 16)
  GantryRotationDirection = int('300A011F', 16)
  BeamLimitingDeviceAngle = int('300A0120', 16)
  BeamLimitingDeviceRotationDirection = int('300A0121', 16)
  PatientSupportAngle = int('300A0122', 16)
  PatientSupportRotationDirection = int('300A0123', 16)
  TableTopEccentricAxisDistance = int('300A0124', 16)
  TableTopEccentricAngle = int('300A0125', 16)
  TableTopEccentricRotationDirection = int('300A0126', 16)
  TableTopVerticalPosition = int('300A0128', 16)
  TableTopLongitudinalPosition = int('300A0129', 16)
  TableTopLateralPosition = int('300A012A', 16)
  IsocenterPosition = int('300A012C', 16)
  SurfaceEntryPoint = int('300A012E', 16)
  SourcetoSurfaceDistance = int('300A0130', 16)
  AverageBeamDosePointSourcetoExternalContourDistance = int('300A0131', 16)
  SourcetoExternalContourDistance = int('300A0132', 16)
  ExternalContourEntryPoint = int('300A0133', 16)
  CumulativeMetersetWeight = int('300A0134', 16)
  TableTopPitchAngle = int('300A0140', 16)
  TableTopPitchRotationDirection = int('300A0142', 16)
  TableTopRollAngle = int('300A0144', 16)
  TableTopRollRotationDirection = int('300A0146', 16)
  HeadFixationAngle = int('300A0148', 16)
  GantryPitchAngle = int('300A014A', 16)
  GantryPitchRotationDirection = int('300A014C', 16)
  GantryPitchAngleTolerance = int('300A014E', 16)
  FixationEye = int('300A0150', 16)
  ChairHeadFramePosition = int('300A0151', 16)
  HeadFixationAngleTolerance = int('300A0152', 16)
  ChairHeadFramePositionTolerance = int('300A0153', 16)
  FixationLightAzimuthalAngleTolerance = int('300A0154', 16)
  FixationLightPolarAngleTolerance = int('300A0155', 16)
  PatientSetupSequence = int('300A0180', 16)
  PatientSetupNumber = int('300A0182', 16)
  PatientSetupLabel = int('300A0183', 16)
  PatientAdditionalPosition = int('300A0184', 16)
  FixationDeviceSequence = int('300A0190', 16)
  FixationDeviceType = int('300A0192', 16)
  FixationDeviceLabel = int('300A0194', 16)
  FixationDeviceDescription = int('300A0196', 16)
  FixationDevicePosition = int('300A0198', 16)
  FixationDevicePitchAngle = int('300A0199', 16)
  FixationDeviceRollAngle = int('300A019A', 16)
  ShieldingDeviceSequence = int('300A01A0', 16)
  ShieldingDeviceType = int('300A01A2', 16)
  ShieldingDeviceLabel = int('300A01A4', 16)
  ShieldingDeviceDescription = int('300A01A6', 16)
  ShieldingDevicePosition = int('300A01A8', 16)
  SetupTechnique = int('300A01B0', 16)
  SetupTechniqueDescription = int('300A01B2', 16)
  SetupDeviceSequence = int('300A01B4', 16)
  SetupDeviceType = int('300A01B6', 16)
  SetupDeviceLabel = int('300A01B8', 16)
  SetupDeviceDescription = int('300A01BA', 16)
  SetupDeviceParameter = int('300A01BC', 16)
  SetupReferenceDescription = int('300A01D0', 16)
  TableTopVerticalSetupDisplacement = int('300A01D2', 16)
  TableTopLongitudinalSetupDisplacement = int('300A01D4', 16)
  TableTopLateralSetupDisplacement = int('300A01D6', 16)
  BrachyTreatmentTechnique = int('300A0200', 16)
  BrachyTreatmentType = int('300A0202', 16)
  TreatmentMachineSequence = int('300A0206', 16)
  SourceSequence = int('300A0210', 16)
  SourceNumber = int('300A0212', 16)
  SourceType = int('300A0214', 16)
  SourceManufacturer = int('300A0216', 16)
  ActiveSourceDiameter = int('300A0218', 16)
  ActiveSourceLength = int('300A021A', 16)
  SourceModelID = int('300A021B', 16)
  SourceDescription = int('300A021C', 16)
  SourceEncapsulationNominalThickness = int('300A0222', 16)
  SourceEncapsulationNominalTransmission = int('300A0224', 16)
  SourceIsotopeName = int('300A0226', 16)
  SourceIsotopeHalfLife = int('300A0228', 16)
  SourceStrengthUnits = int('300A0229', 16)
  ReferenceAirKermaRate = int('300A022A', 16)
  SourceStrength = int('300A022B', 16)
  SourceStrengthReferenceDate = int('300A022C', 16)
  SourceStrengthReferenceTime = int('300A022E', 16)
  ApplicationSetupSequence = int('300A0230', 16)
  ApplicationSetupType = int('300A0232', 16)
  ApplicationSetupNumber = int('300A0234', 16)
  ApplicationSetupName = int('300A0236', 16)
  ApplicationSetupManufacturer = int('300A0238', 16)
  TemplateNumber = int('300A0240', 16)
  TemplateType = int('300A0242', 16)
  TemplateName = int('300A0244', 16)
  TotalReferenceAirKerma = int('300A0250', 16)
  BrachyAccessoryDeviceSequence = int('300A0260', 16)
  BrachyAccessoryDeviceNumber = int('300A0262', 16)
  BrachyAccessoryDeviceID = int('300A0263', 16)
  BrachyAccessoryDeviceType = int('300A0264', 16)
  BrachyAccessoryDeviceName = int('300A0266', 16)
  BrachyAccessoryDeviceNominalThickness = int('300A026A', 16)
  BrachyAccessoryDeviceNominalTransmission = int('300A026C', 16)
  ChannelSequence = int('300A0280', 16)
  ChannelNumber = int('300A0282', 16)
  ChannelLength = int('300A0284', 16)
  ChannelTotalTime = int('300A0286', 16)
  SourceMovementType = int('300A0288', 16)
  NumberofPulses = int('300A028A', 16)
  PulseRepetitionInterval = int('300A028C', 16)
  SourceApplicatorNumber = int('300A0290', 16)
  SourceApplicatorID = int('300A0291', 16)
  SourceApplicatorType = int('300A0292', 16)
  SourceApplicatorName = int('300A0294', 16)
  SourceApplicatorLength = int('300A0296', 16)
  SourceApplicatorManufacturer = int('300A0298', 16)
  SourceApplicatorWallNominalThickness = int('300A029C', 16)
  SourceApplicatorWallNominalTransmission = int('300A029E', 16)
  SourceApplicatorStepSize = int('300A02A0', 16)
  TransferTubeNumber = int('300A02A2', 16)
  TransferTubeLength = int('300A02A4', 16)
  ChannelShieldSequence = int('300A02B0', 16)
  ChannelShieldNumber = int('300A02B2', 16)
  ChannelShieldID = int('300A02B3', 16)
  ChannelShieldName = int('300A02B4', 16)
  ChannelShieldNominalThickness = int('300A02B8', 16)
  ChannelShieldNominalTransmission = int('300A02BA', 16)
  FinalCumulativeTimeWeight = int('300A02C8', 16)
  BrachyControlPointSequence = int('300A02D0', 16)
  ControlPointRelativePosition = int('300A02D2', 16)
  ControlPoint3DPosition = int('300A02D4', 16)
  CumulativeTimeWeight = int('300A02D6', 16)
  CompensatorDivergence = int('300A02E0', 16)
  CompensatorMountingPosition = int('300A02E1', 16)
  SourcetoCompensatorDistance = int('300A02E2', 16)
  TotalCompensatorTrayWaterEquivalentThickness = int('300A02E3', 16)
  IsocentertoCompensatorTrayDistance = int('300A02E4', 16)
  CompensatorColumnOffset = int('300A02E5', 16)
  IsocentertoCompensatorDistances = int('300A02E6', 16)
  CompensatorRelativeStoppingPowerRatio = int('300A02E7', 16)
  CompensatorMillingToolDiameter = int('300A02E8', 16)
  IonRangeCompensatorSequence = int('300A02EA', 16)
  CompensatorDescription = int('300A02EB', 16)
  RadiationMassNumber = int('300A0302', 16)
  RadiationAtomicNumber = int('300A0304', 16)
  RadiationChargeState = int('300A0306', 16)
  ScanMode = int('300A0308', 16)
  ModulatedScanModeType = int('300A0309', 16)
  VirtualSourceAxisDistances = int('300A030A', 16)
  SnoutSequence = int('300A030C', 16)
  SnoutPosition = int('300A030D', 16)
  SnoutID = int('300A030F', 16)
  NumberofRangeShifters = int('300A0312', 16)
  RangeShifterSequence = int('300A0314', 16)
  RangeShifterNumber = int('300A0316', 16)
  RangeShifterID = int('300A0318', 16)
  RangeShifterType = int('300A0320', 16)
  RangeShifterDescription = int('300A0322', 16)
  NumberofLateralSpreadingDevices = int('300A0330', 16)
  LateralSpreadingDeviceSequence = int('300A0332', 16)
  LateralSpreadingDeviceNumber = int('300A0334', 16)
  LateralSpreadingDeviceID = int('300A0336', 16)
  LateralSpreadingDeviceType = int('300A0338', 16)
  LateralSpreadingDeviceDescription = int('300A033A', 16)
  LateralSpreadingDeviceWaterEquivalentThickness = int('300A033C', 16)
  NumberofRangeModulators = int('300A0340', 16)
  RangeModulatorSequence = int('300A0342', 16)
  RangeModulatorNumber = int('300A0344', 16)
  RangeModulatorID = int('300A0346', 16)
  RangeModulatorType = int('300A0348', 16)
  RangeModulatorDescription = int('300A034A', 16)
  BeamCurrentModulationID = int('300A034C', 16)
  PatientSupportType = int('300A0350', 16)
  PatientSupportID = int('300A0352', 16)
  PatientSupportAccessoryCode = int('300A0354', 16)
  TrayAccessoryCode = int('300A0355', 16)
  FixationLightAzimuthalAngle = int('300A0356', 16)
  FixationLightPolarAngle = int('300A0358', 16)
  MetersetRate = int('300A035A', 16)
  RangeShifterSettingsSequence = int('300A0360', 16)
  RangeShifterSetting = int('300A0362', 16)
  IsocentertoRangeShifterDistance = int('300A0364', 16)
  RangeShifterWaterEquivalentThickness = int('300A0366', 16)
  LateralSpreadingDeviceSettingsSequence = int('300A0370', 16)
  LateralSpreadingDeviceSetting = int('300A0372', 16)
  IsocentertoLateralSpreadingDeviceDistance = int('300A0374', 16)
  RangeModulatorSettingsSequence = int('300A0380', 16)
  RangeModulatorGatingStartValue = int('300A0382', 16)
  RangeModulatorGatingStopValue = int('300A0384', 16)
  RangeModulatorGatingStartWaterEquivalentThickness = int('300A0386', 16)
  RangeModulatorGatingStopWaterEquivalentThickness = int('300A0388', 16)
  IsocentertoRangeModulatorDistance = int('300A038A', 16)
  ScanSpotTuneID = int('300A0390', 16)
  ScanSpotPrescribedIndices = int('300A0391', 16)
  NumberofScanSpotPositions = int('300A0392', 16)
  ScanSpotReordered = int('300A0393', 16)
  ScanSpotPositionMap = int('300A0394', 16)
  ScanSpotReorderingAllowed = int('300A0395', 16)
  ScanSpotMetersetWeights = int('300A0396', 16)
  ScanningSpotSize = int('300A0398', 16)
  NumberofPaintings = int('300A039A', 16)
  IonToleranceTableSequence = int('300A03A0', 16)
  IonBeamSequence = int('300A03A2', 16)
  IonBeamLimitingDeviceSequence = int('300A03A4', 16)
  IonBlockSequence = int('300A03A6', 16)
  IonControlPointSequence = int('300A03A8', 16)
  IonWedgeSequence = int('300A03AA', 16)
  IonWedgePositionSequence = int('300A03AC', 16)
  ReferencedSetupImageSequence = int('300A0401', 16)
  SetupImageComment = int('300A0402', 16)
  MotionSynchronizationSequence = int('300A0410', 16)
  ControlPointOrientation = int('300A0412', 16)
  GeneralAccessorySequence = int('300A0420', 16)
  GeneralAccessoryID = int('300A0421', 16)
  GeneralAccessoryDescription = int('300A0422', 16)
  GeneralAccessoryType = int('300A0423', 16)
  GeneralAccessoryNumber = int('300A0424', 16)
  SourcetoGeneralAccessoryDistance = int('300A0425', 16)
  ApplicatorGeometrySequence = int('300A0431', 16)
  ApplicatorApertureShape = int('300A0432', 16)
  ApplicatorOpening = int('300A0433', 16)
  ApplicatorOpeningX = int('300A0434', 16)
  ApplicatorOpeningY = int('300A0435', 16)
  SourcetoApplicatorMountingPositionDistance = int('300A0436', 16)
  NumberofBlockSlabItems = int('300A0440', 16)
  BlockSlabSequence = int('300A0441', 16)
  BlockSlabThickness = int('300A0442', 16)
  BlockSlabNumber = int('300A0443', 16)
  DeviceMotionControlSequence = int('300A0450', 16)
  DeviceMotionExecutionMode = int('300A0451', 16)
  DeviceMotionObservationMode = int('300A0452', 16)
  DeviceMotionParameterCodeSequence = int('300A0453', 16)
  DistalDepthFraction = int('300A0501', 16)
  DistalDepth = int('300A0502', 16)
  NominalRangeModulationFractions = int('300A0503', 16)
  NominalRangeModulatedRegionDepths = int('300A0504', 16)
  DepthDoseParametersSequence = int('300A0505', 16)
  DeliveredDepthDoseParametersSequence = int('300A0506', 16)
  DeliveredDistalDepthFraction = int('300A0507', 16)
  DeliveredDistalDepth = int('300A0508', 16)
  DeliveredNominalRangeModulationFractions = int('300A0509', 16)
  DeliveredNominalRangeModulatedRegionDepths = int('300A0510', 16)
  DeliveredReferenceDoseDefinition = int('300A0511', 16)
  ReferenceDoseDefinition = int('300A0512', 16)
  ReferencedRTPlanSequence = int('300C0002', 16)
  ReferencedBeamSequence = int('300C0004', 16)
  ReferencedBeamNumber = int('300C0006', 16)
  ReferencedReferenceImageNumber = int('300C0007', 16)
  StartCumulativeMetersetWeight = int('300C0008', 16)
  EndCumulativeMetersetWeight = int('300C0009', 16)
  ReferencedBrachyApplicationSetupSequence = int('300C000A', 16)
  ReferencedBrachyApplicationSetupNumber = int('300C000C', 16)
  ReferencedSourceNumber = int('300C000E', 16)
  ReferencedFractionGroupSequence = int('300C0020', 16)
  ReferencedFractionGroupNumber = int('300C0022', 16)
  ReferencedVerificationImageSequence = int('300C0040', 16)
  ReferencedReferenceImageSequence = int('300C0042', 16)
  ReferencedDoseReferenceSequence = int('300C0050', 16)
  ReferencedDoseReferenceNumber = int('300C0051', 16)
  BrachyReferencedDoseReferenceSequence = int('300C0055', 16)
  ReferencedStructureSetSequence = int('300C0060', 16)
  ReferencedPatientSetupNumber = int('300C006A', 16)
  ReferencedDoseSequence = int('300C0080', 16)
  ReferencedToleranceTableNumber = int('300C00A0', 16)
  ReferencedBolusSequence = int('300C00B0', 16)
  ReferencedWedgeNumber = int('300C00C0', 16)
  ReferencedCompensatorNumber = int('300C00D0', 16)
  ReferencedBlockNumber = int('300C00E0', 16)
  ReferencedControlPointIndex = int('300C00F0', 16)
  ReferencedControlPointSequence = int('300C00F2', 16)
  ReferencedStartControlPointIndex = int('300C00F4', 16)
  ReferencedStopControlPointIndex = int('300C00F6', 16)
  ReferencedRangeShifterNumber = int('300C0100', 16)
  ReferencedLateralSpreadingDeviceNumber = int('300C0102', 16)
  ReferencedRangeModulatorNumber = int('300C0104', 16)
  OmittedBeamTaskSequence = int('300C0111', 16)
  ReasonforOmission = int('300C0112', 16)
  ReasonforOmissionDescription = int('300C0113', 16)
  ApprovalStatus = int('300E0002', 16)
  ReviewDate = int('300E0004', 16)
  ReviewTime = int('300E0005', 16)
  ReviewerName = int('300E0008', 16)
  Arbitrary = int('40000010', 16)
  TextComments = int('40004000', 16)
  ResultsID = int('40080040', 16)
  ResultsIDIssuer = int('40080042', 16)
  ReferencedInterpretationSequence = int('40080050', 16)
  ReportProductionStatusTrial = int('400800FF', 16)
  InterpretationRecordedDate = int('40080100', 16)
  InterpretationRecordedTime = int('40080101', 16)
  InterpretationRecorder = int('40080102', 16)
  ReferencetoRecordedSound = int('40080103', 16)
  InterpretationTranscriptionDate = int('40080108', 16)
  InterpretationTranscriptionTime = int('40080109', 16)
  InterpretationTranscriber = int('4008010A', 16)
  InterpretationText = int('4008010B', 16)
  InterpretationAuthor = int('4008010C', 16)
  InterpretationApproverSequence = int('40080111', 16)
  InterpretationApprovalDate = int('40080112', 16)
  InterpretationApprovalTime = int('40080113', 16)
  PhysicianApprovingInterpretation = int('40080114', 16)
  InterpretationDiagnosisDescription = int('40080115', 16)
  InterpretationDiagnosisCodeSequence = int('40080117', 16)
  ResultsDistributionListSequence = int('40080118', 16)
  DistributionName = int('40080119', 16)
  DistributionAddress = int('4008011A', 16)
  InterpretationID = int('40080200', 16)
  InterpretationIDIssuer = int('40080202', 16)
  InterpretationTypeID = int('40080210', 16)
  InterpretationStatusID = int('40080212', 16)
  Impressions = int('40080300', 16)
  ResultsComments = int('40084000', 16)
  LowEnergyDetectors = int('40100001', 16)
  HighEnergyDetectors = int('40100002', 16)
  DetectorGeometrySequence = int('40100004', 16)
  ThreatROIVoxelSequence = int('40101001', 16)
  ThreatROIBase = int('40101004', 16)
  ThreatROIExtents = int('40101005', 16)
  ThreatROIBitmap = int('40101006', 16)
  RouteSegmentID = int('40101007', 16)
  GantryType = int('40101008', 16)
  OOIOwnerType = int('40101009', 16)
  RouteSegmentSequence = int('4010100A', 16)
  PotentialThreatObjectID = int('40101010', 16)
  ThreatSequence = int('40101011', 16)
  ThreatCategory = int('40101012', 16)
  ThreatCategoryDescription = int('40101013', 16)
  ATDAbilityAssessment = int('40101014', 16)
  ATDAssessmentFlag = int('40101015', 16)
  ATDAssessmentProbability = int('40101016', 16)
  Mass = int('40101017', 16)
  Density = int('40101018', 16)
  ZEffective = int('40101019', 16)
  BoardingPassID = int('4010101A', 16)
  CenterofMass = int('4010101B', 16)
  CenterofPTO = int('4010101C', 16)
  BoundingPolygon = int('4010101D', 16)
  RouteSegmentStartLocationID = int('4010101E', 16)
  RouteSegmentEndLocationID = int('4010101F', 16)
  RouteSegmentLocationIDType = int('40101020', 16)
  AbortReason = int('40101021', 16)
  VolumeofPTO = int('40101023', 16)
  AbortFlag = int('40101024', 16)
  RouteSegmentStartTime = int('40101025', 16)
  RouteSegmentEndTime = int('40101026', 16)
  TDRType = int('40101027', 16)
  InternationalRouteSegment = int('40101028', 16)
  ThreatDetectionAlgorithmandVersion = int('40101029', 16)
  AssignedLocation = int('4010102A', 16)
  AlarmDecisionTime = int('4010102B', 16)
  AlarmDecision = int('40101031', 16)
  NumberofTotalObjects = int('40101033', 16)
  NumberofAlarmObjects = int('40101034', 16)
  PTORepresentationSequence = int('40101037', 16)
  ATDAssessmentSequence = int('40101038', 16)
  TIPType = int('40101039', 16)
  Version = int('4010103A', 16)
  OOIOwnerCreationTime = int('40101041', 16)
  OOIType = int('40101042', 16)
  OOISize = int('40101043', 16)
  AcquisitionStatus = int('40101044', 16)
  BasisMaterialsCodeSequence = int('40101045', 16)
  PhantomType = int('40101046', 16)
  OOIOwnerSequence = int('40101047', 16)
  ScanType = int('40101048', 16)
  ItineraryID = int('40101051', 16)
  ItineraryIDType = int('40101052', 16)
  ItineraryIDAssigningAuthority = int('40101053', 16)
  RouteID = int('40101054', 16)
  RouteIDAssigningAuthority = int('40101055', 16)
  InboundArrivalType = int('40101056', 16)
  CarrierID = int('40101058', 16)
  CarrierIDAssigningAuthority = int('40101059', 16)
  SourceOrientation = int('40101060', 16)
  SourcePosition = int('40101061', 16)
  BeltHeight = int('40101062', 16)
  AlgorithmRoutingCodeSequence = int('40101064', 16)
  TransportClassification = int('40101067', 16)
  OOITypeDescriptor = int('40101068', 16)
  TotalProcessingTime = int('40101069', 16)
  DetectorCalibrationData = int('4010106C', 16)
  AdditionalScreeningPerformed = int('4010106D', 16)
  AdditionalInspectionSelectionCriteria = int('4010106E', 16)
  AdditionalInspectionMethodSequence = int('4010106F', 16)
  AITDeviceType = int('40101070', 16)
  QRMeasurementsSequence = int('40101071', 16)
  TargetMaterialSequence = int('40101072', 16)
  SNRThreshold = int('40101073', 16)
  ImageScaleRepresentation = int('40101075', 16)
  ReferencedPTOSequence = int('40101076', 16)
  ReferencedTDRInstanceSequence = int('40101077', 16)
  PTOLocationDescription = int('40101078', 16)
  AnomalyLocatorIndicatorSequence = int('40101079', 16)
  AnomalyLocatorIndicator = int('4010107A', 16)
  PTORegionSequence = int('4010107B', 16)
  InspectionSelectionCriteria = int('4010107C', 16)
  SecondaryInspectionMethodSequence = int('4010107D', 16)
  PRCStoRCSOrientation = int('4010107E', 16)
  MACParametersSequence = int('4FFE0001', 16)
  SharedFunctionalGroupsSequence = int('52009229', 16)
  PerframeFunctionalGroupsSequence = int('52009230', 16)
  WaveformSequence = int('54000100', 16)
  ChannelMinimumValue = int('54000110', 16)
  ChannelMaximumValue = int('54000112', 16)
  WaveformBitsAllocated = int('54001004', 16)
  WaveformSampleInterpretation = int('54001006', 16)
  WaveformPaddingValue = int('5400100A', 16)
  WaveformData = int('54001010', 16)
  FirstOrderPhaseCorrectionAngle = int('56000010', 16)
  SpectroscopyData = int('56000020', 16)
  FloatPixelData = int('7FE00008', 16)
  DoubleFloatPixelData = int('7FE00009', 16)
  PixelData = int('7FE00010', 16)
  CoefficientsSDVN = int('7FE00020', 16)
  CoefficientsSDHN = int('7FE00030', 16)
  CoefficientsSDDN = int('7FE00040', 16)
  DigitalSignaturesSequence = int('FFFAFFFA', 16)
  DataSetTrailingPadding = int('FFFCFFFC', 16)
  Item = int('FFFEE000', 16)
  ItemDelimitationItem = int('FFFEE00D', 16)
  SequenceDelimitationItem = int('FFFEE0DD', 16)
